#pragma once
/*
	Quadcopter PC configuration and monitoring application

	1. Connect to Quadcopter - serial connection
	2. Get configuration variables and update then
	3. Save configuration into EEPROM, load from EEPROM, reset config to default
	4. Configuration
		Battery warning level and current voltage
		I2C Scan
		LED configuration
		RC receiver
			PPM shift
			Number of channels and channel assignment
			Altitude Hold Tx value
			IMU On/Off TX value
		GPS type and GMT offset
		Motor configuration
			Number of motors
			+ or x
			Front CW or CCW
			Motor sensitivity - RC value to motor speed
			Motor update rate
			disable motors
			default IMU mode
			PID Kp, Ki, Kd, Krp values, max i, min i
		Camera servo
			Pan/Tilt center, offset, ranges
		Sensor
			Axis to axis map
			invert map
			Pitch, Roll, Yaw offset
		Configuration of IMU Kalman constants
	5. Quadcopter picture showing orientation, motor speeds, gyro/acc sensor output
	6. Artificial horizon
	7. Waypoint map showing current location and waypoints
	8. IMU state data
	9. Serial monitor - serial data from Quadcopter (except information parsed by app e.g. IMU state, artifical horizon data)
	10. Plot of running history of
		sensors - gyro, accelerometer, compass, pressure
		IMU output
		motor speeds
		PID values
		RC receiver values
	11. Enable/disable display of serial data parsed by application i.e. raw/parsed display
		Note: info is allows written to capture file
	12. Load of a capture file and display plot and config
	13. Direct control of motor speeds
	14. Baudrate is defaulted to 230400 but can be overriden using a DWORD reg key (actual baud rate)
			HK_CU\Software\timmmoore\QuadCopter\BaudRate
	15. Save 
			Window location/size
			COM port
			Raw Mode
	16. ESC calibration
		Set motors to max
		Tell user to power ESCs up, press button on beep
		Set motors to min
	17. Camera stablization on/off
	18.	Status line containing
			motor speeds
			IMU angles
			capture file
			Battery alarm
			Altitude hold
			COM port status
			Configuration variable status
	19. Get Clock Speed from Quad
*/
#define CLKSPEED 80000000		// default Quad clock speed until updated from Quad

namespace QuadConsole1 {

	using namespace System;
	using namespace System::Threading;
	using namespace System::ComponentModel;
	using namespace System::Collections;
	using namespace System::Windows::Forms;
	using namespace System::Data;
	using namespace System::Drawing;
	using namespace System::Drawing::Drawing2D;
	using namespace System::Globalization;
	using namespace System::IO;
	using namespace Microsoft::Win32;

	double scales[] = { 0.0001, 0.001, 0.01, 0.1, 1.0, 10.0, 100.0, 1000.0, 10000.0 };
	int clockfreq;
	int mcommand[4];
	int times[16];
	int motors[8];
	int pids[8];
	int rc[8];
	int initdone;
	int closing;
	int doingtext;
	int tobeclosed;
	struct {
		unsigned int valid;
		unsigned int latq;
		unsigned int longq;
		unsigned int altq;
		unsigned int pressureq;
	} waypoints[20];
	/// <summary>
	/// Summary for Form1
	/// </summary>
	public ref class Form1 : public System::Windows::Forms::Form
	{
	public:
		static int varmaxcount;
		static int varindex;
 		static int varmax;
		static Form1 ^form;
		static int update;
		static int noupdate;
		static int startcalibration;
		static int calibrationcount;
		int rawmode;
		int pointIndex;
		int numberOfPointsInChart;
		int numberOfPointsAfterRemoval;
		array<Color>^ colors;
		String^ comp;
		Rectangle rectl;
		Rectangle rectr;
		int startah;
		int startquad;
		int baudrate;
		Drawing::Font^ hupfont;
		String^ line;
		Pen^ pblackpen;
		Pen^ tblackpen;
		Pen^ blackpen;
		Pen^ ablackpen;
		Pen^ amotorpen;
		Pen^ redpen;
		Brush^ white;
		Brush^ brown;
		Brush^ blue;
		double Pitch, Roll, Yaw, PitchA, RollA;
		double SPitch, SRoll, SYaw;
		double HYaw, HPitchA, HRollA;
		double HSPitch, HSRoll, HSYaw;
		static Mutex^ mut;
	    static StreamWriter^ myStream ;
	    static StreamReader^ myReadStream ;

	private: System::Windows::Forms::Label^  label35;
	private: System::Windows::Forms::Label^  label34;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown12;

	private: System::Windows::Forms::GroupBox^  groupBox3;
	private: System::Windows::Forms::Label^  label42;
	private: System::Windows::Forms::Label^  label43;
	private: System::Windows::Forms::Label^  label44;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown29;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown30;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown31;
	private: System::Windows::Forms::GroupBox^  groupBox2;
	private: System::Windows::Forms::Label^  label39;
	private: System::Windows::Forms::Label^  label40;
	private: System::Windows::Forms::Label^  label41;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown26;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown27;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown28;
	private: System::Windows::Forms::GroupBox^  groupBox1;
	private: System::Windows::Forms::Label^  label38;
	private: System::Windows::Forms::Label^  label37;
	private: System::Windows::Forms::Label^  label36;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown25;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown24;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown23;
	private: System::Windows::Forms::TabPage^  tabPage10;
	private: System::Windows::Forms::RichTextBox^  richTextBox2;
	private: System::Windows::Forms::GroupBox^  groupBox4;
	private: System::Windows::Forms::Button^  button2;
	private: System::Windows::Forms::Button^  button4;
	private: System::Windows::Forms::Button^  button3;
	private: System::Windows::Forms::Button^  button5;
	private: System::Windows::Forms::Label^  label45;
	private: System::Windows::Forms::ComboBox^  comboBox4;
	private: System::Windows::Forms::TabPage^  tabPage11;
	private: System::Windows::Forms::PictureBox^  pictureBox1;
	private: System::Windows::Forms::CheckBox^  checkBox7;
	private: System::Windows::Forms::Label^  label47;
	private: System::Windows::Forms::Label^  label46;
	private: System::Windows::Forms::Button^  button6;
	private: System::Windows::Forms::SaveFileDialog^  saveFileDialog1;

	private: System::Windows::Forms::TrackBar^  trackBar4;
	private: System::Windows::Forms::TrackBar^  trackBar3;
	private: System::Windows::Forms::TrackBar^  trackBar2;
	private: System::Windows::Forms::TrackBar^  trackBar1;
	private: System::Windows::Forms::Label^  label50;
	private: System::Windows::Forms::Label^  label49;
	private: System::Windows::Forms::Label^  label48;




	private: System::Windows::Forms::CheckBox^  checkBox10;
	private: System::Windows::Forms::CheckBox^  checkBox9;
	private: System::Windows::Forms::CheckBox^  checkBox2;
	private: System::Windows::Forms::CheckBox^  checkBox13;
	private: System::Windows::Forms::CheckBox^  checkBox12;
	private: System::Windows::Forms::CheckBox^  checkBox11;
	private: System::Windows::Forms::CheckBox^  checkBox16;
	private: System::Windows::Forms::CheckBox^  checkBox15;
	private: System::Windows::Forms::CheckBox^  checkBox14;
	private: System::Windows::Forms::Button^  button9;
	private: System::Windows::Forms::Button^  button8;
	private: System::Windows::Forms::Button^  button7;
	private: System::Windows::Forms::Label^  label55;
	private: System::Windows::Forms::Label^  label54;
	private: System::Windows::Forms::Label^  label53;
	private: System::Windows::Forms::TabPage^  tabPage12;

	private: System::Windows::Forms::Button^  button12;
	private: System::Windows::Forms::Button^  button11;
	private: System::Windows::Forms::Button^  button10;
	private: System::Windows::Forms::Button^  button13;
	private: System::Windows::Forms::Label^  label58;
	private: System::Windows::Forms::Label^  label57;
	private: System::Windows::Forms::Label^  label56;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown33;
	private: System::Windows::Forms::TextBox^  textBox10;
	private: System::Windows::Forms::TextBox^  textBox9;
	private: System::Windows::Forms::TextBox^  textBox8;
	private: System::Windows::Forms::Label^  label59;
	private: System::Windows::Forms::TextBox^  textBox11;

	private: System::Windows::Forms::TabPage^  tabPage13;
	private: System::Windows::Forms::PictureBox^  pictureBox2;
private: System::Windows::Forms::Label^  label65;
private: System::Windows::Forms::Label^  label64;
private: System::Windows::Forms::Label^  label63;
private: System::Windows::Forms::Label^  label62;
private: System::Windows::Forms::Label^  label61;
private: System::Windows::Forms::Label^  label60;
private: System::Windows::Forms::Label^  label70;
private: System::Windows::Forms::Label^  label69;
private: System::Windows::Forms::Label^  label68;
private: System::Windows::Forms::Label^  label67;
private: System::Windows::Forms::Label^  label66;
private: System::Windows::Forms::TrackBar^  trackBar10;
private: System::Windows::Forms::TrackBar^  trackBar9;
private: System::Windows::Forms::TrackBar^  trackBar8;
private: System::Windows::Forms::TrackBar^  trackBar7;
private: System::Windows::Forms::TrackBar^  trackBar6;
private: System::Windows::Forms::TrackBar^  trackBar5;
private: System::Windows::Forms::TabPage^  tabPage14;
private: System::Windows::Forms::DataVisualization::Charting::Chart^  chart1;

















private: System::Windows::Forms::CheckBox^  checkBox34;
private: System::Windows::Forms::GroupBox^  groupBox6;
private: System::Windows::Forms::Label^  label75;
private: System::Windows::Forms::Label^  label74;
private: System::Windows::Forms::Label^  label73;
private: System::Windows::Forms::Label^  label72;
private: System::Windows::Forms::Label^  label71;
private: System::Windows::Forms::TextBox^  textBox16;
private: System::Windows::Forms::TextBox^  textBox15;
private: System::Windows::Forms::TextBox^  textBox14;
private: System::Windows::Forms::TextBox^  textBox13;
private: System::Windows::Forms::TextBox^  textBox12;
private: System::Windows::Forms::Button^  button14;
private: System::Windows::Forms::OpenFileDialog^  openFileDialog1;
private: System::Windows::Forms::GroupBox^  groupBox5;
private: System::Windows::Forms::Button^  button15;




private: System::Windows::Forms::CheckedListBox^  checkedListBox1;
private: System::Windows::Forms::Label^  label77;
private: System::Windows::Forms::Label^  label76;
private: System::Windows::Forms::PictureBox^  pictureBox3;

private: System::Windows::Forms::TextBox^  textBox17;
private: System::Windows::Forms::TrackBar^  trackBar18;
private: System::Windows::Forms::TrackBar^  trackBar17;
private: System::Windows::Forms::TrackBar^  trackBar16;
private: System::Windows::Forms::TrackBar^  trackBar15;
private: System::Windows::Forms::TrackBar^  trackBar14;
private: System::Windows::Forms::TrackBar^  trackBar13;
private: System::Windows::Forms::TrackBar^  trackBar12;
private: System::Windows::Forms::TrackBar^  trackBar11;
private: System::Windows::Forms::TabPage^  tabPage15;



private: System::Windows::Forms::Button^  button16;
private: System::Windows::Forms::RichTextBox^  richTextBox4;
private: System::Windows::Forms::RichTextBox^  richTextBox3;
private: System::Windows::Forms::Label^  label81;
private: System::Windows::Forms::Label^  label80;
private: System::Windows::Forms::Label^  label79;
private: System::Windows::Forms::CheckBox^  checkBox8;
private: System::Windows::Forms::GroupBox^  groupBox7;
private: System::Windows::Forms::GroupBox^  groupBox8;
private: System::Windows::Forms::GroupBox^  groupBox10;
private: System::Windows::Forms::GroupBox^  groupBox9;
private: System::Windows::Forms::GroupBox^  groupBox11;
private: System::Windows::Forms::GroupBox^  groupBox12;
private: System::Windows::Forms::Label^  label83;
private: System::Windows::Forms::Label^  label84;
private: System::Windows::Forms::Label^  label52;
private: System::Windows::Forms::Label^  label82;
private: System::Windows::Forms::Label^  label51;
private: System::Windows::Forms::Label^  label1;
private: System::Windows::Forms::CheckBox^  checkBox19;
private: System::Windows::Forms::CheckBox^  checkBox18;
private: System::Windows::Forms::CheckBox^  checkBox17;
private: System::Windows::Forms::PictureBox^  pictureBox4;
private: System::Windows::Forms::GroupBox^  groupBox13;
private: System::Windows::Forms::StatusStrip^  statusStrip1;

private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel2;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel3;
private: System::Windows::Forms::CheckBox^  checkBox20;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel4;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel5;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel6;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel7;
private: System::Windows::Forms::ToolStripStatusLabel^  toolStripStatusLabel8;

private: System::Windows::Forms::ToolStripSplitButton^  toolStripSplitButton1;
private: System::Windows::Forms::SplitContainer^  splitContainer1;
private: System::Windows::Forms::ListBox^  listBox22;
private: System::Windows::Forms::ListBox^  listBox23;
private: System::Windows::Forms::ListBox^  listBox24;
private: System::Windows::Forms::ListBox^  listBox25;
private: System::Windows::Forms::ListBox^  listBox26;
private: System::Windows::Forms::ListBox^  listBox27;
private: System::Windows::Forms::ListBox^  listBox28;
private: System::Windows::Forms::ListBox^  listBox15;
private: System::Windows::Forms::ListBox^  listBox16;
private: System::Windows::Forms::ListBox^  listBox17;
private: System::Windows::Forms::ListBox^  listBox18;
private: System::Windows::Forms::ListBox^  listBox19;
private: System::Windows::Forms::ListBox^  listBox20;
private: System::Windows::Forms::ListBox^  listBox21;
private: System::Windows::Forms::ListBox^  listBox8;
private: System::Windows::Forms::ListBox^  listBox9;
private: System::Windows::Forms::ListBox^  listBox10;
private: System::Windows::Forms::ListBox^  listBox11;
private: System::Windows::Forms::ListBox^  listBox12;
private: System::Windows::Forms::ListBox^  listBox13;
private: System::Windows::Forms::ListBox^  listBox14;
private: System::Windows::Forms::ListBox^  listBox7;
private: System::Windows::Forms::ListBox^  listBox6;
private: System::Windows::Forms::ListBox^  listBox5;
private: System::Windows::Forms::ListBox^  listBox4;
private: System::Windows::Forms::ListBox^  listBox3;
private: System::Windows::Forms::ListBox^  listBox2;
private: System::Windows::Forms::ListBox^  listBox1;
private: System::Windows::Forms::ListBox^  listBox29;
private: System::Windows::Forms::ListBox^  listBox30;
private: System::Windows::Forms::ListBox^  listBox31;
private: System::Windows::Forms::ListBox^  listBox34;
private: System::Windows::Forms::ListBox^  listBox32;
private: System::Windows::Forms::ListBox^  listBox33;
private: System::Windows::Forms::ListBox^  listBox36;
private: System::Windows::Forms::ListBox^  listBox35;
private: System::Windows::Forms::Label^  label78;
private: System::Windows::Forms::Label^  label85;
private: System::Windows::Forms::Label^  label86;
private: System::Windows::Forms::GroupBox^  groupBox14;
private: System::Windows::Forms::Label^  label87;
private: System::Windows::Forms::Label^  label88;
private: System::Windows::Forms::CheckBox^  checkBox21;
private: System::Windows::Forms::CheckBox^  checkBox22;
private: System::Windows::Forms::CheckBox^  checkBox23;
private: System::Windows::Forms::Label^  label89;
private: System::Windows::Forms::Label^  label90;
private: System::Windows::Forms::Label^  label91;
private: System::Windows::Forms::NumericUpDown^  numericUpDown32;
private: System::Windows::Forms::NumericUpDown^  numericUpDown34;
private: System::Windows::Forms::NumericUpDown^  numericUpDown35;












	private: System::Windows::Forms::NumericUpDown^  numericUpDown11;
	public: 
		Form1(void)
		{
			comp = nullptr;
			InitializeComponent();

			InitControls();
			clockfreq = CLKSPEED;
			tobeclosed = 0;
			closing = 0;
			rawmode = 0;
			startcalibration = 0;
			mut = gcnew Mutex;
			hupfont = gcnew System::Drawing::Font(L"Parallax", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0));
			white = gcnew SolidBrush(Color::White);
			brown = gcnew SolidBrush(Color::Brown);
			blue = gcnew SolidBrush(Color::Blue);
			pblackpen = gcnew Pen(Brushes::Black, 1);
			tblackpen = gcnew Pen(Brushes::White, 2);
			blackpen = gcnew Pen(Brushes::Black, 8);
			ablackpen = gcnew Pen(Brushes::Black, 8);
			amotorpen = gcnew Pen(Brushes::Blue, 8);
			redpen = gcnew Pen(Brushes::Red, 8);
			redpen->EndCap = System::Drawing::Drawing2D::LineCap::ArrowAnchor;
			ablackpen->EndCap = System::Drawing::Drawing2D::LineCap::ArrowAnchor;
			amotorpen->EndCap = System::Drawing::Drawing2D::LineCap::ArrowAnchor;
			Pitch = Math::PI * 165.0 / 180.0;
			PitchA = Pitch - Math::PI;
			Roll =  Math::PI * 170.0 / 180.0;
			RollA = Roll - Math::PI;
			Yaw =  Math::PI * 25.0 / 180.0;
			SPitch = PitchA;
			SRoll =  RollA;
			SYaw =  Yaw;
			HYaw = Yaw;
			HPitchA = PitchA;
			HRollA = RollA;
			HSPitch = SPitch;
			HSRoll = SRoll;
			HSYaw = SYaw;
			label86->Text = "";
			String ^s = "P: " + Q15s2Str((unsigned int)((PitchA*180.0)/Math::PI)<<16, 3) + " R: " + Q15s2Str((unsigned int)((RollA*180.0)/Math::PI)<<16, 3) + " Y: " + Q15s2Str((unsigned int)((Yaw*180.0)/Math::PI)<<16, 3);
			toolStripStatusLabel7->Text = s;
			s = "F:" + motors[0].ToString("D") + " B:" + motors[1].ToString("D") + " L:" + motors[2].ToString("D") + " R:" + motors[3].ToString("D");
			toolStripStatusLabel8->Text = s;
			this->label48->Text = Q15s2Str((unsigned int)((PitchA*180.0)/Math::PI)<<16, 3);
			this->label49->Text = Q15s2Str((unsigned int)((RollA*180.0)/Math::PI)<<16, 3);
			this->label50->Text = Q15s2Str((unsigned int)((Yaw*180.0)/Math::PI)<<16, 3);
			Decimal way = numericUpDown33->Value;
			this->textBox8->Text = Q15s2Str(waypoints[(int)way].latq);
			textBox9->Text = Q15s2Str(waypoints[(int)way].longq);
			textBox10->Text = Q15s2Str(waypoints[(int)way].altq);
			pointIndex = 0;
			numberOfPointsInChart = 1000;
			numberOfPointsAfterRemoval = 950;
			toolStripSplitButton1->Text = "Connect";
			toolStripStatusLabel4->Text = "";
			toolStripStatusLabel5->Text = "";
			toolStripStatusLabel6->Text = "";
			SetConfigStatus(false);
			SetHeadsUpSize();
			QuadTabSizeChanged();
			SetupSeries();
			HistoryTabSizeChanged();
			CalibrationTabSizeChanged();
			if((clockfreq % 1000000) == 0)
			{
				label78->Text = (clockfreq/1000000).ToString() + "Mhz";
			}
			else if((clockfreq % 1000) == 0)
			{
				label78->Text = (clockfreq/1000).ToString() + "Khz";
			}
			else
			{
				label78->Text = (clockfreq).ToString() + "Hz";
			}
			listBox1->SelectedIndex = 4;
			listBox2->SelectedIndex = 4;
			listBox3->SelectedIndex = 4;
			listBox4->SelectedIndex = 4;
			listBox5->SelectedIndex = 4;
			listBox6->SelectedIndex = 4;
			listBox7->SelectedIndex = 4;
			listBox8->SelectedIndex = 4;
			listBox9->SelectedIndex = 4;
			listBox10->SelectedIndex = 4;
			listBox11->SelectedIndex = 4;
			listBox12->SelectedIndex = 4;
			listBox13->SelectedIndex = 4;
			listBox14->SelectedIndex = 4;
			listBox15->SelectedIndex = 4;
			listBox16->SelectedIndex = 4;
			listBox17->SelectedIndex = 4;
			listBox18->SelectedIndex = 4;
			listBox19->SelectedIndex = 4;
			listBox20->SelectedIndex = 4;
			listBox21->SelectedIndex = 4;
			listBox22->SelectedIndex = 4;
			listBox23->SelectedIndex = 4;
			listBox24->SelectedIndex = 4;
			listBox25->SelectedIndex = 4;
			listBox26->SelectedIndex = 4;
			listBox27->SelectedIndex = 4;
			listBox28->SelectedIndex = 4;
			listBox29->SelectedIndex = 4;
			listBox30->SelectedIndex = 4;
			listBox31->SelectedIndex = 4;
			listBox32->SelectedIndex = 4;
			listBox33->SelectedIndex = 4;
			listBox34->SelectedIndex = 4;
			listBox35->SelectedIndex = 4;
			listBox36->SelectedIndex = 4;
			chart1->ApplyPaletteColors();
			System::Windows::Forms::DataVisualization::Charting::Series^ ser;
			int i = 0;
			colors = gcnew array<Color>(10);
			ser = this->chart1->Series->FindByName("Gyro X");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Gyro Y");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Gyro Z");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Acc X");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Acc Y");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Acc Z");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Mag X");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Mag Y");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Mag Z");
			colors[i++] = ser->Color;
			ser = this->chart1->Series->FindByName("Pressure");
			colors[i++] = ser->Color;
		}

	protected:
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		~Form1()
		{
			closing = 1;
			WriteConfig();
			if(myStream)
				myStream->Close();
			this->serialPort1->Close();
			delete tblackpen;
			delete blackpen;
			delete ablackpen;
			delete amotorpen;
			delete redpen;
			if (components)
			{
				delete components;
			}
		}
   static System::Windows::Forms::Timer^ myTimer = gcnew System::Windows::Forms::Timer;
	private: System::Windows::Forms::TabControl^  tabControl1;
	protected: 
	private: System::Windows::Forms::TabPage^  tabPage1;

	private: System::Windows::Forms::ComboBox^  comboBox1;
	private: System::Windows::Forms::TabPage^  tabPage2;
	private: System::Windows::Forms::TabPage^  tabPage3;
	private: System::Windows::Forms::Label^  label2;
	private: System::Windows::Forms::TextBox^  textBox2;
	private: System::Windows::Forms::Label^  label3;
	private: System::Windows::Forms::TextBox^  textBox1;
	private: System::Windows::Forms::CheckBox^  checkBox3;

	private: System::Windows::Forms::CheckBox^  checkBox1;
	private: System::Windows::Forms::TabPage^  tabPage4;
	private: System::Windows::Forms::Label^  label12;
	private: System::Windows::Forms::Label^  label11;
	private: System::Windows::Forms::Label^  label10;
	private: System::Windows::Forms::Label^  label9;
	private: System::Windows::Forms::Label^  label8;
	private: System::Windows::Forms::Label^  label7;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown10;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown9;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown8;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown7;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown6;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown5;
	private: System::Windows::Forms::Label^  label6;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown4;
	private: System::Windows::Forms::Label^  label5;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown3;
	private: System::Windows::Forms::Label^  label4;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown2;
	private: System::Windows::Forms::Label^  label13;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown1;
	private: System::Windows::Forms::CheckBox^  checkBox4;
	private: System::Windows::Forms::TabPage^  tabPage5;
	private: System::Windows::Forms::Label^  label15;
	private: System::Windows::Forms::ComboBox^  comboBox2;
	private: System::Windows::Forms::TabPage^  tabPage6;
	private: System::Windows::Forms::Label^  label23;
	private: System::Windows::Forms::Label^  label22;
	private: System::Windows::Forms::Label^  label21;
	private: System::Windows::Forms::Label^  label20;
	private: System::Windows::Forms::TextBox^  textBox7;
	private: System::Windows::Forms::TextBox^  textBox6;
	private: System::Windows::Forms::TextBox^  textBox5;
	private: System::Windows::Forms::TextBox^  textBox4;
	private: System::Windows::Forms::Label^  label19;
	private: System::Windows::Forms::TextBox^  textBox3;
	private: System::Windows::Forms::Label^  label18;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown14;
	private: System::Windows::Forms::Label^  label17;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown13;
	private: System::Windows::Forms::CheckBox^  checkBox6;
	private: System::Windows::Forms::CheckBox^  checkBox5;
	private: System::Windows::Forms::Label^  label16;
	private: System::Windows::Forms::ComboBox^  comboBox3;
	private: System::Windows::Forms::TabPage^  tabPage7;
	private: System::Windows::Forms::Label^  label31;
	private: System::Windows::Forms::Label^  label30;
	private: System::Windows::Forms::Label^  label29;
	private: System::Windows::Forms::Label^  label28;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown22;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown21;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown20;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown19;
	private: System::Windows::Forms::Label^  label27;
	private: System::Windows::Forms::Label^  label26;
	private: System::Windows::Forms::Label^  label25;
	private: System::Windows::Forms::Label^  label24;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown18;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown17;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown16;
	private: System::Windows::Forms::NumericUpDown^  numericUpDown15;
	private: System::IO::Ports::SerialPort^  serialPort1;
	private: System::Windows::Forms::TabPage^  tabPage8;
	private: System::Windows::Forms::Button^  button1;
private: System::Windows::Forms::RichTextBox^  richTextBox1;
private: System::Windows::Forms::TabPage^  tabPage9;
private: System::Windows::Forms::Label^  label14;
private: System::Windows::Forms::Label^  label33;
private: System::Windows::Forms::Label^  label32;



	private: System::ComponentModel::IContainer^  components;

	private:
		/// <summary>
		/// Required designer variable.
		/// </summary>


#pragma region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		void InitializeComponent(void)
		{
			this->components = (gcnew System::ComponentModel::Container());
			System::ComponentModel::ComponentResourceManager^  resources = (gcnew System::ComponentModel::ComponentResourceManager(Form1::typeid));
			System::Windows::Forms::DataVisualization::Charting::ChartArea^  chartArea3 = (gcnew System::Windows::Forms::DataVisualization::Charting::ChartArea());
			System::Windows::Forms::DataVisualization::Charting::Legend^  legend3 = (gcnew System::Windows::Forms::DataVisualization::Charting::Legend());
			System::Windows::Forms::DataVisualization::Charting::Series^  series145 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series146 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series147 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series148 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series149 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series150 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series151 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series152 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series153 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series154 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series155 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series156 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series157 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series158 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series159 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series160 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series161 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series162 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series163 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series164 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series165 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series166 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series167 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series168 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series169 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series170 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series171 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series172 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series173 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series174 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series175 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series176 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series177 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series178 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series179 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series180 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series181 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series182 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series183 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series184 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series185 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series186 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series187 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series188 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series189 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series190 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series191 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series192 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series193 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series194 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series195 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series196 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series197 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series198 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series199 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series200 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series201 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series202 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series203 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series204 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series205 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series206 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series207 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series208 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series209 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series210 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series211 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series212 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series213 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series214 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series215 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			System::Windows::Forms::DataVisualization::Charting::Series^  series216 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
			this->tabControl1 = (gcnew System::Windows::Forms::TabControl());
			this->tabPage1 = (gcnew System::Windows::Forms::TabPage());
			this->label86 = (gcnew System::Windows::Forms::Label());
			this->groupBox12 = (gcnew System::Windows::Forms::GroupBox());
			this->comboBox1 = (gcnew System::Windows::Forms::ComboBox());
			this->checkBox34 = (gcnew System::Windows::Forms::CheckBox());
			this->button1 = (gcnew System::Windows::Forms::Button());
			this->groupBox4 = (gcnew System::Windows::Forms::GroupBox());
			this->button5 = (gcnew System::Windows::Forms::Button());
			this->button4 = (gcnew System::Windows::Forms::Button());
			this->button3 = (gcnew System::Windows::Forms::Button());
			this->button2 = (gcnew System::Windows::Forms::Button());
			this->groupBox5 = (gcnew System::Windows::Forms::GroupBox());
			this->button15 = (gcnew System::Windows::Forms::Button());
			this->button6 = (gcnew System::Windows::Forms::Button());
			this->button14 = (gcnew System::Windows::Forms::Button());
			this->tabPage2 = (gcnew System::Windows::Forms::TabPage());
			this->richTextBox1 = (gcnew System::Windows::Forms::RichTextBox());
			this->tabPage3 = (gcnew System::Windows::Forms::TabPage());
			this->label85 = (gcnew System::Windows::Forms::Label());
			this->label78 = (gcnew System::Windows::Forms::Label());
			this->checkBox3 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox1 = (gcnew System::Windows::Forms::CheckBox());
			this->groupBox7 = (gcnew System::Windows::Forms::GroupBox());
			this->label46 = (gcnew System::Windows::Forms::Label());
			this->label47 = (gcnew System::Windows::Forms::Label());
			this->textBox1 = (gcnew System::Windows::Forms::TextBox());
			this->label3 = (gcnew System::Windows::Forms::Label());
			this->label2 = (gcnew System::Windows::Forms::Label());
			this->textBox2 = (gcnew System::Windows::Forms::TextBox());
			this->tabPage4 = (gcnew System::Windows::Forms::TabPage());
			this->trackBar18 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar17 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar16 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar15 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar14 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar13 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar12 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar11 = (gcnew System::Windows::Forms::TrackBar());
			this->label35 = (gcnew System::Windows::Forms::Label());
			this->label34 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown12 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown11 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label12 = (gcnew System::Windows::Forms::Label());
			this->label11 = (gcnew System::Windows::Forms::Label());
			this->label10 = (gcnew System::Windows::Forms::Label());
			this->label9 = (gcnew System::Windows::Forms::Label());
			this->label8 = (gcnew System::Windows::Forms::Label());
			this->label7 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown10 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown9 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown8 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown7 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown6 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown5 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label6 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown4 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label5 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown3 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label4 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown2 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label13 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown1 = (gcnew System::Windows::Forms::NumericUpDown());
			this->checkBox4 = (gcnew System::Windows::Forms::CheckBox());
			this->tabPage5 = (gcnew System::Windows::Forms::TabPage());
			this->label45 = (gcnew System::Windows::Forms::Label());
			this->comboBox4 = (gcnew System::Windows::Forms::ComboBox());
			this->label15 = (gcnew System::Windows::Forms::Label());
			this->comboBox2 = (gcnew System::Windows::Forms::ComboBox());
			this->tabPage6 = (gcnew System::Windows::Forms::TabPage());
			this->checkBox8 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox7 = (gcnew System::Windows::Forms::CheckBox());
			this->label18 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown14 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label17 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown13 = (gcnew System::Windows::Forms::NumericUpDown());
			this->checkBox6 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox5 = (gcnew System::Windows::Forms::CheckBox());
			this->label16 = (gcnew System::Windows::Forms::Label());
			this->comboBox3 = (gcnew System::Windows::Forms::ComboBox());
			this->groupBox8 = (gcnew System::Windows::Forms::GroupBox());
			this->label19 = (gcnew System::Windows::Forms::Label());
			this->label59 = (gcnew System::Windows::Forms::Label());
			this->textBox3 = (gcnew System::Windows::Forms::TextBox());
			this->textBox11 = (gcnew System::Windows::Forms::TextBox());
			this->textBox4 = (gcnew System::Windows::Forms::TextBox());
			this->textBox5 = (gcnew System::Windows::Forms::TextBox());
			this->label23 = (gcnew System::Windows::Forms::Label());
			this->textBox6 = (gcnew System::Windows::Forms::TextBox());
			this->label22 = (gcnew System::Windows::Forms::Label());
			this->textBox7 = (gcnew System::Windows::Forms::TextBox());
			this->label21 = (gcnew System::Windows::Forms::Label());
			this->label20 = (gcnew System::Windows::Forms::Label());
			this->tabPage7 = (gcnew System::Windows::Forms::TabPage());
			this->checkBox20 = (gcnew System::Windows::Forms::CheckBox());
			this->groupBox10 = (gcnew System::Windows::Forms::GroupBox());
			this->label26 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown15 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label27 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown16 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown17 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label25 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown18 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label24 = (gcnew System::Windows::Forms::Label());
			this->groupBox9 = (gcnew System::Windows::Forms::GroupBox());
			this->numericUpDown20 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label31 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown19 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label30 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown21 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label29 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown22 = (gcnew System::Windows::Forms::NumericUpDown());
			this->label28 = (gcnew System::Windows::Forms::Label());
			this->tabPage8 = (gcnew System::Windows::Forms::TabPage());
			this->groupBox13 = (gcnew System::Windows::Forms::GroupBox());
			this->textBox17 = (gcnew System::Windows::Forms::TextBox());
			this->checkBox19 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox18 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox17 = (gcnew System::Windows::Forms::CheckBox());
			this->groupBox11 = (gcnew System::Windows::Forms::GroupBox());
			this->button7 = (gcnew System::Windows::Forms::Button());
			this->button8 = (gcnew System::Windows::Forms::Button());
			this->button9 = (gcnew System::Windows::Forms::Button());
			this->label55 = (gcnew System::Windows::Forms::Label());
			this->label53 = (gcnew System::Windows::Forms::Label());
			this->label54 = (gcnew System::Windows::Forms::Label());
			this->groupBox6 = (gcnew System::Windows::Forms::GroupBox());
			this->label75 = (gcnew System::Windows::Forms::Label());
			this->label74 = (gcnew System::Windows::Forms::Label());
			this->label73 = (gcnew System::Windows::Forms::Label());
			this->label72 = (gcnew System::Windows::Forms::Label());
			this->label71 = (gcnew System::Windows::Forms::Label());
			this->textBox16 = (gcnew System::Windows::Forms::TextBox());
			this->textBox15 = (gcnew System::Windows::Forms::TextBox());
			this->textBox14 = (gcnew System::Windows::Forms::TextBox());
			this->textBox13 = (gcnew System::Windows::Forms::TextBox());
			this->textBox12 = (gcnew System::Windows::Forms::TextBox());
			this->groupBox3 = (gcnew System::Windows::Forms::GroupBox());
			this->label83 = (gcnew System::Windows::Forms::Label());
			this->label84 = (gcnew System::Windows::Forms::Label());
			this->checkBox10 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox9 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox2 = (gcnew System::Windows::Forms::CheckBox());
			this->label42 = (gcnew System::Windows::Forms::Label());
			this->label43 = (gcnew System::Windows::Forms::Label());
			this->label44 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown29 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown30 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown31 = (gcnew System::Windows::Forms::NumericUpDown());
			this->groupBox2 = (gcnew System::Windows::Forms::GroupBox());
			this->label52 = (gcnew System::Windows::Forms::Label());
			this->label82 = (gcnew System::Windows::Forms::Label());
			this->checkBox13 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox12 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox11 = (gcnew System::Windows::Forms::CheckBox());
			this->label39 = (gcnew System::Windows::Forms::Label());
			this->label40 = (gcnew System::Windows::Forms::Label());
			this->label41 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown26 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown27 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown28 = (gcnew System::Windows::Forms::NumericUpDown());
			this->groupBox1 = (gcnew System::Windows::Forms::GroupBox());
			this->label51 = (gcnew System::Windows::Forms::Label());
			this->label1 = (gcnew System::Windows::Forms::Label());
			this->checkBox16 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox15 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox14 = (gcnew System::Windows::Forms::CheckBox());
			this->label38 = (gcnew System::Windows::Forms::Label());
			this->label37 = (gcnew System::Windows::Forms::Label());
			this->label36 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown25 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown24 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown23 = (gcnew System::Windows::Forms::NumericUpDown());
			this->tabPage15 = (gcnew System::Windows::Forms::TabPage());
			this->richTextBox4 = (gcnew System::Windows::Forms::RichTextBox());
			this->richTextBox3 = (gcnew System::Windows::Forms::RichTextBox());
			this->button16 = (gcnew System::Windows::Forms::Button());
			this->tabPage10 = (gcnew System::Windows::Forms::TabPage());
			this->richTextBox2 = (gcnew System::Windows::Forms::RichTextBox());
			this->tabPage11 = (gcnew System::Windows::Forms::TabPage());
			this->label81 = (gcnew System::Windows::Forms::Label());
			this->label80 = (gcnew System::Windows::Forms::Label());
			this->label79 = (gcnew System::Windows::Forms::Label());
			this->trackBar10 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar9 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar8 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar7 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar6 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar5 = (gcnew System::Windows::Forms::TrackBar());
			this->label50 = (gcnew System::Windows::Forms::Label());
			this->label49 = (gcnew System::Windows::Forms::Label());
			this->label48 = (gcnew System::Windows::Forms::Label());
			this->trackBar4 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar3 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar2 = (gcnew System::Windows::Forms::TrackBar());
			this->trackBar1 = (gcnew System::Windows::Forms::TrackBar());
			this->pictureBox1 = (gcnew System::Windows::Forms::PictureBox());
			this->tabPage13 = (gcnew System::Windows::Forms::TabPage());
			this->label77 = (gcnew System::Windows::Forms::Label());
			this->label76 = (gcnew System::Windows::Forms::Label());
			this->label70 = (gcnew System::Windows::Forms::Label());
			this->label69 = (gcnew System::Windows::Forms::Label());
			this->label68 = (gcnew System::Windows::Forms::Label());
			this->label67 = (gcnew System::Windows::Forms::Label());
			this->label66 = (gcnew System::Windows::Forms::Label());
			this->label65 = (gcnew System::Windows::Forms::Label());
			this->label64 = (gcnew System::Windows::Forms::Label());
			this->label63 = (gcnew System::Windows::Forms::Label());
			this->label62 = (gcnew System::Windows::Forms::Label());
			this->label61 = (gcnew System::Windows::Forms::Label());
			this->label60 = (gcnew System::Windows::Forms::Label());
			this->pictureBox2 = (gcnew System::Windows::Forms::PictureBox());
			this->tabPage12 = (gcnew System::Windows::Forms::TabPage());
			this->pictureBox4 = (gcnew System::Windows::Forms::PictureBox());
			this->button13 = (gcnew System::Windows::Forms::Button());
			this->label58 = (gcnew System::Windows::Forms::Label());
			this->label57 = (gcnew System::Windows::Forms::Label());
			this->label56 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown33 = (gcnew System::Windows::Forms::NumericUpDown());
			this->textBox10 = (gcnew System::Windows::Forms::TextBox());
			this->textBox9 = (gcnew System::Windows::Forms::TextBox());
			this->textBox8 = (gcnew System::Windows::Forms::TextBox());
			this->button12 = (gcnew System::Windows::Forms::Button());
			this->button11 = (gcnew System::Windows::Forms::Button());
			this->button10 = (gcnew System::Windows::Forms::Button());
			this->tabPage14 = (gcnew System::Windows::Forms::TabPage());
			this->splitContainer1 = (gcnew System::Windows::Forms::SplitContainer());
			this->chart1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Chart());
			this->listBox36 = (gcnew System::Windows::Forms::ListBox());
			this->listBox35 = (gcnew System::Windows::Forms::ListBox());
			this->listBox34 = (gcnew System::Windows::Forms::ListBox());
			this->listBox32 = (gcnew System::Windows::Forms::ListBox());
			this->listBox33 = (gcnew System::Windows::Forms::ListBox());
			this->listBox29 = (gcnew System::Windows::Forms::ListBox());
			this->listBox30 = (gcnew System::Windows::Forms::ListBox());
			this->listBox31 = (gcnew System::Windows::Forms::ListBox());
			this->listBox22 = (gcnew System::Windows::Forms::ListBox());
			this->listBox23 = (gcnew System::Windows::Forms::ListBox());
			this->listBox24 = (gcnew System::Windows::Forms::ListBox());
			this->listBox25 = (gcnew System::Windows::Forms::ListBox());
			this->listBox26 = (gcnew System::Windows::Forms::ListBox());
			this->listBox27 = (gcnew System::Windows::Forms::ListBox());
			this->listBox28 = (gcnew System::Windows::Forms::ListBox());
			this->listBox15 = (gcnew System::Windows::Forms::ListBox());
			this->listBox16 = (gcnew System::Windows::Forms::ListBox());
			this->listBox17 = (gcnew System::Windows::Forms::ListBox());
			this->listBox18 = (gcnew System::Windows::Forms::ListBox());
			this->listBox19 = (gcnew System::Windows::Forms::ListBox());
			this->listBox20 = (gcnew System::Windows::Forms::ListBox());
			this->listBox21 = (gcnew System::Windows::Forms::ListBox());
			this->listBox8 = (gcnew System::Windows::Forms::ListBox());
			this->listBox9 = (gcnew System::Windows::Forms::ListBox());
			this->listBox10 = (gcnew System::Windows::Forms::ListBox());
			this->listBox11 = (gcnew System::Windows::Forms::ListBox());
			this->listBox12 = (gcnew System::Windows::Forms::ListBox());
			this->listBox13 = (gcnew System::Windows::Forms::ListBox());
			this->listBox14 = (gcnew System::Windows::Forms::ListBox());
			this->listBox7 = (gcnew System::Windows::Forms::ListBox());
			this->listBox6 = (gcnew System::Windows::Forms::ListBox());
			this->listBox5 = (gcnew System::Windows::Forms::ListBox());
			this->listBox4 = (gcnew System::Windows::Forms::ListBox());
			this->listBox3 = (gcnew System::Windows::Forms::ListBox());
			this->listBox2 = (gcnew System::Windows::Forms::ListBox());
			this->listBox1 = (gcnew System::Windows::Forms::ListBox());
			this->checkedListBox1 = (gcnew System::Windows::Forms::CheckedListBox());
			this->tabPage9 = (gcnew System::Windows::Forms::TabPage());
			this->pictureBox3 = (gcnew System::Windows::Forms::PictureBox());
			this->label33 = (gcnew System::Windows::Forms::Label());
			this->label32 = (gcnew System::Windows::Forms::Label());
			this->label14 = (gcnew System::Windows::Forms::Label());
			this->serialPort1 = (gcnew System::IO::Ports::SerialPort(this->components));
			this->saveFileDialog1 = (gcnew System::Windows::Forms::SaveFileDialog());
			this->openFileDialog1 = (gcnew System::Windows::Forms::OpenFileDialog());
			this->statusStrip1 = (gcnew System::Windows::Forms::StatusStrip());
			this->toolStripSplitButton1 = (gcnew System::Windows::Forms::ToolStripSplitButton());
			this->toolStripStatusLabel2 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel3 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel4 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel5 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel6 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel7 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->toolStripStatusLabel8 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
			this->groupBox14 = (gcnew System::Windows::Forms::GroupBox());
			this->label87 = (gcnew System::Windows::Forms::Label());
			this->label88 = (gcnew System::Windows::Forms::Label());
			this->checkBox21 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox22 = (gcnew System::Windows::Forms::CheckBox());
			this->checkBox23 = (gcnew System::Windows::Forms::CheckBox());
			this->label89 = (gcnew System::Windows::Forms::Label());
			this->label90 = (gcnew System::Windows::Forms::Label());
			this->label91 = (gcnew System::Windows::Forms::Label());
			this->numericUpDown32 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown34 = (gcnew System::Windows::Forms::NumericUpDown());
			this->numericUpDown35 = (gcnew System::Windows::Forms::NumericUpDown());
			this->tabControl1->SuspendLayout();
			this->tabPage1->SuspendLayout();
			this->groupBox12->SuspendLayout();
			this->groupBox4->SuspendLayout();
			this->groupBox5->SuspendLayout();
			this->tabPage2->SuspendLayout();
			this->tabPage3->SuspendLayout();
			this->groupBox7->SuspendLayout();
			this->tabPage4->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar18))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar17))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar16))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar15))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar14))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar13))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar12))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar11))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown12))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown11))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown10))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown9))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown8))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown7))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown6))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown5))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown4))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown3))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown2))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown1))->BeginInit();
			this->tabPage5->SuspendLayout();
			this->tabPage6->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown14))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown13))->BeginInit();
			this->groupBox8->SuspendLayout();
			this->tabPage7->SuspendLayout();
			this->groupBox10->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown15))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown16))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown17))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown18))->BeginInit();
			this->groupBox9->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown20))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown19))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown21))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown22))->BeginInit();
			this->tabPage8->SuspendLayout();
			this->groupBox13->SuspendLayout();
			this->groupBox11->SuspendLayout();
			this->groupBox6->SuspendLayout();
			this->groupBox3->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown29))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown30))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown31))->BeginInit();
			this->groupBox2->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown26))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown27))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown28))->BeginInit();
			this->groupBox1->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown25))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown24))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown23))->BeginInit();
			this->tabPage15->SuspendLayout();
			this->tabPage10->SuspendLayout();
			this->tabPage11->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar10))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar9))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar8))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar7))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar6))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar5))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar4))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar3))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar2))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar1))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox1))->BeginInit();
			this->tabPage13->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox2))->BeginInit();
			this->tabPage12->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox4))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown33))->BeginInit();
			this->tabPage14->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->splitContainer1))->BeginInit();
			this->splitContainer1->Panel1->SuspendLayout();
			this->splitContainer1->Panel2->SuspendLayout();
			this->splitContainer1->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->chart1))->BeginInit();
			this->tabPage9->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox3))->BeginInit();
			this->statusStrip1->SuspendLayout();
			this->groupBox14->SuspendLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown32))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown34))->BeginInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown35))->BeginInit();
			this->SuspendLayout();
			// 
			// tabControl1
			// 
			this->tabControl1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom) 
				| System::Windows::Forms::AnchorStyles::Left) 
				| System::Windows::Forms::AnchorStyles::Right));
			this->tabControl1->Controls->Add(this->tabPage1);
			this->tabControl1->Controls->Add(this->tabPage2);
			this->tabControl1->Controls->Add(this->tabPage3);
			this->tabControl1->Controls->Add(this->tabPage4);
			this->tabControl1->Controls->Add(this->tabPage5);
			this->tabControl1->Controls->Add(this->tabPage6);
			this->tabControl1->Controls->Add(this->tabPage7);
			this->tabControl1->Controls->Add(this->tabPage8);
			this->tabControl1->Controls->Add(this->tabPage15);
			this->tabControl1->Controls->Add(this->tabPage10);
			this->tabControl1->Controls->Add(this->tabPage11);
			this->tabControl1->Controls->Add(this->tabPage13);
			this->tabControl1->Controls->Add(this->tabPage12);
			this->tabControl1->Controls->Add(this->tabPage14);
			this->tabControl1->Controls->Add(this->tabPage9);
			this->tabControl1->Location = System::Drawing::Point(0, 0);
			this->tabControl1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabControl1->Name = L"tabControl1";
			this->tabControl1->SelectedIndex = 0;
			this->tabControl1->Size = System::Drawing::Size(1093, 635);
			this->tabControl1->TabIndex = 0;
			this->tabControl1->Selected += gcnew System::Windows::Forms::TabControlEventHandler(this, &Form1::tabControl1_Selected);
			this->tabControl1->Deselected += gcnew System::Windows::Forms::TabControlEventHandler(this, &Form1::tabControl1_Deselected);
			// 
			// tabPage1
			// 
			this->tabPage1->Controls->Add(this->label86);
			this->tabPage1->Controls->Add(this->groupBox12);
			this->tabPage1->Controls->Add(this->groupBox4);
			this->tabPage1->Controls->Add(this->groupBox5);
			this->tabPage1->Location = System::Drawing::Point(4, 22);
			this->tabPage1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage1->Name = L"tabPage1";
			this->tabPage1->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage1->Size = System::Drawing::Size(1085, 609);
			this->tabPage1->TabIndex = 0;
			this->tabPage1->Text = L"Serial Port";
			this->tabPage1->UseVisualStyleBackColor = true;
			// 
			// label86
			// 
			this->label86->AutoSize = true;
			this->label86->Location = System::Drawing::Point(310, 152);
			this->label86->Name = L"label86";
			this->label86->Size = System::Drawing::Size(41, 13);
			this->label86->TabIndex = 10;
			this->label86->Text = L"label86";
			// 
			// groupBox12
			// 
			this->groupBox12->Controls->Add(this->comboBox1);
			this->groupBox12->Controls->Add(this->checkBox34);
			this->groupBox12->Controls->Add(this->button1);
			this->groupBox12->Location = System::Drawing::Point(42, 23);
			this->groupBox12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox12->Name = L"groupBox12";
			this->groupBox12->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox12->Size = System::Drawing::Size(144, 142);
			this->groupBox12->TabIndex = 9;
			this->groupBox12->TabStop = false;
			this->groupBox12->Text = L"Serial Port";
			// 
			// comboBox1
			// 
			this->comboBox1->FormattingEnabled = true;
			this->comboBox1->Location = System::Drawing::Point(11, 21);
			this->comboBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->comboBox1->Name = L"comboBox1";
			this->comboBox1->Size = System::Drawing::Size(120, 21);
			this->comboBox1->TabIndex = 0;
			this->comboBox1->DropDown += gcnew System::EventHandler(this, &Form1::comboBox1_DropDown);
			this->comboBox1->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::comboBox1_SelectedIndexChanged);
			// 
			// checkBox34
			// 
			this->checkBox34->AutoSize = true;
			this->checkBox34->Location = System::Drawing::Point(11, 105);
			this->checkBox34->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox34->Name = L"checkBox34";
			this->checkBox34->Size = System::Drawing::Size(78, 17);
			this->checkBox34->TabIndex = 6;
			this->checkBox34->Text = L"Raw Mode";
			this->checkBox34->UseVisualStyleBackColor = true;
			this->checkBox34->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox34_CheckedChanged);
			// 
			// button1
			// 
			this->button1->Location = System::Drawing::Point(11, 60);
			this->button1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button1->Name = L"button1";
			this->button1->Size = System::Drawing::Size(74, 23);
			this->button1->TabIndex = 2;
			this->button1->Text = L"Connect";
			this->button1->UseVisualStyleBackColor = true;
			this->button1->Click += gcnew System::EventHandler(this, &Form1::button1_Click);
			// 
			// groupBox4
			// 
			this->groupBox4->Controls->Add(this->button5);
			this->groupBox4->Controls->Add(this->button4);
			this->groupBox4->Controls->Add(this->button3);
			this->groupBox4->Controls->Add(this->button2);
			this->groupBox4->Location = System::Drawing::Point(542, 23);
			this->groupBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox4->Name = L"groupBox4";
			this->groupBox4->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox4->Size = System::Drawing::Size(95, 142);
			this->groupBox4->TabIndex = 4;
			this->groupBox4->TabStop = false;
			this->groupBox4->Text = L"eeprom";
			// 
			// button5
			// 
			this->button5->Location = System::Drawing::Point(7, 109);
			this->button5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button5->Name = L"button5";
			this->button5->Size = System::Drawing::Size(74, 23);
			this->button5->TabIndex = 6;
			this->button5->Text = L"Reboot";
			this->button5->UseVisualStyleBackColor = true;
			this->button5->Click += gcnew System::EventHandler(this, &Form1::button5_Click);
			// 
			// button4
			// 
			this->button4->Location = System::Drawing::Point(7, 79);
			this->button4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button4->Name = L"button4";
			this->button4->Size = System::Drawing::Size(74, 23);
			this->button4->TabIndex = 5;
			this->button4->Text = L"Default";
			this->button4->UseVisualStyleBackColor = true;
			this->button4->Click += gcnew System::EventHandler(this, &Form1::button4_Click);
			// 
			// button3
			// 
			this->button3->Location = System::Drawing::Point(7, 49);
			this->button3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button3->Name = L"button3";
			this->button3->Size = System::Drawing::Size(74, 23);
			this->button3->TabIndex = 4;
			this->button3->Text = L"Save";
			this->button3->UseVisualStyleBackColor = true;
			this->button3->Click += gcnew System::EventHandler(this, &Form1::button3_Click);
			// 
			// button2
			// 
			this->button2->Location = System::Drawing::Point(6, 21);
			this->button2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button2->Name = L"button2";
			this->button2->Size = System::Drawing::Size(74, 23);
			this->button2->TabIndex = 3;
			this->button2->Text = L"Load";
			this->button2->UseVisualStyleBackColor = true;
			this->button2->Click += gcnew System::EventHandler(this, &Form1::button2_Click);
			// 
			// groupBox5
			// 
			this->groupBox5->Controls->Add(this->button15);
			this->groupBox5->Controls->Add(this->button6);
			this->groupBox5->Controls->Add(this->button14);
			this->groupBox5->Location = System::Drawing::Point(310, 23);
			this->groupBox5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox5->Name = L"groupBox5";
			this->groupBox5->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox5->Size = System::Drawing::Size(104, 122);
			this->groupBox5->TabIndex = 8;
			this->groupBox5->TabStop = false;
			this->groupBox5->Text = L"LogFiles";
			// 
			// button15
			// 
			this->button15->Location = System::Drawing::Point(12, 81);
			this->button15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button15->Name = L"button15";
			this->button15->Size = System::Drawing::Size(74, 23);
			this->button15->TabIndex = 8;
			this->button15->Text = L"Clear plot";
			this->button15->UseVisualStyleBackColor = true;
			this->button15->Click += gcnew System::EventHandler(this, &Form1::button15_Click);
			// 
			// button6
			// 
			this->button6->Location = System::Drawing::Point(12, 21);
			this->button6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button6->Name = L"button6";
			this->button6->Size = System::Drawing::Size(74, 23);
			this->button6->TabIndex = 5;
			this->button6->Text = L"Capture";
			this->button6->UseVisualStyleBackColor = true;
			this->button6->Click += gcnew System::EventHandler(this, &Form1::button6_Click);
			// 
			// button14
			// 
			this->button14->Location = System::Drawing::Point(12, 52);
			this->button14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button14->Name = L"button14";
			this->button14->Size = System::Drawing::Size(74, 23);
			this->button14->TabIndex = 7;
			this->button14->Text = L"Open";
			this->button14->UseVisualStyleBackColor = true;
			this->button14->Click += gcnew System::EventHandler(this, &Form1::button14_Click);
			// 
			// tabPage2
			// 
			this->tabPage2->Controls->Add(this->richTextBox1);
			this->tabPage2->Location = System::Drawing::Point(4, 22);
			this->tabPage2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage2->Name = L"tabPage2";
			this->tabPage2->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage2->Size = System::Drawing::Size(1085, 609);
			this->tabPage2->TabIndex = 1;
			this->tabPage2->Text = L"Console";
			this->tabPage2->UseVisualStyleBackColor = true;
			// 
			// richTextBox1
			// 
			this->richTextBox1->BackColor = System::Drawing::SystemColors::InactiveCaption;
			this->richTextBox1->Dock = System::Windows::Forms::DockStyle::Fill;
			this->richTextBox1->Font = (gcnew System::Drawing::Font(L"Parallax", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->richTextBox1->Location = System::Drawing::Point(2, 3);
			this->richTextBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->richTextBox1->Name = L"richTextBox1";
			this->richTextBox1->Size = System::Drawing::Size(1081, 603);
			this->richTextBox1->TabIndex = 0;
			this->richTextBox1->Text = L"";
			// 
			// tabPage3
			// 
			this->tabPage3->Controls->Add(this->label85);
			this->tabPage3->Controls->Add(this->label78);
			this->tabPage3->Controls->Add(this->checkBox3);
			this->tabPage3->Controls->Add(this->checkBox1);
			this->tabPage3->Controls->Add(this->groupBox7);
			this->tabPage3->Location = System::Drawing::Point(4, 22);
			this->tabPage3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage3->Name = L"tabPage3";
			this->tabPage3->Size = System::Drawing::Size(1085, 609);
			this->tabPage3->TabIndex = 2;
			this->tabPage3->Text = L"Diagnostics";
			this->tabPage3->UseVisualStyleBackColor = true;
			this->tabPage3->Click += gcnew System::EventHandler(this, &Form1::tabPage3_Click);
			// 
			// label85
			// 
			this->label85->AutoSize = true;
			this->label85->Location = System::Drawing::Point(21, 72);
			this->label85->Name = L"label85";
			this->label85->Size = System::Drawing::Size(97, 13);
			this->label85->TabIndex = 18;
			this->label85->Text = L"Quad Clock Speed";
			// 
			// label78
			// 
			this->label78->AutoSize = true;
			this->label78->Location = System::Drawing::Point(124, 72);
			this->label78->Name = L"label78";
			this->label78->Size = System::Drawing::Size(41, 13);
			this->label78->TabIndex = 17;
			this->label78->Text = L"label78";
			// 
			// checkBox3
			// 
			this->checkBox3->AutoSize = true;
			this->checkBox3->Location = System::Drawing::Point(24, 52);
			this->checkBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox3->Name = L"checkBox3";
			this->checkBox3->Size = System::Drawing::Size(76, 17);
			this->checkBox3->TabIndex = 9;
			this->checkBox3->Text = L"LED invert";
			this->checkBox3->UseVisualStyleBackColor = true;
			this->checkBox3->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox3_CheckedChanged);
			// 
			// checkBox1
			// 
			this->checkBox1->AutoSize = true;
			this->checkBox1->Location = System::Drawing::Point(24, 29);
			this->checkBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox1->Name = L"checkBox1";
			this->checkBox1->Size = System::Drawing::Size(70, 17);
			this->checkBox1->TabIndex = 7;
			this->checkBox1->Text = L"I2C Scan";
			this->checkBox1->UseVisualStyleBackColor = true;
			this->checkBox1->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox1_CheckedChanged);
			// 
			// groupBox7
			// 
			this->groupBox7->Controls->Add(this->label46);
			this->groupBox7->Controls->Add(this->label47);
			this->groupBox7->Controls->Add(this->textBox1);
			this->groupBox7->Controls->Add(this->label3);
			this->groupBox7->Controls->Add(this->label2);
			this->groupBox7->Controls->Add(this->textBox2);
			this->groupBox7->Location = System::Drawing::Point(278, 29);
			this->groupBox7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox7->Name = L"groupBox7";
			this->groupBox7->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox7->Size = System::Drawing::Size(278, 117);
			this->groupBox7->TabIndex = 16;
			this->groupBox7->TabStop = false;
			this->groupBox7->Text = L"Battery";
			// 
			// label46
			// 
			this->label46->AutoSize = true;
			this->label46->Location = System::Drawing::Point(17, 86);
			this->label46->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label46->Name = L"label46";
			this->label46->Size = System::Drawing::Size(27, 13);
			this->label46->TabIndex = 14;
			this->label46->Text = L"N/A";
			// 
			// label47
			// 
			this->label47->AutoSize = true;
			this->label47->Location = System::Drawing::Point(132, 86);
			this->label47->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label47->Name = L"label47";
			this->label47->Size = System::Drawing::Size(114, 13);
			this->label47->TabIndex = 15;
			this->label47->Text = L"Current battery voltage";
			// 
			// textBox1
			// 
			this->textBox1->AcceptsReturn = true;
			this->textBox1->Location = System::Drawing::Point(17, 21);
			this->textBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox1->Name = L"textBox1";
			this->textBox1->Size = System::Drawing::Size(100, 20);
			this->textBox1->TabIndex = 10;
			this->textBox1->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox1_KeyUp);
			this->textBox1->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox1_Validating);
			this->textBox1->Validated += gcnew System::EventHandler(this, &Form1::textBox1_Validated);
			// 
			// label3
			// 
			this->label3->AutoSize = true;
			this->label3->Location = System::Drawing::Point(132, 21);
			this->label3->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label3->Name = L"label3";
			this->label3->Size = System::Drawing::Size(84, 13);
			this->label3->TabIndex = 11;
			this->label3->Text = L"Battery Multiplier";
			// 
			// label2
			// 
			this->label2->AutoSize = true;
			this->label2->Location = System::Drawing::Point(132, 52);
			this->label2->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label2->Name = L"label2";
			this->label2->Size = System::Drawing::Size(105, 13);
			this->label2->TabIndex = 13;
			this->label2->Text = L"Battery warning level";
			// 
			// textBox2
			// 
			this->textBox2->AcceptsReturn = true;
			this->textBox2->Location = System::Drawing::Point(17, 52);
			this->textBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox2->Name = L"textBox2";
			this->textBox2->Size = System::Drawing::Size(100, 20);
			this->textBox2->TabIndex = 12;
			this->textBox2->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox2_KeyUp);
			this->textBox2->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox2_Validating);
			this->textBox2->Validated += gcnew System::EventHandler(this, &Form1::textBox2_Validated);
			// 
			// tabPage4
			// 
			this->tabPage4->Controls->Add(this->trackBar18);
			this->tabPage4->Controls->Add(this->trackBar17);
			this->tabPage4->Controls->Add(this->trackBar16);
			this->tabPage4->Controls->Add(this->trackBar15);
			this->tabPage4->Controls->Add(this->trackBar14);
			this->tabPage4->Controls->Add(this->trackBar13);
			this->tabPage4->Controls->Add(this->trackBar12);
			this->tabPage4->Controls->Add(this->trackBar11);
			this->tabPage4->Controls->Add(this->label35);
			this->tabPage4->Controls->Add(this->label34);
			this->tabPage4->Controls->Add(this->numericUpDown12);
			this->tabPage4->Controls->Add(this->numericUpDown11);
			this->tabPage4->Controls->Add(this->label12);
			this->tabPage4->Controls->Add(this->label11);
			this->tabPage4->Controls->Add(this->label10);
			this->tabPage4->Controls->Add(this->label9);
			this->tabPage4->Controls->Add(this->label8);
			this->tabPage4->Controls->Add(this->label7);
			this->tabPage4->Controls->Add(this->numericUpDown10);
			this->tabPage4->Controls->Add(this->numericUpDown9);
			this->tabPage4->Controls->Add(this->numericUpDown8);
			this->tabPage4->Controls->Add(this->numericUpDown7);
			this->tabPage4->Controls->Add(this->numericUpDown6);
			this->tabPage4->Controls->Add(this->numericUpDown5);
			this->tabPage4->Controls->Add(this->label6);
			this->tabPage4->Controls->Add(this->numericUpDown4);
			this->tabPage4->Controls->Add(this->label5);
			this->tabPage4->Controls->Add(this->numericUpDown3);
			this->tabPage4->Controls->Add(this->label4);
			this->tabPage4->Controls->Add(this->numericUpDown2);
			this->tabPage4->Controls->Add(this->label13);
			this->tabPage4->Controls->Add(this->numericUpDown1);
			this->tabPage4->Controls->Add(this->checkBox4);
			this->tabPage4->Location = System::Drawing::Point(4, 22);
			this->tabPage4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage4->Name = L"tabPage4";
			this->tabPage4->Size = System::Drawing::Size(1085, 609);
			this->tabPage4->TabIndex = 3;
			this->tabPage4->Text = L"RC Receiver";
			this->tabPage4->UseVisualStyleBackColor = true;
			// 
			// trackBar18
			// 
			this->trackBar18->AutoSize = false;
			this->trackBar18->Enabled = false;
			this->trackBar18->Location = System::Drawing::Point(662, 237);
			this->trackBar18->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar18->Maximum = 2000;
			this->trackBar18->Minimum = 1000;
			this->trackBar18->Name = L"trackBar18";
			this->trackBar18->Size = System::Drawing::Size(157, 21);
			this->trackBar18->TabIndex = 57;
			this->trackBar18->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar18->Value = 1500;
			// 
			// trackBar17
			// 
			this->trackBar17->AutoSize = false;
			this->trackBar17->Enabled = false;
			this->trackBar17->Location = System::Drawing::Point(662, 211);
			this->trackBar17->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar17->Maximum = 2000;
			this->trackBar17->Minimum = 1000;
			this->trackBar17->Name = L"trackBar17";
			this->trackBar17->Size = System::Drawing::Size(157, 21);
			this->trackBar17->TabIndex = 56;
			this->trackBar17->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar17->Value = 1500;
			// 
			// trackBar16
			// 
			this->trackBar16->AutoSize = false;
			this->trackBar16->Enabled = false;
			this->trackBar16->Location = System::Drawing::Point(662, 183);
			this->trackBar16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar16->Maximum = 2000;
			this->trackBar16->Minimum = 1000;
			this->trackBar16->Name = L"trackBar16";
			this->trackBar16->Size = System::Drawing::Size(157, 21);
			this->trackBar16->TabIndex = 55;
			this->trackBar16->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar16->Value = 1500;
			// 
			// trackBar15
			// 
			this->trackBar15->AutoSize = false;
			this->trackBar15->Enabled = false;
			this->trackBar15->Location = System::Drawing::Point(662, 157);
			this->trackBar15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar15->Maximum = 2000;
			this->trackBar15->Minimum = 1000;
			this->trackBar15->Name = L"trackBar15";
			this->trackBar15->Size = System::Drawing::Size(157, 21);
			this->trackBar15->TabIndex = 54;
			this->trackBar15->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar15->Value = 1500;
			// 
			// trackBar14
			// 
			this->trackBar14->AutoSize = false;
			this->trackBar14->Enabled = false;
			this->trackBar14->Location = System::Drawing::Point(662, 127);
			this->trackBar14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar14->Maximum = 2000;
			this->trackBar14->Minimum = 1000;
			this->trackBar14->Name = L"trackBar14";
			this->trackBar14->Size = System::Drawing::Size(157, 21);
			this->trackBar14->TabIndex = 53;
			this->trackBar14->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar14->Value = 1500;
			// 
			// trackBar13
			// 
			this->trackBar13->AutoSize = false;
			this->trackBar13->Enabled = false;
			this->trackBar13->Location = System::Drawing::Point(662, 101);
			this->trackBar13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar13->Maximum = 2000;
			this->trackBar13->Minimum = 1000;
			this->trackBar13->Name = L"trackBar13";
			this->trackBar13->Size = System::Drawing::Size(157, 21);
			this->trackBar13->TabIndex = 52;
			this->trackBar13->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar13->Value = 1500;
			// 
			// trackBar12
			// 
			this->trackBar12->AutoSize = false;
			this->trackBar12->Enabled = false;
			this->trackBar12->Location = System::Drawing::Point(662, 75);
			this->trackBar12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar12->Maximum = 2000;
			this->trackBar12->Minimum = 1000;
			this->trackBar12->Name = L"trackBar12";
			this->trackBar12->Size = System::Drawing::Size(157, 21);
			this->trackBar12->TabIndex = 51;
			this->trackBar12->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar12->Value = 1500;
			// 
			// trackBar11
			// 
			this->trackBar11->AutoSize = false;
			this->trackBar11->Enabled = false;
			this->trackBar11->Location = System::Drawing::Point(662, 47);
			this->trackBar11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar11->Maximum = 2000;
			this->trackBar11->Minimum = 1000;
			this->trackBar11->Name = L"trackBar11";
			this->trackBar11->RightToLeft = System::Windows::Forms::RightToLeft::No;
			this->trackBar11->Size = System::Drawing::Size(157, 21);
			this->trackBar11->TabIndex = 50;
			this->trackBar11->TickStyle = System::Windows::Forms::TickStyle::None;
			this->trackBar11->Value = 1500;
			// 
			// label35
			// 
			this->label35->AutoSize = true;
			this->label35->Location = System::Drawing::Point(505, 239);
			this->label35->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label35->Name = L"label35";
			this->label35->Size = System::Drawing::Size(104, 13);
			this->label35->TabIndex = 47;
			this->label35->Text = L"IMU On/Off channel";
			// 
			// label34
			// 
			this->label34->AutoSize = true;
			this->label34->Location = System::Drawing::Point(505, 212);
			this->label34->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label34->Name = L"label34";
			this->label34->Size = System::Drawing::Size(108, 13);
			this->label34->TabIndex = 46;
			this->label34->Text = L"Alititude hold channel";
			// 
			// numericUpDown12
			// 
			this->numericUpDown12->Location = System::Drawing::Point(368, 237);
			this->numericUpDown12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown12->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown12->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown12->Name = L"numericUpDown12";
			this->numericUpDown12->Size = System::Drawing::Size(120, 20);
			this->numericUpDown12->TabIndex = 45;
			this->numericUpDown12->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown12->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown12_ValueChanged);
			// 
			// numericUpDown11
			// 
			this->numericUpDown11->Location = System::Drawing::Point(368, 211);
			this->numericUpDown11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown11->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown11->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown11->Name = L"numericUpDown11";
			this->numericUpDown11->Size = System::Drawing::Size(120, 20);
			this->numericUpDown11->TabIndex = 44;
			this->numericUpDown11->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown11->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown11_ValueChanged);
			// 
			// label12
			// 
			this->label12->AutoSize = true;
			this->label12->Location = System::Drawing::Point(505, 185);
			this->label12->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label12->Name = L"label12";
			this->label12->Size = System::Drawing::Size(102, 13);
			this->label12->TabIndex = 43;
			this->label12->Text = L"Camera Tilt Channel";
			// 
			// label11
			// 
			this->label11->AutoSize = true;
			this->label11->Location = System::Drawing::Point(505, 159);
			this->label11->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label11->Name = L"label11";
			this->label11->Size = System::Drawing::Size(107, 13);
			this->label11->TabIndex = 42;
			this->label11->Text = L"Camera Pan Channel";
			// 
			// label10
			// 
			this->label10->AutoSize = true;
			this->label10->Location = System::Drawing::Point(505, 130);
			this->label10->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label10->Name = L"label10";
			this->label10->Size = System::Drawing::Size(70, 13);
			this->label10->TabIndex = 41;
			this->label10->Text = L"Yaw Channel";
			// 
			// label9
			// 
			this->label9->AutoSize = true;
			this->label9->Location = System::Drawing::Point(505, 104);
			this->label9->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label9->Name = L"label9";
			this->label9->Size = System::Drawing::Size(85, 13);
			this->label9->TabIndex = 40;
			this->label9->Text = L"Throttle Channel";
			// 
			// label8
			// 
			this->label8->AutoSize = true;
			this->label8->Location = System::Drawing::Point(505, 78);
			this->label8->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label8->Name = L"label8";
			this->label8->Size = System::Drawing::Size(67, 13);
			this->label8->TabIndex = 39;
			this->label8->Text = L"Roll Channel";
			// 
			// label7
			// 
			this->label7->AutoSize = true;
			this->label7->Location = System::Drawing::Point(505, 52);
			this->label7->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label7->Name = L"label7";
			this->label7->Size = System::Drawing::Size(73, 13);
			this->label7->TabIndex = 38;
			this->label7->Text = L"Pitch Channel";
			// 
			// numericUpDown10
			// 
			this->numericUpDown10->Location = System::Drawing::Point(368, 183);
			this->numericUpDown10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown10->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown10->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown10->Name = L"numericUpDown10";
			this->numericUpDown10->Size = System::Drawing::Size(120, 20);
			this->numericUpDown10->TabIndex = 37;
			this->numericUpDown10->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown10->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown10_ValueChanged);
			// 
			// numericUpDown9
			// 
			this->numericUpDown9->Location = System::Drawing::Point(368, 157);
			this->numericUpDown9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown9->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown9->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown9->Name = L"numericUpDown9";
			this->numericUpDown9->Size = System::Drawing::Size(120, 20);
			this->numericUpDown9->TabIndex = 36;
			this->numericUpDown9->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown9->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown9_ValueChanged);
			// 
			// numericUpDown8
			// 
			this->numericUpDown8->Location = System::Drawing::Point(368, 127);
			this->numericUpDown8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown8->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown8->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown8->Name = L"numericUpDown8";
			this->numericUpDown8->Size = System::Drawing::Size(120, 20);
			this->numericUpDown8->TabIndex = 35;
			this->numericUpDown8->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown8->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown8_ValueChanged);
			// 
			// numericUpDown7
			// 
			this->numericUpDown7->Location = System::Drawing::Point(368, 101);
			this->numericUpDown7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown7->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown7->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown7->Name = L"numericUpDown7";
			this->numericUpDown7->Size = System::Drawing::Size(120, 20);
			this->numericUpDown7->TabIndex = 34;
			this->numericUpDown7->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown7->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown7_ValueChanged);
			// 
			// numericUpDown6
			// 
			this->numericUpDown6->Location = System::Drawing::Point(368, 75);
			this->numericUpDown6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown6->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown6->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown6->Name = L"numericUpDown6";
			this->numericUpDown6->Size = System::Drawing::Size(120, 20);
			this->numericUpDown6->TabIndex = 33;
			this->numericUpDown6->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown6->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown6_ValueChanged);
			// 
			// numericUpDown5
			// 
			this->numericUpDown5->Location = System::Drawing::Point(368, 49);
			this->numericUpDown5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown5->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown5->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown5->Name = L"numericUpDown5";
			this->numericUpDown5->Size = System::Drawing::Size(120, 20);
			this->numericUpDown5->TabIndex = 32;
			this->numericUpDown5->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1, 0, 0, 0});
			this->numericUpDown5->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown5_ValueChanged);
			// 
			// label6
			// 
			this->label6->AutoSize = true;
			this->label6->Location = System::Drawing::Point(505, 29);
			this->label6->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label6->Name = L"label6";
			this->label6->Size = System::Drawing::Size(121, 13);
			this->label6->TabIndex = 31;
			this->label6->Text = L"Number of RC Channels";
			// 
			// numericUpDown4
			// 
			this->numericUpDown4->Location = System::Drawing::Point(368, 23);
			this->numericUpDown4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown4->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {8, 0, 0, 0});
			this->numericUpDown4->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {4, 0, 0, 0});
			this->numericUpDown4->Name = L"numericUpDown4";
			this->numericUpDown4->Size = System::Drawing::Size(120, 20);
			this->numericUpDown4->TabIndex = 30;
			this->numericUpDown4->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {4, 0, 0, 0});
			this->numericUpDown4->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown4_ValueChanged);
			// 
			// label5
			// 
			this->label5->AutoSize = true;
			this->label5->Location = System::Drawing::Point(142, 157);
			this->label5->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label5->Name = L"label5";
			this->label5->Size = System::Drawing::Size(92, 13);
			this->label5->TabIndex = 29;
			this->label5->Text = L"IMU On RC Value";
			// 
			// numericUpDown3
			// 
			this->numericUpDown3->Location = System::Drawing::Point(8, 157);
			this->numericUpDown3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown3->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, 0});
			this->numericUpDown3->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, System::Int32::MinValue});
			this->numericUpDown3->Name = L"numericUpDown3";
			this->numericUpDown3->Size = System::Drawing::Size(120, 20);
			this->numericUpDown3->TabIndex = 28;
			this->numericUpDown3->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown3_ValueChanged);
			// 
			// label4
			// 
			this->label4->AutoSize = true;
			this->label4->Location = System::Drawing::Point(142, 109);
			this->label4->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label4->Name = L"label4";
			this->label4->Size = System::Drawing::Size(115, 13);
			this->label4->TabIndex = 27;
			this->label4->Text = L"Altitude Hold RC Value";
			// 
			// numericUpDown2
			// 
			this->numericUpDown2->Location = System::Drawing::Point(8, 109);
			this->numericUpDown2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown2->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, 0});
			this->numericUpDown2->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, System::Int32::MinValue});
			this->numericUpDown2->Name = L"numericUpDown2";
			this->numericUpDown2->Size = System::Drawing::Size(120, 20);
			this->numericUpDown2->TabIndex = 26;
			this->numericUpDown2->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown2_ValueChanged);
			// 
			// label13
			// 
			this->label13->AutoSize = true;
			this->label13->Location = System::Drawing::Point(142, 60);
			this->label13->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label13->Name = L"label13";
			this->label13->Size = System::Drawing::Size(88, 13);
			this->label13->TabIndex = 25;
			this->label13->Text = L"Speed Threshold";
			// 
			// numericUpDown1
			// 
			this->numericUpDown1->Location = System::Drawing::Point(8, 60);
			this->numericUpDown1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown1->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, 0});
			this->numericUpDown1->Name = L"numericUpDown1";
			this->numericUpDown1->Size = System::Drawing::Size(120, 20);
			this->numericUpDown1->TabIndex = 24;
			this->numericUpDown1->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown1_ValueChanged);
			// 
			// checkBox4
			// 
			this->checkBox4->AutoSize = true;
			this->checkBox4->Location = System::Drawing::Point(8, 23);
			this->checkBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox4->Name = L"checkBox4";
			this->checkBox4->Size = System::Drawing::Size(73, 17);
			this->checkBox4->TabIndex = 23;
			this->checkBox4->Text = L"PPM Shift";
			this->checkBox4->UseVisualStyleBackColor = true;
			this->checkBox4->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox4_CheckedChanged);
			// 
			// tabPage5
			// 
			this->tabPage5->Controls->Add(this->label45);
			this->tabPage5->Controls->Add(this->comboBox4);
			this->tabPage5->Controls->Add(this->label15);
			this->tabPage5->Controls->Add(this->comboBox2);
			this->tabPage5->Location = System::Drawing::Point(4, 22);
			this->tabPage5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage5->Name = L"tabPage5";
			this->tabPage5->Size = System::Drawing::Size(1085, 609);
			this->tabPage5->TabIndex = 4;
			this->tabPage5->Text = L"GPS";
			this->tabPage5->UseVisualStyleBackColor = true;
			// 
			// label45
			// 
			this->label45->AutoSize = true;
			this->label45->Location = System::Drawing::Point(161, 75);
			this->label45->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label45->Name = L"label45";
			this->label45->Size = System::Drawing::Size(84, 13);
			this->label45->TabIndex = 5;
			this->label45->Text = L"UTC Time offset";
			// 
			// comboBox4
			// 
			this->comboBox4->FormattingEnabled = true;
			this->comboBox4->Items->AddRange(gcnew cli::array< System::Object^  >(26) {L"UTC-12", L"UTC-11", L"UTC-10", L"UTC-9", L"UTC-8 (PST)", 
				L"UTC-7 (MST)", L"UTC-6 (CST)", L"UTC-5 (EST)", L"UTC-4", L"UTC-3", L"UTC-2", L"UTC-1", L"UTC", L"UTC+1", L"UTC+2", L"UTC+3", 
				L"UTC+4", L"UTC+5", L"UTC+6", L"UTC+7", L"UTC+8", L"UTC+9", L"UTC+10", L"UTC+11", L"UTC+12", L"UTC+13"});
			this->comboBox4->Location = System::Drawing::Point(26, 73);
			this->comboBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->comboBox4->Name = L"comboBox4";
			this->comboBox4->Size = System::Drawing::Size(120, 21);
			this->comboBox4->TabIndex = 4;
			this->comboBox4->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::comboBox4_SelectedIndexChanged);
			// 
			// label15
			// 
			this->label15->AutoSize = true;
			this->label15->Location = System::Drawing::Point(161, 47);
			this->label15->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label15->Name = L"label15";
			this->label15->Size = System::Drawing::Size(56, 13);
			this->label15->TabIndex = 3;
			this->label15->Text = L"GPS Type";
			// 
			// comboBox2
			// 
			this->comboBox2->FormattingEnabled = true;
			this->comboBox2->Items->AddRange(gcnew cli::array< System::Object^  >(4) {L"NMEA", L"FV-E8", L"PMB-248", L"PMB-648"});
			this->comboBox2->Location = System::Drawing::Point(26, 44);
			this->comboBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->comboBox2->Name = L"comboBox2";
			this->comboBox2->Size = System::Drawing::Size(120, 21);
			this->comboBox2->TabIndex = 2;
			this->comboBox2->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::comboBox2_SelectedIndexChanged);
			// 
			// tabPage6
			// 
			this->tabPage6->Controls->Add(this->checkBox8);
			this->tabPage6->Controls->Add(this->checkBox7);
			this->tabPage6->Controls->Add(this->label18);
			this->tabPage6->Controls->Add(this->numericUpDown14);
			this->tabPage6->Controls->Add(this->label17);
			this->tabPage6->Controls->Add(this->numericUpDown13);
			this->tabPage6->Controls->Add(this->checkBox6);
			this->tabPage6->Controls->Add(this->checkBox5);
			this->tabPage6->Controls->Add(this->label16);
			this->tabPage6->Controls->Add(this->comboBox3);
			this->tabPage6->Controls->Add(this->groupBox8);
			this->tabPage6->Location = System::Drawing::Point(4, 22);
			this->tabPage6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage6->Name = L"tabPage6";
			this->tabPage6->Size = System::Drawing::Size(1085, 609);
			this->tabPage6->TabIndex = 5;
			this->tabPage6->Text = L"Motor Config";
			this->tabPage6->UseVisualStyleBackColor = true;
			this->tabPage6->Click += gcnew System::EventHandler(this, &Form1::tabPage6_Click);
			// 
			// checkBox8
			// 
			this->checkBox8->AutoSize = true;
			this->checkBox8->Location = System::Drawing::Point(374, 21);
			this->checkBox8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox8->Name = L"checkBox8";
			this->checkBox8->Size = System::Drawing::Size(63, 17);
			this->checkBox8->TabIndex = 42;
			this->checkBox8->Text = L"IMU On";
			this->checkBox8->UseVisualStyleBackColor = true;
			this->checkBox8->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox8_CheckedChanged);
			// 
			// checkBox7
			// 
			this->checkBox7->AutoSize = true;
			this->checkBox7->Location = System::Drawing::Point(19, 151);
			this->checkBox7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox7->Name = L"checkBox7";
			this->checkBox7->Size = System::Drawing::Size(95, 17);
			this->checkBox7->TabIndex = 37;
			this->checkBox7->Text = L"Disable motors";
			this->checkBox7->UseVisualStyleBackColor = true;
			this->checkBox7->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox7_CheckedChanged);
			// 
			// label18
			// 
			this->label18->AutoSize = true;
			this->label18->Location = System::Drawing::Point(152, 127);
			this->label18->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label18->Name = L"label18";
			this->label18->Size = System::Drawing::Size(98, 13);
			this->label18->TabIndex = 25;
			this->label18->Text = L"Motor Update Rate";
			// 
			// numericUpDown14
			// 
			this->numericUpDown14->Location = System::Drawing::Point(19, 125);
			this->numericUpDown14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown14->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {200, 0, 0, 0});
			this->numericUpDown14->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {50, 0, 0, 0});
			this->numericUpDown14->Name = L"numericUpDown14";
			this->numericUpDown14->Size = System::Drawing::Size(120, 20);
			this->numericUpDown14->TabIndex = 24;
			this->numericUpDown14->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {50, 0, 0, 0});
			this->numericUpDown14->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown14_ValueChanged);
			// 
			// label17
			// 
			this->label17->AutoSize = true;
			this->label17->Location = System::Drawing::Point(152, 100);
			this->label17->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label17->Name = L"label17";
			this->label17->Size = System::Drawing::Size(84, 13);
			this->label17->TabIndex = 23;
			this->label17->Text = L"Motor Sensitivity";
			// 
			// numericUpDown13
			// 
			this->numericUpDown13->Location = System::Drawing::Point(19, 99);
			this->numericUpDown13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown13->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, 0});
			this->numericUpDown13->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {500, 0, 0, System::Int32::MinValue});
			this->numericUpDown13->Name = L"numericUpDown13";
			this->numericUpDown13->Size = System::Drawing::Size(120, 20);
			this->numericUpDown13->TabIndex = 22;
			this->numericUpDown13->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown13_ValueChanged);
			// 
			// checkBox6
			// 
			this->checkBox6->AutoSize = true;
			this->checkBox6->Location = System::Drawing::Point(19, 73);
			this->checkBox6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox6->Name = L"checkBox6";
			this->checkBox6->Size = System::Drawing::Size(71, 17);
			this->checkBox6->TabIndex = 21;
			this->checkBox6->Text = L"Front CW";
			this->checkBox6->UseVisualStyleBackColor = true;
			this->checkBox6->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox6_CheckedChanged);
			// 
			// checkBox5
			// 
			this->checkBox5->AutoSize = true;
			this->checkBox5->Location = System::Drawing::Point(19, 49);
			this->checkBox5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox5->Name = L"checkBox5";
			this->checkBox5->Size = System::Drawing::Size(72, 17);
			this->checkBox5->TabIndex = 20;
			this->checkBox5->Text = L"Forty Five";
			this->checkBox5->UseVisualStyleBackColor = true;
			this->checkBox5->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox5_CheckedChanged);
			// 
			// label16
			// 
			this->label16->AutoSize = true;
			this->label16->Location = System::Drawing::Point(152, 23);
			this->label16->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label16->Name = L"label16";
			this->label16->Size = System::Drawing::Size(90, 13);
			this->label16->TabIndex = 19;
			this->label16->Text = L"Number of motors";
			// 
			// comboBox3
			// 
			this->comboBox3->FormattingEnabled = true;
			this->comboBox3->Items->AddRange(gcnew cli::array< System::Object^  >(3) {L"4", L"6", L"8"});
			this->comboBox3->Location = System::Drawing::Point(19, 21);
			this->comboBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->comboBox3->Name = L"comboBox3";
			this->comboBox3->Size = System::Drawing::Size(120, 21);
			this->comboBox3->TabIndex = 18;
			this->comboBox3->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::comboBox3_SelectedIndexChanged);
			// 
			// groupBox8
			// 
			this->groupBox8->Controls->Add(this->label19);
			this->groupBox8->Controls->Add(this->label59);
			this->groupBox8->Controls->Add(this->textBox3);
			this->groupBox8->Controls->Add(this->textBox11);
			this->groupBox8->Controls->Add(this->textBox4);
			this->groupBox8->Controls->Add(this->textBox5);
			this->groupBox8->Controls->Add(this->label23);
			this->groupBox8->Controls->Add(this->textBox6);
			this->groupBox8->Controls->Add(this->label22);
			this->groupBox8->Controls->Add(this->textBox7);
			this->groupBox8->Controls->Add(this->label21);
			this->groupBox8->Controls->Add(this->label20);
			this->groupBox8->Location = System::Drawing::Point(374, 49);
			this->groupBox8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox8->Name = L"groupBox8";
			this->groupBox8->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox8->Size = System::Drawing::Size(245, 203);
			this->groupBox8->TabIndex = 43;
			this->groupBox8->TabStop = false;
			this->groupBox8->Text = L"Motor PID";
			// 
			// label19
			// 
			this->label19->AutoSize = true;
			this->label19->Location = System::Drawing::Point(154, 34);
			this->label19->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label19->Name = L"label19";
			this->label19->Size = System::Drawing::Size(41, 13);
			this->label19->TabIndex = 27;
			this->label19->Text = L"PID Kp";
			// 
			// label59
			// 
			this->label59->AutoSize = true;
			this->label59->Location = System::Drawing::Point(154, 116);
			this->label59->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label59->Name = L"label59";
			this->label59->Size = System::Drawing::Size(44, 13);
			this->label59->TabIndex = 41;
			this->label59->Text = L"PID Krp";
			// 
			// textBox3
			// 
			this->textBox3->AcceptsReturn = true;
			this->textBox3->Location = System::Drawing::Point(30, 34);
			this->textBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox3->Name = L"textBox3";
			this->textBox3->Size = System::Drawing::Size(100, 20);
			this->textBox3->TabIndex = 26;
			this->textBox3->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox3_KeyUp);
			this->textBox3->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox3_Validating);
			this->textBox3->Validated += gcnew System::EventHandler(this, &Form1::textBox3_Validated);
			// 
			// textBox11
			// 
			this->textBox11->AcceptsReturn = true;
			this->textBox11->Location = System::Drawing::Point(30, 116);
			this->textBox11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox11->Name = L"textBox11";
			this->textBox11->Size = System::Drawing::Size(100, 20);
			this->textBox11->TabIndex = 40;
			this->textBox11->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox11_KeyUp);
			this->textBox11->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox11_Validating);
			this->textBox11->Validated += gcnew System::EventHandler(this, &Form1::textBox11_Validated);
			// 
			// textBox4
			// 
			this->textBox4->AcceptsReturn = true;
			this->textBox4->Location = System::Drawing::Point(30, 62);
			this->textBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox4->Name = L"textBox4";
			this->textBox4->Size = System::Drawing::Size(100, 20);
			this->textBox4->TabIndex = 28;
			this->textBox4->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox4_KeyUp);
			this->textBox4->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox4_Validating);
			this->textBox4->Validated += gcnew System::EventHandler(this, &Form1::textBox4_Validated);
			// 
			// textBox5
			// 
			this->textBox5->AcceptsReturn = true;
			this->textBox5->Location = System::Drawing::Point(30, 90);
			this->textBox5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox5->Name = L"textBox5";
			this->textBox5->Size = System::Drawing::Size(100, 20);
			this->textBox5->TabIndex = 29;
			this->textBox5->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox5_KeyUp);
			this->textBox5->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox5_Validating);
			this->textBox5->Validated += gcnew System::EventHandler(this, &Form1::textBox5_Validated);
			// 
			// label23
			// 
			this->label23->AutoSize = true;
			this->label23->Location = System::Drawing::Point(154, 168);
			this->label23->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label23->Name = L"label23";
			this->label23->Size = System::Drawing::Size(66, 13);
			this->label23->TabIndex = 35;
			this->label23->Text = L"PID Minarea";
			// 
			// textBox6
			// 
			this->textBox6->AcceptsReturn = true;
			this->textBox6->Location = System::Drawing::Point(30, 142);
			this->textBox6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox6->Name = L"textBox6";
			this->textBox6->Size = System::Drawing::Size(100, 20);
			this->textBox6->TabIndex = 30;
			this->textBox6->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox6_KeyUp);
			this->textBox6->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox6_Validating);
			this->textBox6->Validated += gcnew System::EventHandler(this, &Form1::textBox6_Validated);
			// 
			// label22
			// 
			this->label22->AutoSize = true;
			this->label22->Location = System::Drawing::Point(154, 142);
			this->label22->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label22->Name = L"label22";
			this->label22->Size = System::Drawing::Size(69, 13);
			this->label22->TabIndex = 34;
			this->label22->Text = L"PID Maxarea";
			// 
			// textBox7
			// 
			this->textBox7->AcceptsReturn = true;
			this->textBox7->Location = System::Drawing::Point(30, 168);
			this->textBox7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox7->Name = L"textBox7";
			this->textBox7->Size = System::Drawing::Size(100, 20);
			this->textBox7->TabIndex = 31;
			this->textBox7->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox7_KeyUp);
			this->textBox7->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox7_Validating);
			this->textBox7->Validated += gcnew System::EventHandler(this, &Form1::textBox7_Validated);
			// 
			// label21
			// 
			this->label21->AutoSize = true;
			this->label21->Location = System::Drawing::Point(154, 86);
			this->label21->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label21->Name = L"label21";
			this->label21->Size = System::Drawing::Size(41, 13);
			this->label21->TabIndex = 33;
			this->label21->Text = L"PID Kd";
			// 
			// label20
			// 
			this->label20->AutoSize = true;
			this->label20->Location = System::Drawing::Point(154, 62);
			this->label20->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label20->Name = L"label20";
			this->label20->Size = System::Drawing::Size(37, 13);
			this->label20->TabIndex = 32;
			this->label20->Text = L"PID Ki";
			// 
			// tabPage7
			// 
			this->tabPage7->Controls->Add(this->checkBox20);
			this->tabPage7->Controls->Add(this->groupBox10);
			this->tabPage7->Controls->Add(this->groupBox9);
			this->tabPage7->Location = System::Drawing::Point(4, 22);
			this->tabPage7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage7->Name = L"tabPage7";
			this->tabPage7->Size = System::Drawing::Size(1085, 609);
			this->tabPage7->TabIndex = 6;
			this->tabPage7->Text = L"Camera Servo";
			this->tabPage7->UseVisualStyleBackColor = true;
			// 
			// checkBox20
			// 
			this->checkBox20->AutoSize = true;
			this->checkBox20->Location = System::Drawing::Point(42, 192);
			this->checkBox20->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox20->Name = L"checkBox20";
			this->checkBox20->Size = System::Drawing::Size(80, 17);
			this->checkBox20->TabIndex = 34;
			this->checkBox20->Text = L"Stablization";
			this->checkBox20->UseVisualStyleBackColor = true;
			this->checkBox20->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox20_CheckedChanged);
			// 
			// groupBox10
			// 
			this->groupBox10->Controls->Add(this->label26);
			this->groupBox10->Controls->Add(this->numericUpDown15);
			this->groupBox10->Controls->Add(this->label27);
			this->groupBox10->Controls->Add(this->numericUpDown16);
			this->groupBox10->Controls->Add(this->numericUpDown17);
			this->groupBox10->Controls->Add(this->label25);
			this->groupBox10->Controls->Add(this->numericUpDown18);
			this->groupBox10->Controls->Add(this->label24);
			this->groupBox10->Location = System::Drawing::Point(42, 35);
			this->groupBox10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox10->Name = L"groupBox10";
			this->groupBox10->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox10->Size = System::Drawing::Size(190, 142);
			this->groupBox10->TabIndex = 33;
			this->groupBox10->TabStop = false;
			this->groupBox10->Text = L"Pan";
			// 
			// label26
			// 
			this->label26->AutoSize = true;
			this->label26->Location = System::Drawing::Point(136, 79);
			this->label26->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label26->Name = L"label26";
			this->label26->Size = System::Drawing::Size(24, 13);
			this->label26->TabIndex = 22;
			this->label26->Text = L"Min";
			// 
			// numericUpDown15
			// 
			this->numericUpDown15->Location = System::Drawing::Point(8, 21);
			this->numericUpDown15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown15->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown15->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown15->Name = L"numericUpDown15";
			this->numericUpDown15->Size = System::Drawing::Size(120, 20);
			this->numericUpDown15->TabIndex = 16;
			this->numericUpDown15->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown15->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown15_ValueChanged);
			// 
			// label27
			// 
			this->label27->AutoSize = true;
			this->label27->Location = System::Drawing::Point(136, 107);
			this->label27->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label27->Name = L"label27";
			this->label27->Size = System::Drawing::Size(35, 13);
			this->label27->TabIndex = 23;
			this->label27->Text = L"Offset";
			// 
			// numericUpDown16
			// 
			this->numericUpDown16->Location = System::Drawing::Point(8, 48);
			this->numericUpDown16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown16->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown16->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown16->Name = L"numericUpDown16";
			this->numericUpDown16->Size = System::Drawing::Size(120, 20);
			this->numericUpDown16->TabIndex = 17;
			this->numericUpDown16->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown16->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown16_ValueChanged);
			// 
			// numericUpDown17
			// 
			this->numericUpDown17->Location = System::Drawing::Point(8, 75);
			this->numericUpDown17->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown17->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown17->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown17->Name = L"numericUpDown17";
			this->numericUpDown17->Size = System::Drawing::Size(120, 20);
			this->numericUpDown17->TabIndex = 18;
			this->numericUpDown17->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown17->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown17_ValueChanged);
			// 
			// label25
			// 
			this->label25->AutoSize = true;
			this->label25->Location = System::Drawing::Point(136, 52);
			this->label25->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label25->Name = L"label25";
			this->label25->Size = System::Drawing::Size(27, 13);
			this->label25->TabIndex = 21;
			this->label25->Text = L"Max";
			// 
			// numericUpDown18
			// 
			this->numericUpDown18->Location = System::Drawing::Point(8, 101);
			this->numericUpDown18->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown18->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown18->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, System::Int32::MinValue});
			this->numericUpDown18->Name = L"numericUpDown18";
			this->numericUpDown18->Size = System::Drawing::Size(120, 20);
			this->numericUpDown18->TabIndex = 19;
			this->numericUpDown18->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown18_ValueChanged);
			// 
			// label24
			// 
			this->label24->AutoSize = true;
			this->label24->Location = System::Drawing::Point(136, 25);
			this->label24->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label24->Name = L"label24";
			this->label24->Size = System::Drawing::Size(38, 13);
			this->label24->TabIndex = 20;
			this->label24->Text = L"Center";
			// 
			// groupBox9
			// 
			this->groupBox9->Controls->Add(this->numericUpDown20);
			this->groupBox9->Controls->Add(this->label31);
			this->groupBox9->Controls->Add(this->numericUpDown19);
			this->groupBox9->Controls->Add(this->label30);
			this->groupBox9->Controls->Add(this->numericUpDown21);
			this->groupBox9->Controls->Add(this->label29);
			this->groupBox9->Controls->Add(this->numericUpDown22);
			this->groupBox9->Controls->Add(this->label28);
			this->groupBox9->Location = System::Drawing::Point(299, 35);
			this->groupBox9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox9->Name = L"groupBox9";
			this->groupBox9->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox9->Size = System::Drawing::Size(194, 142);
			this->groupBox9->TabIndex = 32;
			this->groupBox9->TabStop = false;
			this->groupBox9->Text = L"Tilt";
			// 
			// numericUpDown20
			// 
			this->numericUpDown20->Location = System::Drawing::Point(6, 47);
			this->numericUpDown20->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown20->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown20->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown20->Name = L"numericUpDown20";
			this->numericUpDown20->Size = System::Drawing::Size(120, 20);
			this->numericUpDown20->TabIndex = 25;
			this->numericUpDown20->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown20->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown20_ValueChanged);
			// 
			// label31
			// 
			this->label31->AutoSize = true;
			this->label31->Location = System::Drawing::Point(136, 101);
			this->label31->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label31->Name = L"label31";
			this->label31->Size = System::Drawing::Size(35, 13);
			this->label31->TabIndex = 31;
			this->label31->Text = L"Offset";
			// 
			// numericUpDown19
			// 
			this->numericUpDown19->Location = System::Drawing::Point(6, 21);
			this->numericUpDown19->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown19->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown19->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown19->Name = L"numericUpDown19";
			this->numericUpDown19->Size = System::Drawing::Size(120, 20);
			this->numericUpDown19->TabIndex = 24;
			this->numericUpDown19->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown19->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown19_ValueChanged);
			// 
			// label30
			// 
			this->label30->AutoSize = true;
			this->label30->Location = System::Drawing::Point(136, 75);
			this->label30->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label30->Name = L"label30";
			this->label30->Size = System::Drawing::Size(24, 13);
			this->label30->TabIndex = 30;
			this->label30->Text = L"Min";
			// 
			// numericUpDown21
			// 
			this->numericUpDown21->Location = System::Drawing::Point(6, 73);
			this->numericUpDown21->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown21->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2000, 0, 0, 0});
			this->numericUpDown21->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown21->Name = L"numericUpDown21";
			this->numericUpDown21->Size = System::Drawing::Size(120, 20);
			this->numericUpDown21->TabIndex = 26;
			this->numericUpDown21->Value = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown21->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown21_ValueChanged);
			// 
			// label29
			// 
			this->label29->AutoSize = true;
			this->label29->Location = System::Drawing::Point(136, 48);
			this->label29->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label29->Name = L"label29";
			this->label29->Size = System::Drawing::Size(27, 13);
			this->label29->TabIndex = 29;
			this->label29->Text = L"Max";
			// 
			// numericUpDown22
			// 
			this->numericUpDown22->Location = System::Drawing::Point(6, 100);
			this->numericUpDown22->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown22->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, 0});
			this->numericUpDown22->Minimum = System::Decimal(gcnew cli::array< System::Int32 >(4) {1000, 0, 0, System::Int32::MinValue});
			this->numericUpDown22->Name = L"numericUpDown22";
			this->numericUpDown22->Size = System::Drawing::Size(120, 20);
			this->numericUpDown22->TabIndex = 27;
			this->numericUpDown22->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown22_ValueChanged);
			// 
			// label28
			// 
			this->label28->AutoSize = true;
			this->label28->Location = System::Drawing::Point(136, 21);
			this->label28->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label28->Name = L"label28";
			this->label28->Size = System::Drawing::Size(38, 13);
			this->label28->TabIndex = 28;
			this->label28->Text = L"Center";
			// 
			// tabPage8
			// 
			this->tabPage8->Controls->Add(this->groupBox14);
			this->tabPage8->Controls->Add(this->groupBox13);
			this->tabPage8->Controls->Add(this->groupBox11);
			this->tabPage8->Controls->Add(this->groupBox6);
			this->tabPage8->Controls->Add(this->groupBox3);
			this->tabPage8->Controls->Add(this->groupBox2);
			this->tabPage8->Controls->Add(this->groupBox1);
			this->tabPage8->Location = System::Drawing::Point(4, 22);
			this->tabPage8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage8->Name = L"tabPage8";
			this->tabPage8->Size = System::Drawing::Size(1085, 609);
			this->tabPage8->TabIndex = 7;
			this->tabPage8->Text = L" Sensors";
			this->tabPage8->UseVisualStyleBackColor = true;
			this->tabPage8->Click += gcnew System::EventHandler(this, &Form1::tabPage8_Click);
			// 
			// groupBox13
			// 
			this->groupBox13->Controls->Add(this->textBox17);
			this->groupBox13->Controls->Add(this->checkBox19);
			this->groupBox13->Controls->Add(this->checkBox18);
			this->groupBox13->Controls->Add(this->checkBox17);
			this->groupBox13->Location = System::Drawing::Point(11, 165);
			this->groupBox13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox13->Name = L"groupBox13";
			this->groupBox13->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox13->Size = System::Drawing::Size(143, 73);
			this->groupBox13->TabIndex = 20;
			this->groupBox13->TabStop = false;
			this->groupBox13->Text = L"Gyro Temp compensation";
			// 
			// textBox17
			// 
			this->textBox17->AcceptsReturn = true;
			this->textBox17->Location = System::Drawing::Point(7, 21);
			this->textBox17->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox17->Name = L"textBox17";
			this->textBox17->Size = System::Drawing::Size(100, 20);
			this->textBox17->TabIndex = 14;
			this->textBox17->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox17_KeyUp);
			this->textBox17->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox17_Validating);
			this->textBox17->Validated += gcnew System::EventHandler(this, &Form1::textBox17_Validated);
			// 
			// checkBox19
			// 
			this->checkBox19->AutoSize = true;
			this->checkBox19->Location = System::Drawing::Point(73, 47);
			this->checkBox19->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox19->Name = L"checkBox19";
			this->checkBox19->Size = System::Drawing::Size(33, 17);
			this->checkBox19->TabIndex = 19;
			this->checkBox19->Text = L"Z";
			this->checkBox19->UseVisualStyleBackColor = true;
			// 
			// checkBox18
			// 
			this->checkBox18->AutoSize = true;
			this->checkBox18->Location = System::Drawing::Point(40, 47);
			this->checkBox18->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox18->Name = L"checkBox18";
			this->checkBox18->Size = System::Drawing::Size(33, 17);
			this->checkBox18->TabIndex = 18;
			this->checkBox18->Text = L"Y";
			this->checkBox18->UseVisualStyleBackColor = true;
			// 
			// checkBox17
			// 
			this->checkBox17->AutoSize = true;
			this->checkBox17->Location = System::Drawing::Point(7, 47);
			this->checkBox17->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox17->Name = L"checkBox17";
			this->checkBox17->Size = System::Drawing::Size(33, 17);
			this->checkBox17->TabIndex = 17;
			this->checkBox17->Text = L"X";
			this->checkBox17->UseVisualStyleBackColor = true;
			this->checkBox17->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox17_CheckedChanged);
			// 
			// groupBox11
			// 
			this->groupBox11->Controls->Add(this->button7);
			this->groupBox11->Controls->Add(this->button8);
			this->groupBox11->Controls->Add(this->button9);
			this->groupBox11->Controls->Add(this->label55);
			this->groupBox11->Controls->Add(this->label53);
			this->groupBox11->Controls->Add(this->label54);
			this->groupBox11->Location = System::Drawing::Point(316, 246);
			this->groupBox11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox11->Name = L"groupBox11";
			this->groupBox11->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox11->Size = System::Drawing::Size(172, 121);
			this->groupBox11->TabIndex = 16;
			this->groupBox11->TabStop = false;
			this->groupBox11->Text = L"IMU Offsets";
			// 
			// button7
			// 
			this->button7->Location = System::Drawing::Point(17, 21);
			this->button7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button7->Name = L"button7";
			this->button7->Size = System::Drawing::Size(74, 23);
			this->button7->TabIndex = 6;
			this->button7->Text = L"Pitch";
			this->button7->UseVisualStyleBackColor = true;
			this->button7->Click += gcnew System::EventHandler(this, &Form1::button7_Click);
			// 
			// button8
			// 
			this->button8->Location = System::Drawing::Point(17, 49);
			this->button8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button8->Name = L"button8";
			this->button8->Size = System::Drawing::Size(74, 23);
			this->button8->TabIndex = 7;
			this->button8->Text = L"Roll";
			this->button8->UseVisualStyleBackColor = true;
			this->button8->Click += gcnew System::EventHandler(this, &Form1::button8_Click);
			// 
			// button9
			// 
			this->button9->Location = System::Drawing::Point(17, 78);
			this->button9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button9->Name = L"button9";
			this->button9->Size = System::Drawing::Size(74, 23);
			this->button9->TabIndex = 8;
			this->button9->Text = L"Yaw";
			this->button9->UseVisualStyleBackColor = true;
			this->button9->Click += gcnew System::EventHandler(this, &Form1::button9_Click);
			// 
			// label55
			// 
			this->label55->AutoSize = true;
			this->label55->Location = System::Drawing::Point(102, 83);
			this->label55->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label55->Name = L"label55";
			this->label55->Size = System::Drawing::Size(0, 13);
			this->label55->TabIndex = 11;
			// 
			// label53
			// 
			this->label53->AutoSize = true;
			this->label53->Location = System::Drawing::Point(102, 25);
			this->label53->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label53->Name = L"label53";
			this->label53->Size = System::Drawing::Size(0, 13);
			this->label53->TabIndex = 9;
			// 
			// label54
			// 
			this->label54->AutoSize = true;
			this->label54->Location = System::Drawing::Point(102, 56);
			this->label54->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label54->Name = L"label54";
			this->label54->Size = System::Drawing::Size(0, 13);
			this->label54->TabIndex = 10;
			// 
			// groupBox6
			// 
			this->groupBox6->Controls->Add(this->label75);
			this->groupBox6->Controls->Add(this->label74);
			this->groupBox6->Controls->Add(this->label73);
			this->groupBox6->Controls->Add(this->label72);
			this->groupBox6->Controls->Add(this->label71);
			this->groupBox6->Controls->Add(this->textBox16);
			this->groupBox6->Controls->Add(this->textBox15);
			this->groupBox6->Controls->Add(this->textBox14);
			this->groupBox6->Controls->Add(this->textBox13);
			this->groupBox6->Controls->Add(this->textBox12);
			this->groupBox6->Location = System::Drawing::Point(11, 246);
			this->groupBox6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox6->Name = L"groupBox6";
			this->groupBox6->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox6->Size = System::Drawing::Size(254, 159);
			this->groupBox6->TabIndex = 13;
			this->groupBox6->TabStop = false;
			this->groupBox6->Text = L"Kalman filter settings";
			// 
			// label75
			// 
			this->label75->AutoSize = true;
			this->label75->Location = System::Drawing::Point(148, 127);
			this->label75->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label75->Name = L"label75";
			this->label75->Size = System::Drawing::Size(61, 13);
			this->label75->TabIndex = 9;
			this->label75->Text = L"R Compass";
			// 
			// label74
			// 
			this->label74->AutoSize = true;
			this->label74->Location = System::Drawing::Point(148, 101);
			this->label74->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label74->Name = L"label74";
			this->label74->Size = System::Drawing::Size(86, 13);
			this->label74->TabIndex = 8;
			this->label74->Text = L"R Accelerometer";
			// 
			// label73
			// 
			this->label73->AutoSize = true;
			this->label73->Location = System::Drawing::Point(148, 74);
			this->label73->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label73->Name = L"label73";
			this->label73->Size = System::Drawing::Size(61, 13);
			this->label73->TabIndex = 7;
			this->label73->Text = L"Q Compass";
			// 
			// label72
			// 
			this->label72->AutoSize = true;
			this->label72->Location = System::Drawing::Point(148, 47);
			this->label72->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label72->Name = L"label72";
			this->label72->Size = System::Drawing::Size(40, 13);
			this->label72->TabIndex = 6;
			this->label72->Text = L"Q Gyro";
			// 
			// label71
			// 
			this->label71->AutoSize = true;
			this->label71->Location = System::Drawing::Point(148, 21);
			this->label71->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label71->Name = L"label71";
			this->label71->Size = System::Drawing::Size(85, 13);
			this->label71->TabIndex = 5;
			this->label71->Text = L"Q accelerometer";
			// 
			// textBox16
			// 
			this->textBox16->AcceptsReturn = true;
			this->textBox16->Location = System::Drawing::Point(8, 127);
			this->textBox16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox16->Name = L"textBox16";
			this->textBox16->Size = System::Drawing::Size(120, 20);
			this->textBox16->TabIndex = 4;
			this->textBox16->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox16_KeyUp);
			this->textBox16->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox16_Validating);
			this->textBox16->Validated += gcnew System::EventHandler(this, &Form1::textBox16_Validated);
			// 
			// textBox15
			// 
			this->textBox15->AcceptsReturn = true;
			this->textBox15->Location = System::Drawing::Point(8, 101);
			this->textBox15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox15->Name = L"textBox15";
			this->textBox15->Size = System::Drawing::Size(120, 20);
			this->textBox15->TabIndex = 3;
			this->textBox15->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox15_KeyUp);
			this->textBox15->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox15_Validating);
			this->textBox15->Validated += gcnew System::EventHandler(this, &Form1::textBox15_Validated);
			// 
			// textBox14
			// 
			this->textBox14->AcceptsReturn = true;
			this->textBox14->Location = System::Drawing::Point(8, 74);
			this->textBox14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox14->Name = L"textBox14";
			this->textBox14->Size = System::Drawing::Size(120, 20);
			this->textBox14->TabIndex = 2;
			this->textBox14->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox14_KeyUp);
			this->textBox14->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox14_Validating);
			this->textBox14->Validated += gcnew System::EventHandler(this, &Form1::textBox14_Validated);
			// 
			// textBox13
			// 
			this->textBox13->AcceptsReturn = true;
			this->textBox13->Location = System::Drawing::Point(8, 47);
			this->textBox13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox13->Name = L"textBox13";
			this->textBox13->Size = System::Drawing::Size(120, 20);
			this->textBox13->TabIndex = 1;
			this->textBox13->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox13_KeyUp);
			this->textBox13->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox13_Validating);
			this->textBox13->Validated += gcnew System::EventHandler(this, &Form1::textBox13_Validated);
			// 
			// textBox12
			// 
			this->textBox12->AcceptsReturn = true;
			this->textBox12->Location = System::Drawing::Point(8, 21);
			this->textBox12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox12->Name = L"textBox12";
			this->textBox12->Size = System::Drawing::Size(120, 20);
			this->textBox12->TabIndex = 0;
			this->textBox12->KeyUp += gcnew System::Windows::Forms::KeyEventHandler(this, &Form1::textBox12_KeyUp);
			this->textBox12->Validating += gcnew System::ComponentModel::CancelEventHandler(this, &Form1::textBox12_Validating);
			this->textBox12->Validated += gcnew System::EventHandler(this, &Form1::textBox12_Validated);
			// 
			// groupBox3
			// 
			this->groupBox3->Controls->Add(this->label83);
			this->groupBox3->Controls->Add(this->label84);
			this->groupBox3->Controls->Add(this->checkBox10);
			this->groupBox3->Controls->Add(this->checkBox9);
			this->groupBox3->Controls->Add(this->checkBox2);
			this->groupBox3->Controls->Add(this->label42);
			this->groupBox3->Controls->Add(this->label43);
			this->groupBox3->Controls->Add(this->label44);
			this->groupBox3->Controls->Add(this->numericUpDown29);
			this->groupBox3->Controls->Add(this->numericUpDown30);
			this->groupBox3->Controls->Add(this->numericUpDown31);
			this->groupBox3->Location = System::Drawing::Point(500, 31);
			this->groupBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox3->Name = L"groupBox3";
			this->groupBox3->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox3->Size = System::Drawing::Size(218, 121);
			this->groupBox3->TabIndex = 4;
			this->groupBox3->TabStop = false;
			this->groupBox3->Text = L"Compass";
			// 
			// label83
			// 
			this->label83->AutoSize = true;
			this->label83->Location = System::Drawing::Point(140, 21);
			this->label83->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label83->Name = L"label83";
			this->label83->Size = System::Drawing::Size(33, 13);
			this->label83->TabIndex = 18;
			this->label83->Text = L"invert";
			// 
			// label84
			// 
			this->label84->AutoSize = true;
			this->label84->Location = System::Drawing::Point(10, 21);
			this->label84->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label84->Name = L"label84";
			this->label84->Size = System::Drawing::Size(25, 13);
			this->label84->TabIndex = 17;
			this->label84->Text = L"axis";
			// 
			// checkBox10
			// 
			this->checkBox10->AutoSize = true;
			this->checkBox10->Location = System::Drawing::Point(149, 92);
			this->checkBox10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox10->Name = L"checkBox10";
			this->checkBox10->Size = System::Drawing::Size(15, 14);
			this->checkBox10->TabIndex = 7;
			this->checkBox10->UseVisualStyleBackColor = true;
			this->checkBox10->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox10_CheckedChanged);
			// 
			// checkBox9
			// 
			this->checkBox9->AutoSize = true;
			this->checkBox9->Location = System::Drawing::Point(149, 66);
			this->checkBox9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox9->Name = L"checkBox9";
			this->checkBox9->Size = System::Drawing::Size(15, 14);
			this->checkBox9->TabIndex = 7;
			this->checkBox9->UseVisualStyleBackColor = true;
			this->checkBox9->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox9_CheckedChanged);
			// 
			// checkBox2
			// 
			this->checkBox2->AutoSize = true;
			this->checkBox2->Location = System::Drawing::Point(149, 42);
			this->checkBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox2->Name = L"checkBox2";
			this->checkBox2->Size = System::Drawing::Size(15, 14);
			this->checkBox2->TabIndex = 6;
			this->checkBox2->UseVisualStyleBackColor = true;
			this->checkBox2->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox2_CheckedChanged);
			// 
			// label42
			// 
			this->label42->AutoSize = true;
			this->label42->Location = System::Drawing::Point(181, 94);
			this->label42->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label42->Name = L"label42";
			this->label42->Size = System::Drawing::Size(14, 13);
			this->label42->TabIndex = 5;
			this->label42->Text = L"Z";
			// 
			// label43
			// 
			this->label43->AutoSize = true;
			this->label43->Location = System::Drawing::Point(181, 66);
			this->label43->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label43->Name = L"label43";
			this->label43->Size = System::Drawing::Size(14, 13);
			this->label43->TabIndex = 4;
			this->label43->Text = L"Y";
			// 
			// label44
			// 
			this->label44->AutoSize = true;
			this->label44->Location = System::Drawing::Point(182, 42);
			this->label44->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label44->Name = L"label44";
			this->label44->Size = System::Drawing::Size(14, 13);
			this->label44->TabIndex = 3;
			this->label44->Text = L"X";
			// 
			// numericUpDown29
			// 
			this->numericUpDown29->Location = System::Drawing::Point(8, 92);
			this->numericUpDown29->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown29->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown29->Name = L"numericUpDown29";
			this->numericUpDown29->Size = System::Drawing::Size(120, 20);
			this->numericUpDown29->TabIndex = 2;
			this->numericUpDown29->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown29_ValueChanged);
			// 
			// numericUpDown30
			// 
			this->numericUpDown30->Location = System::Drawing::Point(8, 65);
			this->numericUpDown30->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown30->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown30->Name = L"numericUpDown30";
			this->numericUpDown30->Size = System::Drawing::Size(120, 20);
			this->numericUpDown30->TabIndex = 1;
			this->numericUpDown30->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown30_ValueChanged);
			// 
			// numericUpDown31
			// 
			this->numericUpDown31->Location = System::Drawing::Point(8, 38);
			this->numericUpDown31->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown31->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown31->Name = L"numericUpDown31";
			this->numericUpDown31->Size = System::Drawing::Size(120, 20);
			this->numericUpDown31->TabIndex = 0;
			this->numericUpDown31->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown31_ValueChanged);
			// 
			// groupBox2
			// 
			this->groupBox2->Controls->Add(this->label52);
			this->groupBox2->Controls->Add(this->label82);
			this->groupBox2->Controls->Add(this->checkBox13);
			this->groupBox2->Controls->Add(this->checkBox12);
			this->groupBox2->Controls->Add(this->checkBox11);
			this->groupBox2->Controls->Add(this->label39);
			this->groupBox2->Controls->Add(this->label40);
			this->groupBox2->Controls->Add(this->label41);
			this->groupBox2->Controls->Add(this->numericUpDown26);
			this->groupBox2->Controls->Add(this->numericUpDown27);
			this->groupBox2->Controls->Add(this->numericUpDown28);
			this->groupBox2->Location = System::Drawing::Point(252, 31);
			this->groupBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox2->Name = L"groupBox2";
			this->groupBox2->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox2->Size = System::Drawing::Size(218, 121);
			this->groupBox2->TabIndex = 3;
			this->groupBox2->TabStop = false;
			this->groupBox2->Text = L"Accelerometers";
			// 
			// label52
			// 
			this->label52->AutoSize = true;
			this->label52->Location = System::Drawing::Point(143, 18);
			this->label52->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label52->Name = L"label52";
			this->label52->Size = System::Drawing::Size(33, 13);
			this->label52->TabIndex = 18;
			this->label52->Text = L"invert";
			// 
			// label82
			// 
			this->label82->AutoSize = true;
			this->label82->Location = System::Drawing::Point(10, 21);
			this->label82->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label82->Name = L"label82";
			this->label82->Size = System::Drawing::Size(25, 13);
			this->label82->TabIndex = 17;
			this->label82->Text = L"axis";
			// 
			// checkBox13
			// 
			this->checkBox13->AutoSize = true;
			this->checkBox13->Location = System::Drawing::Point(152, 94);
			this->checkBox13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox13->Name = L"checkBox13";
			this->checkBox13->Size = System::Drawing::Size(15, 14);
			this->checkBox13->TabIndex = 8;
			this->checkBox13->UseVisualStyleBackColor = true;
			this->checkBox13->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox13_CheckedChanged);
			// 
			// checkBox12
			// 
			this->checkBox12->AutoSize = true;
			this->checkBox12->Location = System::Drawing::Point(152, 66);
			this->checkBox12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox12->Name = L"checkBox12";
			this->checkBox12->Size = System::Drawing::Size(15, 14);
			this->checkBox12->TabIndex = 9;
			this->checkBox12->UseVisualStyleBackColor = true;
			this->checkBox12->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox12_CheckedChanged);
			// 
			// checkBox11
			// 
			this->checkBox11->AutoSize = true;
			this->checkBox11->Location = System::Drawing::Point(152, 42);
			this->checkBox11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox11->Name = L"checkBox11";
			this->checkBox11->Size = System::Drawing::Size(15, 14);
			this->checkBox11->TabIndex = 8;
			this->checkBox11->UseVisualStyleBackColor = true;
			this->checkBox11->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox11_CheckedChanged);
			// 
			// label39
			// 
			this->label39->AutoSize = true;
			this->label39->Location = System::Drawing::Point(186, 92);
			this->label39->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label39->Name = L"label39";
			this->label39->Size = System::Drawing::Size(14, 13);
			this->label39->TabIndex = 5;
			this->label39->Text = L"Z";
			// 
			// label40
			// 
			this->label40->AutoSize = true;
			this->label40->Location = System::Drawing::Point(186, 65);
			this->label40->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label40->Name = L"label40";
			this->label40->Size = System::Drawing::Size(14, 13);
			this->label40->TabIndex = 4;
			this->label40->Text = L"Y";
			// 
			// label41
			// 
			this->label41->AutoSize = true;
			this->label41->Location = System::Drawing::Point(186, 38);
			this->label41->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label41->Name = L"label41";
			this->label41->Size = System::Drawing::Size(14, 13);
			this->label41->TabIndex = 3;
			this->label41->Text = L"X";
			// 
			// numericUpDown26
			// 
			this->numericUpDown26->Location = System::Drawing::Point(8, 92);
			this->numericUpDown26->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown26->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown26->Name = L"numericUpDown26";
			this->numericUpDown26->Size = System::Drawing::Size(120, 20);
			this->numericUpDown26->TabIndex = 2;
			this->numericUpDown26->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown26_ValueChanged);
			// 
			// numericUpDown27
			// 
			this->numericUpDown27->Location = System::Drawing::Point(8, 65);
			this->numericUpDown27->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown27->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown27->Name = L"numericUpDown27";
			this->numericUpDown27->Size = System::Drawing::Size(120, 20);
			this->numericUpDown27->TabIndex = 1;
			this->numericUpDown27->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown27_ValueChanged);
			// 
			// numericUpDown28
			// 
			this->numericUpDown28->Location = System::Drawing::Point(8, 38);
			this->numericUpDown28->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown28->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown28->Name = L"numericUpDown28";
			this->numericUpDown28->Size = System::Drawing::Size(120, 20);
			this->numericUpDown28->TabIndex = 0;
			this->numericUpDown28->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown28_ValueChanged);
			// 
			// groupBox1
			// 
			this->groupBox1->Controls->Add(this->label51);
			this->groupBox1->Controls->Add(this->label1);
			this->groupBox1->Controls->Add(this->checkBox16);
			this->groupBox1->Controls->Add(this->checkBox15);
			this->groupBox1->Controls->Add(this->checkBox14);
			this->groupBox1->Controls->Add(this->label38);
			this->groupBox1->Controls->Add(this->label37);
			this->groupBox1->Controls->Add(this->label36);
			this->groupBox1->Controls->Add(this->numericUpDown25);
			this->groupBox1->Controls->Add(this->numericUpDown24);
			this->groupBox1->Controls->Add(this->numericUpDown23);
			this->groupBox1->Location = System::Drawing::Point(11, 31);
			this->groupBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox1->Name = L"groupBox1";
			this->groupBox1->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox1->Size = System::Drawing::Size(212, 121);
			this->groupBox1->TabIndex = 2;
			this->groupBox1->TabStop = false;
			this->groupBox1->Text = L"Gyros";
			// 
			// label51
			// 
			this->label51->AutoSize = true;
			this->label51->Location = System::Drawing::Point(138, 21);
			this->label51->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label51->Name = L"label51";
			this->label51->Size = System::Drawing::Size(33, 13);
			this->label51->TabIndex = 11;
			this->label51->Text = L"invert";
			// 
			// label1
			// 
			this->label1->AutoSize = true;
			this->label1->Location = System::Drawing::Point(8, 21);
			this->label1->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label1->Name = L"label1";
			this->label1->Size = System::Drawing::Size(25, 13);
			this->label1->TabIndex = 10;
			this->label1->Text = L"axis";
			// 
			// checkBox16
			// 
			this->checkBox16->AutoSize = true;
			this->checkBox16->Location = System::Drawing::Point(148, 95);
			this->checkBox16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox16->Name = L"checkBox16";
			this->checkBox16->Size = System::Drawing::Size(15, 14);
			this->checkBox16->TabIndex = 9;
			this->checkBox16->UseVisualStyleBackColor = true;
			this->checkBox16->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox16_CheckedChanged);
			// 
			// checkBox15
			// 
			this->checkBox15->AutoSize = true;
			this->checkBox15->Location = System::Drawing::Point(148, 68);
			this->checkBox15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox15->Name = L"checkBox15";
			this->checkBox15->Size = System::Drawing::Size(15, 14);
			this->checkBox15->TabIndex = 9;
			this->checkBox15->UseVisualStyleBackColor = true;
			this->checkBox15->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox15_CheckedChanged);
			// 
			// checkBox14
			// 
			this->checkBox14->AutoSize = true;
			this->checkBox14->Location = System::Drawing::Point(148, 42);
			this->checkBox14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox14->Name = L"checkBox14";
			this->checkBox14->Size = System::Drawing::Size(15, 14);
			this->checkBox14->TabIndex = 9;
			this->checkBox14->UseVisualStyleBackColor = true;
			this->checkBox14->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox14_CheckedChanged);
			// 
			// label38
			// 
			this->label38->AutoSize = true;
			this->label38->Location = System::Drawing::Point(178, 95);
			this->label38->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label38->Name = L"label38";
			this->label38->Size = System::Drawing::Size(14, 13);
			this->label38->TabIndex = 5;
			this->label38->Text = L"Z";
			// 
			// label37
			// 
			this->label37->AutoSize = true;
			this->label37->Location = System::Drawing::Point(178, 68);
			this->label37->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label37->Name = L"label37";
			this->label37->Size = System::Drawing::Size(14, 13);
			this->label37->TabIndex = 4;
			this->label37->Text = L"Y";
			// 
			// label36
			// 
			this->label36->AutoSize = true;
			this->label36->Location = System::Drawing::Point(178, 40);
			this->label36->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label36->Name = L"label36";
			this->label36->Size = System::Drawing::Size(14, 13);
			this->label36->TabIndex = 3;
			this->label36->Text = L"X";
			// 
			// numericUpDown25
			// 
			this->numericUpDown25->Location = System::Drawing::Point(8, 92);
			this->numericUpDown25->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown25->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown25->Name = L"numericUpDown25";
			this->numericUpDown25->Size = System::Drawing::Size(120, 20);
			this->numericUpDown25->TabIndex = 2;
			this->numericUpDown25->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown25_ValueChanged);
			// 
			// numericUpDown24
			// 
			this->numericUpDown24->Location = System::Drawing::Point(8, 66);
			this->numericUpDown24->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown24->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown24->Name = L"numericUpDown24";
			this->numericUpDown24->Size = System::Drawing::Size(120, 20);
			this->numericUpDown24->TabIndex = 1;
			this->numericUpDown24->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown24_ValueChanged);
			// 
			// numericUpDown23
			// 
			this->numericUpDown23->Location = System::Drawing::Point(8, 39);
			this->numericUpDown23->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown23->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown23->Name = L"numericUpDown23";
			this->numericUpDown23->Size = System::Drawing::Size(120, 20);
			this->numericUpDown23->TabIndex = 0;
			this->numericUpDown23->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown23_ValueChanged);
			// 
			// tabPage15
			// 
			this->tabPage15->Controls->Add(this->richTextBox4);
			this->tabPage15->Controls->Add(this->richTextBox3);
			this->tabPage15->Controls->Add(this->button16);
			this->tabPage15->Location = System::Drawing::Point(4, 22);
			this->tabPage15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage15->Name = L"tabPage15";
			this->tabPage15->Size = System::Drawing::Size(1085, 609);
			this->tabPage15->TabIndex = 14;
			this->tabPage15->Text = L"ESC calibration";
			this->tabPage15->UseVisualStyleBackColor = true;
			this->tabPage15->SizeChanged += gcnew System::EventHandler(this, &Form1::tabPage15_SizeChanged);
			// 
			// richTextBox4
			// 
			this->richTextBox4->Enabled = false;
			this->richTextBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 12, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->richTextBox4->Location = System::Drawing::Point(8, 289);
			this->richTextBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->richTextBox4->Name = L"richTextBox4";
			this->richTextBox4->Size = System::Drawing::Size(858, 133);
			this->richTextBox4->TabIndex = 10;
			this->richTextBox4->Text = resources->GetString(L"richTextBox4.Text");
			// 
			// richTextBox3
			// 
			this->richTextBox3->Enabled = false;
			this->richTextBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 12, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->richTextBox3->Location = System::Drawing::Point(8, 18);
			this->richTextBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->richTextBox3->Name = L"richTextBox3";
			this->richTextBox3->Size = System::Drawing::Size(858, 235);
			this->richTextBox3->TabIndex = 9;
			this->richTextBox3->Text = resources->GetString(L"richTextBox3.Text");
			// 
			// button16
			// 
			this->button16->Enabled = false;
			this->button16->Location = System::Drawing::Point(313, 259);
			this->button16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button16->Name = L"button16";
			this->button16->Size = System::Drawing::Size(104, 23);
			this->button16->TabIndex = 3;
			this->button16->Text = L"Start Calibration";
			this->button16->UseVisualStyleBackColor = true;
			this->button16->Click += gcnew System::EventHandler(this, &Form1::button16_Click);
			// 
			// tabPage10
			// 
			this->tabPage10->Controls->Add(this->richTextBox2);
			this->tabPage10->Location = System::Drawing::Point(4, 22);
			this->tabPage10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage10->Name = L"tabPage10";
			this->tabPage10->Size = System::Drawing::Size(1085, 609);
			this->tabPage10->TabIndex = 9;
			this->tabPage10->Text = L"IMU";
			this->tabPage10->UseVisualStyleBackColor = true;
			// 
			// richTextBox2
			// 
			this->richTextBox2->BackColor = System::Drawing::SystemColors::InactiveCaption;
			this->richTextBox2->Dock = System::Windows::Forms::DockStyle::Fill;
			this->richTextBox2->Font = (gcnew System::Drawing::Font(L"Parallax", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->richTextBox2->Location = System::Drawing::Point(0, 0);
			this->richTextBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->richTextBox2->Name = L"richTextBox2";
			this->richTextBox2->Size = System::Drawing::Size(1085, 609);
			this->richTextBox2->TabIndex = 0;
			this->richTextBox2->Text = L"";
			// 
			// tabPage11
			// 
			this->tabPage11->Controls->Add(this->label81);
			this->tabPage11->Controls->Add(this->label80);
			this->tabPage11->Controls->Add(this->label79);
			this->tabPage11->Controls->Add(this->trackBar10);
			this->tabPage11->Controls->Add(this->trackBar9);
			this->tabPage11->Controls->Add(this->trackBar8);
			this->tabPage11->Controls->Add(this->trackBar7);
			this->tabPage11->Controls->Add(this->trackBar6);
			this->tabPage11->Controls->Add(this->trackBar5);
			this->tabPage11->Controls->Add(this->label50);
			this->tabPage11->Controls->Add(this->label49);
			this->tabPage11->Controls->Add(this->label48);
			this->tabPage11->Controls->Add(this->trackBar4);
			this->tabPage11->Controls->Add(this->trackBar3);
			this->tabPage11->Controls->Add(this->trackBar2);
			this->tabPage11->Controls->Add(this->trackBar1);
			this->tabPage11->Controls->Add(this->pictureBox1);
			this->tabPage11->Location = System::Drawing::Point(4, 22);
			this->tabPage11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage11->Name = L"tabPage11";
			this->tabPage11->Size = System::Drawing::Size(1085, 609);
			this->tabPage11->TabIndex = 10;
			this->tabPage11->Text = L"Quad";
			this->tabPage11->UseVisualStyleBackColor = true;
			this->tabPage11->SizeChanged += gcnew System::EventHandler(this, &Form1::tabPage11_SizeChanged);
			// 
			// label81
			// 
			this->label81->AutoSize = true;
			this->label81->Location = System::Drawing::Point(104, 248);
			this->label81->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label81->Name = L"label81";
			this->label81->Size = System::Drawing::Size(39, 13);
			this->label81->TabIndex = 19;
			this->label81->Text = L"Motors";
			// 
			// label80
			// 
			this->label80->AutoSize = true;
			this->label80->Location = System::Drawing::Point(560, 248);
			this->label80->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label80->Name = L"label80";
			this->label80->Size = System::Drawing::Size(26, 13);
			this->label80->TabIndex = 18;
			this->label80->Text = L"Acc";
			// 
			// label79
			// 
			this->label79->AutoSize = true;
			this->label79->Location = System::Drawing::Point(558, 81);
			this->label79->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label79->Name = L"label79";
			this->label79->Size = System::Drawing::Size(29, 13);
			this->label79->TabIndex = 17;
			this->label79->Text = L"Gyro";
			// 
			// trackBar10
			// 
			this->trackBar10->Enabled = false;
			this->trackBar10->Location = System::Drawing::Point(720, 168);
			this->trackBar10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar10->Maximum = 1600;
			this->trackBar10->Minimum = -1600;
			this->trackBar10->Name = L"trackBar10";
			this->trackBar10->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar10->Size = System::Drawing::Size(45, 185);
			this->trackBar10->TabIndex = 16;
			// 
			// trackBar9
			// 
			this->trackBar9->Enabled = false;
			this->trackBar9->Location = System::Drawing::Point(668, 168);
			this->trackBar9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar9->Maximum = 1600;
			this->trackBar9->Minimum = -1600;
			this->trackBar9->Name = L"trackBar9";
			this->trackBar9->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar9->Size = System::Drawing::Size(45, 185);
			this->trackBar9->TabIndex = 15;
			// 
			// trackBar8
			// 
			this->trackBar8->Enabled = false;
			this->trackBar8->Location = System::Drawing::Point(618, 168);
			this->trackBar8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar8->Maximum = 1600;
			this->trackBar8->Minimum = -1600;
			this->trackBar8->Name = L"trackBar8";
			this->trackBar8->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar8->Size = System::Drawing::Size(45, 185);
			this->trackBar8->TabIndex = 14;
			// 
			// trackBar7
			// 
			this->trackBar7->Enabled = false;
			this->trackBar7->Location = System::Drawing::Point(720, 3);
			this->trackBar7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar7->Maximum = 2000;
			this->trackBar7->Minimum = -2000;
			this->trackBar7->Name = L"trackBar7";
			this->trackBar7->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar7->Size = System::Drawing::Size(45, 164);
			this->trackBar7->TabIndex = 13;
			// 
			// trackBar6
			// 
			this->trackBar6->Enabled = false;
			this->trackBar6->Location = System::Drawing::Point(668, 3);
			this->trackBar6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar6->Maximum = 2000;
			this->trackBar6->Minimum = -2000;
			this->trackBar6->Name = L"trackBar6";
			this->trackBar6->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar6->Size = System::Drawing::Size(45, 164);
			this->trackBar6->TabIndex = 12;
			// 
			// trackBar5
			// 
			this->trackBar5->Enabled = false;
			this->trackBar5->Location = System::Drawing::Point(618, 3);
			this->trackBar5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar5->Maximum = 2000;
			this->trackBar5->Minimum = -2000;
			this->trackBar5->Name = L"trackBar5";
			this->trackBar5->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar5->Size = System::Drawing::Size(45, 164);
			this->trackBar5->TabIndex = 11;
			// 
			// label50
			// 
			this->label50->AutoSize = true;
			this->label50->Location = System::Drawing::Point(102, 34);
			this->label50->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label50->Name = L"label50";
			this->label50->Size = System::Drawing::Size(0, 13);
			this->label50->TabIndex = 10;
			// 
			// label49
			// 
			this->label49->AutoSize = true;
			this->label49->Location = System::Drawing::Point(102, 21);
			this->label49->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label49->Name = L"label49";
			this->label49->Size = System::Drawing::Size(0, 13);
			this->label49->TabIndex = 9;
			// 
			// label48
			// 
			this->label48->AutoSize = true;
			this->label48->Location = System::Drawing::Point(102, 4);
			this->label48->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label48->Name = L"label48";
			this->label48->Size = System::Drawing::Size(0, 13);
			this->label48->TabIndex = 8;
			// 
			// trackBar4
			// 
			this->trackBar4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
			this->trackBar4->Location = System::Drawing::Point(50, 168);
			this->trackBar4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar4->Maximum = 500;
			this->trackBar4->Minimum = -500;
			this->trackBar4->Name = L"trackBar4";
			this->trackBar4->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar4->Size = System::Drawing::Size(45, 185);
			this->trackBar4->TabIndex = 7;
			this->trackBar4->ValueChanged += gcnew System::EventHandler(this, &Form1::trackBar4_ValueChanged);
			// 
			// trackBar3
			// 
			this->trackBar3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
			this->trackBar3->Location = System::Drawing::Point(0, 168);
			this->trackBar3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar3->Maximum = 500;
			this->trackBar3->Minimum = -500;
			this->trackBar3->Name = L"trackBar3";
			this->trackBar3->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar3->Size = System::Drawing::Size(45, 185);
			this->trackBar3->TabIndex = 6;
			this->trackBar3->ValueChanged += gcnew System::EventHandler(this, &Form1::trackBar3_ValueChanged);
			// 
			// trackBar2
			// 
			this->trackBar2->Location = System::Drawing::Point(50, 0);
			this->trackBar2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar2->Maximum = 500;
			this->trackBar2->Minimum = -500;
			this->trackBar2->Name = L"trackBar2";
			this->trackBar2->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar2->Size = System::Drawing::Size(45, 168);
			this->trackBar2->TabIndex = 5;
			this->trackBar2->ValueChanged += gcnew System::EventHandler(this, &Form1::trackBar2_ValueChanged);
			// 
			// trackBar1
			// 
			this->trackBar1->Location = System::Drawing::Point(0, 0);
			this->trackBar1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->trackBar1->Maximum = 500;
			this->trackBar1->Minimum = -500;
			this->trackBar1->Name = L"trackBar1";
			this->trackBar1->Orientation = System::Windows::Forms::Orientation::Vertical;
			this->trackBar1->Size = System::Drawing::Size(45, 168);
			this->trackBar1->TabIndex = 4;
			this->trackBar1->ValueChanged += gcnew System::EventHandler(this, &Form1::trackBar1_ValueChanged);
			// 
			// pictureBox1
			// 
			this->pictureBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom) 
				| System::Windows::Forms::AnchorStyles::Left) 
				| System::Windows::Forms::AnchorStyles::Right));
			this->pictureBox1->Location = System::Drawing::Point(102, 0);
			this->pictureBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->pictureBox1->Name = L"pictureBox1";
			this->pictureBox1->Size = System::Drawing::Size(510, 351);
			this->pictureBox1->TabIndex = 3;
			this->pictureBox1->TabStop = false;
			this->pictureBox1->Paint += gcnew System::Windows::Forms::PaintEventHandler(this, &Form1::pictureBox1_Paint);
			// 
			// tabPage13
			// 
			this->tabPage13->Controls->Add(this->label77);
			this->tabPage13->Controls->Add(this->label76);
			this->tabPage13->Controls->Add(this->label70);
			this->tabPage13->Controls->Add(this->label69);
			this->tabPage13->Controls->Add(this->label68);
			this->tabPage13->Controls->Add(this->label67);
			this->tabPage13->Controls->Add(this->label66);
			this->tabPage13->Controls->Add(this->label65);
			this->tabPage13->Controls->Add(this->label64);
			this->tabPage13->Controls->Add(this->label63);
			this->tabPage13->Controls->Add(this->label62);
			this->tabPage13->Controls->Add(this->label61);
			this->tabPage13->Controls->Add(this->label60);
			this->tabPage13->Controls->Add(this->pictureBox2);
			this->tabPage13->Location = System::Drawing::Point(4, 22);
			this->tabPage13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage13->Name = L"tabPage13";
			this->tabPage13->Size = System::Drawing::Size(1085, 609);
			this->tabPage13->TabIndex = 12;
			this->tabPage13->Text = L"Heads Up";
			this->tabPage13->UseVisualStyleBackColor = true;
			// 
			// label77
			// 
			this->label77->AutoSize = true;
			this->label77->Location = System::Drawing::Point(174, 4);
			this->label77->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label77->Name = L"label77";
			this->label77->Size = System::Drawing::Size(70, 13);
			this->label77->TabIndex = 13;
			this->label77->Text = L"Raw Sensors";
			// 
			// label76
			// 
			this->label76->AutoSize = true;
			this->label76->Location = System::Drawing::Point(569, 4);
			this->label76->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label76->Name = L"label76";
			this->label76->Size = System::Drawing::Size(77, 13);
			this->label76->TabIndex = 12;
			this->label76->Text = L"Kalman Output";
			// 
			// label70
			// 
			this->label70->AutoSize = true;
			this->label70->Location = System::Drawing::Point(170, 34);
			this->label70->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label70->Name = L"label70";
			this->label70->Size = System::Drawing::Size(28, 13);
			this->label70->TabIndex = 11;
			this->label70->Text = L"Yaw";
			// 
			// label69
			// 
			this->label69->AutoSize = true;
			this->label69->Location = System::Drawing::Point(569, 34);
			this->label69->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label69->Name = L"label69";
			this->label69->Size = System::Drawing::Size(28, 13);
			this->label69->TabIndex = 10;
			this->label69->Text = L"Yaw";
			// 
			// label68
			// 
			this->label68->AutoSize = true;
			this->label68->Location = System::Drawing::Point(566, 394);
			this->label68->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label68->Name = L"label68";
			this->label68->Size = System::Drawing::Size(25, 13);
			this->label68->TabIndex = 9;
			this->label68->Text = L"Roll";
			// 
			// label67
			// 
			this->label67->AutoSize = true;
			this->label67->Location = System::Drawing::Point(168, 394);
			this->label67->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label67->Name = L"label67";
			this->label67->Size = System::Drawing::Size(25, 13);
			this->label67->TabIndex = 8;
			this->label67->Text = L"Roll";
			// 
			// label66
			// 
			this->label66->AutoSize = true;
			this->label66->Location = System::Drawing::Point(410, 200);
			this->label66->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label66->Name = L"label66";
			this->label66->Size = System::Drawing::Size(31, 13);
			this->label66->TabIndex = 7;
			this->label66->Text = L"Pitch";
			// 
			// label65
			// 
			this->label65->AutoSize = true;
			this->label65->Location = System::Drawing::Point(613, 394);
			this->label65->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label65->Name = L"label65";
			this->label65->Size = System::Drawing::Size(41, 13);
			this->label65->TabIndex = 6;
			this->label65->Text = L"label65";
			// 
			// label64
			// 
			this->label64->AutoSize = true;
			this->label64->Location = System::Drawing::Point(215, 394);
			this->label64->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label64->Name = L"label64";
			this->label64->Size = System::Drawing::Size(41, 13);
			this->label64->TabIndex = 5;
			this->label64->Text = L"label64";
			// 
			// label63
			// 
			this->label63->AutoSize = true;
			this->label63->Location = System::Drawing::Point(432, 222);
			this->label63->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label63->Name = L"label63";
			this->label63->Size = System::Drawing::Size(41, 13);
			this->label63->TabIndex = 4;
			this->label63->Text = L"label63";
			// 
			// label62
			// 
			this->label62->AutoSize = true;
			this->label62->Location = System::Drawing::Point(395, 222);
			this->label62->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label62->Name = L"label62";
			this->label62->Size = System::Drawing::Size(41, 13);
			this->label62->TabIndex = 3;
			this->label62->Text = L"label62";
			// 
			// label61
			// 
			this->label61->AutoSize = true;
			this->label61->Location = System::Drawing::Point(613, 35);
			this->label61->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label61->Name = L"label61";
			this->label61->Size = System::Drawing::Size(41, 13);
			this->label61->TabIndex = 2;
			this->label61->Text = L"label61";
			// 
			// label60
			// 
			this->label60->AutoSize = true;
			this->label60->Location = System::Drawing::Point(215, 35);
			this->label60->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label60->Name = L"label60";
			this->label60->Size = System::Drawing::Size(41, 13);
			this->label60->TabIndex = 1;
			this->label60->Text = L"label60";
			// 
			// pictureBox2
			// 
			this->pictureBox2->Dock = System::Windows::Forms::DockStyle::Fill;
			this->pictureBox2->Location = System::Drawing::Point(0, 0);
			this->pictureBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->pictureBox2->Name = L"pictureBox2";
			this->pictureBox2->Size = System::Drawing::Size(1085, 609);
			this->pictureBox2->TabIndex = 0;
			this->pictureBox2->TabStop = false;
			this->pictureBox2->SizeChanged += gcnew System::EventHandler(this, &Form1::pictureBox2_SizeChanged);
			this->pictureBox2->Paint += gcnew System::Windows::Forms::PaintEventHandler(this, &Form1::pictureBox2_Paint);
			// 
			// tabPage12
			// 
			this->tabPage12->BackColor = System::Drawing::Color::Transparent;
			this->tabPage12->Controls->Add(this->pictureBox4);
			this->tabPage12->Controls->Add(this->button13);
			this->tabPage12->Controls->Add(this->label58);
			this->tabPage12->Controls->Add(this->label57);
			this->tabPage12->Controls->Add(this->label56);
			this->tabPage12->Controls->Add(this->numericUpDown33);
			this->tabPage12->Controls->Add(this->textBox10);
			this->tabPage12->Controls->Add(this->textBox9);
			this->tabPage12->Controls->Add(this->textBox8);
			this->tabPage12->Controls->Add(this->button12);
			this->tabPage12->Controls->Add(this->button11);
			this->tabPage12->Controls->Add(this->button10);
			this->tabPage12->Location = System::Drawing::Point(4, 22);
			this->tabPage12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage12->Name = L"tabPage12";
			this->tabPage12->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage12->Size = System::Drawing::Size(1085, 609);
			this->tabPage12->TabIndex = 11;
			this->tabPage12->Text = L"Waypoints";
			this->tabPage12->SizeChanged += gcnew System::EventHandler(this, &Form1::tabPage12_SizeChanged);
			// 
			// pictureBox4
			// 
			this->pictureBox4->BackColor = System::Drawing::Color::Transparent;
			this->pictureBox4->Location = System::Drawing::Point(100, 5);
			this->pictureBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->pictureBox4->Name = L"pictureBox4";
			this->pictureBox4->Size = System::Drawing::Size(709, 463);
			this->pictureBox4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::StretchImage;
			this->pictureBox4->TabIndex = 12;
			this->pictureBox4->TabStop = false;
			// 
			// button13
			// 
			this->button13->Location = System::Drawing::Point(0, 246);
			this->button13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button13->Name = L"button13";
			this->button13->Size = System::Drawing::Size(74, 23);
			this->button13->TabIndex = 11;
			this->button13->Text = L"Update";
			this->button13->UseVisualStyleBackColor = true;
			this->button13->Click += gcnew System::EventHandler(this, &Form1::button13_Click);
			// 
			// label58
			// 
			this->label58->AutoSize = true;
			this->label58->Location = System::Drawing::Point(8, 203);
			this->label58->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label58->Name = L"label58";
			this->label58->Size = System::Drawing::Size(42, 13);
			this->label58->TabIndex = 10;
			this->label58->Text = L"Altitude";
			// 
			// label57
			// 
			this->label57->AutoSize = true;
			this->label57->Location = System::Drawing::Point(8, 156);
			this->label57->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label57->Name = L"label57";
			this->label57->Size = System::Drawing::Size(54, 13);
			this->label57->TabIndex = 9;
			this->label57->Text = L"Longitude";
			// 
			// label56
			// 
			this->label56->AutoSize = true;
			this->label56->Location = System::Drawing::Point(8, 113);
			this->label56->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label56->Name = L"label56";
			this->label56->Size = System::Drawing::Size(45, 13);
			this->label56->TabIndex = 8;
			this->label56->Text = L"Latitude";
			// 
			// numericUpDown33
			// 
			this->numericUpDown33->Location = System::Drawing::Point(0, 90);
			this->numericUpDown33->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown33->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {19, 0, 0, 0});
			this->numericUpDown33->Name = L"numericUpDown33";
			this->numericUpDown33->Size = System::Drawing::Size(80, 20);
			this->numericUpDown33->TabIndex = 7;
			this->numericUpDown33->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown33_ValueChanged);
			// 
			// textBox10
			// 
			this->textBox10->Location = System::Drawing::Point(-2, 222);
			this->textBox10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox10->Name = L"textBox10";
			this->textBox10->Size = System::Drawing::Size(81, 20);
			this->textBox10->TabIndex = 6;
			// 
			// textBox9
			// 
			this->textBox9->Location = System::Drawing::Point(0, 179);
			this->textBox9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox9->Name = L"textBox9";
			this->textBox9->Size = System::Drawing::Size(81, 20);
			this->textBox9->TabIndex = 5;
			// 
			// textBox8
			// 
			this->textBox8->Location = System::Drawing::Point(0, 133);
			this->textBox8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->textBox8->Name = L"textBox8";
			this->textBox8->Size = System::Drawing::Size(81, 20);
			this->textBox8->TabIndex = 4;
			// 
			// button12
			// 
			this->button12->Location = System::Drawing::Point(0, 60);
			this->button12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button12->Name = L"button12";
			this->button12->Size = System::Drawing::Size(74, 23);
			this->button12->TabIndex = 2;
			this->button12->Text = L"Delete";
			this->button12->UseVisualStyleBackColor = true;
			this->button12->Click += gcnew System::EventHandler(this, &Form1::button12_Click);
			// 
			// button11
			// 
			this->button11->Location = System::Drawing::Point(0, 30);
			this->button11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button11->Name = L"button11";
			this->button11->Size = System::Drawing::Size(74, 23);
			this->button11->TabIndex = 1;
			this->button11->Text = L"Save";
			this->button11->UseVisualStyleBackColor = true;
			this->button11->Click += gcnew System::EventHandler(this, &Form1::button11_Click);
			// 
			// button10
			// 
			this->button10->Location = System::Drawing::Point(0, 0);
			this->button10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->button10->Name = L"button10";
			this->button10->Size = System::Drawing::Size(74, 23);
			this->button10->TabIndex = 0;
			this->button10->Text = L"Load";
			this->button10->UseVisualStyleBackColor = true;
			this->button10->Click += gcnew System::EventHandler(this, &Form1::button10_Click);
			// 
			// tabPage14
			// 
			this->tabPage14->Controls->Add(this->splitContainer1);
			this->tabPage14->Location = System::Drawing::Point(4, 22);
			this->tabPage14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage14->Name = L"tabPage14";
			this->tabPage14->Size = System::Drawing::Size(1085, 609);
			this->tabPage14->TabIndex = 13;
			this->tabPage14->Text = L"Chart";
			this->tabPage14->UseVisualStyleBackColor = true;
			// 
			// splitContainer1
			// 
			this->splitContainer1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom) 
				| System::Windows::Forms::AnchorStyles::Left) 
				| System::Windows::Forms::AnchorStyles::Right));
			this->splitContainer1->Location = System::Drawing::Point(0, 0);
			this->splitContainer1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->splitContainer1->Name = L"splitContainer1";
			// 
			// splitContainer1.Panel1
			// 
			this->splitContainer1->Panel1->Controls->Add(this->chart1);
			// 
			// splitContainer1.Panel2
			// 
			this->splitContainer1->Panel2->Controls->Add(this->listBox36);
			this->splitContainer1->Panel2->Controls->Add(this->listBox35);
			this->splitContainer1->Panel2->Controls->Add(this->listBox34);
			this->splitContainer1->Panel2->Controls->Add(this->listBox32);
			this->splitContainer1->Panel2->Controls->Add(this->listBox33);
			this->splitContainer1->Panel2->Controls->Add(this->listBox29);
			this->splitContainer1->Panel2->Controls->Add(this->listBox30);
			this->splitContainer1->Panel2->Controls->Add(this->listBox31);
			this->splitContainer1->Panel2->Controls->Add(this->listBox22);
			this->splitContainer1->Panel2->Controls->Add(this->listBox23);
			this->splitContainer1->Panel2->Controls->Add(this->listBox24);
			this->splitContainer1->Panel2->Controls->Add(this->listBox25);
			this->splitContainer1->Panel2->Controls->Add(this->listBox26);
			this->splitContainer1->Panel2->Controls->Add(this->listBox27);
			this->splitContainer1->Panel2->Controls->Add(this->listBox28);
			this->splitContainer1->Panel2->Controls->Add(this->listBox15);
			this->splitContainer1->Panel2->Controls->Add(this->listBox16);
			this->splitContainer1->Panel2->Controls->Add(this->listBox17);
			this->splitContainer1->Panel2->Controls->Add(this->listBox18);
			this->splitContainer1->Panel2->Controls->Add(this->listBox19);
			this->splitContainer1->Panel2->Controls->Add(this->listBox20);
			this->splitContainer1->Panel2->Controls->Add(this->listBox21);
			this->splitContainer1->Panel2->Controls->Add(this->listBox8);
			this->splitContainer1->Panel2->Controls->Add(this->listBox9);
			this->splitContainer1->Panel2->Controls->Add(this->listBox10);
			this->splitContainer1->Panel2->Controls->Add(this->listBox11);
			this->splitContainer1->Panel2->Controls->Add(this->listBox12);
			this->splitContainer1->Panel2->Controls->Add(this->listBox13);
			this->splitContainer1->Panel2->Controls->Add(this->listBox14);
			this->splitContainer1->Panel2->Controls->Add(this->listBox7);
			this->splitContainer1->Panel2->Controls->Add(this->listBox6);
			this->splitContainer1->Panel2->Controls->Add(this->listBox5);
			this->splitContainer1->Panel2->Controls->Add(this->listBox4);
			this->splitContainer1->Panel2->Controls->Add(this->listBox3);
			this->splitContainer1->Panel2->Controls->Add(this->listBox2);
			this->splitContainer1->Panel2->Controls->Add(this->listBox1);
			this->splitContainer1->Panel2->Controls->Add(this->checkedListBox1);
			this->splitContainer1->Size = System::Drawing::Size(1089, 611);
			this->splitContainer1->SplitterDistance = 894;
			this->splitContainer1->TabIndex = 24;
			this->splitContainer1->ClientSizeChanged += gcnew System::EventHandler(this, &Form1::splitContainer1_ClientSizeChanged);
			// 
			// chart1
			// 
			chartArea3->AxisX->MinorGrid->Enabled = true;
			chartArea3->AxisY->MajorGrid->Interval = 0;
			chartArea3->AxisY->MinorGrid->Enabled = true;
			chartArea3->CursorX->IsUserEnabled = true;
			chartArea3->CursorX->IsUserSelectionEnabled = true;
			chartArea3->CursorY->IsUserEnabled = true;
			chartArea3->CursorY->IsUserSelectionEnabled = true;
			chartArea3->Name = L"ChartArea1";
			this->chart1->ChartAreas->Add(chartArea3);
			this->chart1->Dock = System::Windows::Forms::DockStyle::Fill;
			legend3->Name = L"Legend1";
			this->chart1->Legends->Add(legend3);
			this->chart1->Location = System::Drawing::Point(0, 0);
			this->chart1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->chart1->Name = L"chart1";
			this->chart1->Palette = System::Windows::Forms::DataVisualization::Charting::ChartColorPalette::Fire;
			series145->BorderWidth = 2;
			series145->ChartArea = L"ChartArea1";
			series145->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series145->Legend = L"Legend1";
			series145->Name = L"Gyro X";
			series146->BorderWidth = 2;
			series146->ChartArea = L"ChartArea1";
			series146->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series146->Legend = L"Legend1";
			series146->Name = L"Gyro Y";
			series147->BorderWidth = 2;
			series147->ChartArea = L"ChartArea1";
			series147->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series147->Legend = L"Legend1";
			series147->Name = L"Gyro Z";
			series148->BorderWidth = 2;
			series148->ChartArea = L"ChartArea1";
			series148->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series148->Legend = L"Legend1";
			series148->Name = L"Acc X";
			series149->BorderWidth = 2;
			series149->ChartArea = L"ChartArea1";
			series149->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series149->Legend = L"Legend1";
			series149->Name = L"Acc Y";
			series150->BorderWidth = 2;
			series150->ChartArea = L"ChartArea1";
			series150->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series150->Legend = L"Legend1";
			series150->Name = L"Acc Z";
			series151->BorderWidth = 2;
			series151->ChartArea = L"ChartArea1";
			series151->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series151->Legend = L"Legend1";
			series151->Name = L"Mag X";
			series152->BorderWidth = 2;
			series152->ChartArea = L"ChartArea1";
			series152->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series152->Legend = L"Legend1";
			series152->Name = L"Mag Y";
			series153->BorderWidth = 2;
			series153->ChartArea = L"ChartArea1";
			series153->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series153->Legend = L"Legend1";
			series153->Name = L"Mag Z";
			series154->BorderWidth = 2;
			series154->ChartArea = L"ChartArea1";
			series154->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series154->Legend = L"Legend1";
			series154->Name = L"IMU Pitch";
			series155->BorderWidth = 2;
			series155->ChartArea = L"ChartArea1";
			series155->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series155->Legend = L"Legend1";
			series155->Name = L"IMU Roll";
			series156->BorderWidth = 2;
			series156->ChartArea = L"ChartArea1";
			series156->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series156->Legend = L"Legend1";
			series156->Name = L"IMU Yaw";
			series157->BorderWidth = 2;
			series157->ChartArea = L"ChartArea1";
			series157->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series157->Legend = L"Legend1";
			series157->Name = L"Motor Front";
			series158->BorderWidth = 2;
			series158->ChartArea = L"ChartArea1";
			series158->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series158->Legend = L"Legend1";
			series158->Name = L"Motor Back";
			series159->BorderWidth = 2;
			series159->ChartArea = L"ChartArea1";
			series159->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series159->Legend = L"Legend1";
			series159->Name = L"Motor Left";
			series160->BorderWidth = 2;
			series160->ChartArea = L"ChartArea1";
			series160->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series160->Legend = L"Legend1";
			series160->Name = L"Motor Right";
			series161->BorderWidth = 2;
			series161->ChartArea = L"ChartArea1";
			series161->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series161->Legend = L"Legend1";
			series161->Name = L"Pressure";
			series162->BorderWidth = 2;
			series162->ChartArea = L"ChartArea1";
			series162->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series162->Legend = L"Legend1";
			series162->Name = L"PID Pitch";
			series163->BorderWidth = 2;
			series163->ChartArea = L"ChartArea1";
			series163->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series163->Legend = L"Legend1";
			series163->Name = L"PID Roll";
			series164->BorderWidth = 2;
			series164->ChartArea = L"ChartArea1";
			series164->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series164->Legend = L"Legend1";
			series164->Name = L"PID Throttle";
			series165->BorderWidth = 2;
			series165->ChartArea = L"ChartArea1";
			series165->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series165->Legend = L"Legend1";
			series165->Name = L"PID Yaw";
			series166->BorderWidth = 2;
			series166->ChartArea = L"ChartArea1";
			series166->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series166->Legend = L"Legend1";
			series166->Name = L"RC Channel 1";
			series167->BorderWidth = 2;
			series167->ChartArea = L"ChartArea1";
			series167->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series167->Legend = L"Legend1";
			series167->Name = L"RC Channel 2";
			series168->BorderWidth = 2;
			series168->ChartArea = L"ChartArea1";
			series168->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series168->Legend = L"Legend1";
			series168->Name = L"RC Channel 3";
			series169->BorderWidth = 2;
			series169->ChartArea = L"ChartArea1";
			series169->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series169->Legend = L"Legend1";
			series169->Name = L"RC Channel 4";
			series170->BorderWidth = 2;
			series170->ChartArea = L"ChartArea1";
			series170->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series170->Legend = L"Legend1";
			series170->Name = L"RC Channel 5";
			series171->BorderWidth = 2;
			series171->ChartArea = L"ChartArea1";
			series171->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series171->Legend = L"Legend1";
			series171->Name = L"RC Channel 6";
			series172->BorderWidth = 2;
			series172->ChartArea = L"ChartArea1";
			series172->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series172->Legend = L"Legend1";
			series172->Name = L"RC Channel 7";
			series173->BorderWidth = 2;
			series173->ChartArea = L"ChartArea1";
			series173->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series173->Legend = L"Legend1";
			series173->Name = L"RC Channel 8";
			series174->BorderWidth = 2;
			series174->ChartArea = L"ChartArea1";
			series174->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series174->Legend = L"Legend1";
			series174->Name = L"Gyro Temp";
			series175->BorderWidth = 2;
			series175->ChartArea = L"ChartArea1";
			series175->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Line;
			series175->Legend = L"Legend1";
			series175->Name = L"Altitude";
			series176->ChartArea = L"ChartArea1";
			series176->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series176->Enabled = false;
			series176->Legend = L"Legend1";
			series176->Name = L"Gyro X Orig";
			series177->ChartArea = L"ChartArea1";
			series177->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series177->Enabled = false;
			series177->Legend = L"Legend1";
			series177->Name = L"Gyro Y Orig";
			series178->ChartArea = L"ChartArea1";
			series178->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series178->Enabled = false;
			series178->Legend = L"Legend1";
			series178->Name = L"Gyro Z Orig";
			series179->ChartArea = L"ChartArea1";
			series179->Enabled = false;
			series179->Legend = L"Legend1";
			series179->Name = L"Acc X Orig";
			series180->ChartArea = L"ChartArea1";
			series180->Enabled = false;
			series180->Legend = L"Legend1";
			series180->Name = L"Acc Y Orig";
			series181->ChartArea = L"ChartArea1";
			series181->Enabled = false;
			series181->Legend = L"Legend1";
			series181->Name = L"Acc Z Orig";
			series182->ChartArea = L"ChartArea1";
			series182->Enabled = false;
			series182->Legend = L"Legend1";
			series182->Name = L"Mag X Orig";
			series183->ChartArea = L"ChartArea1";
			series183->Enabled = false;
			series183->Legend = L"Legend1";
			series183->Name = L"Mag Y Orig";
			series184->ChartArea = L"ChartArea1";
			series184->Enabled = false;
			series184->Legend = L"Legend1";
			series184->Name = L"Mag Z Orig";
			series185->ChartArea = L"ChartArea1";
			series185->Enabled = false;
			series185->Legend = L"Legend1";
			series185->Name = L"IMU Pitch Orig";
			series186->ChartArea = L"ChartArea1";
			series186->Enabled = false;
			series186->Legend = L"Legend1";
			series186->Name = L"IMU Roll Orig";
			series187->ChartArea = L"ChartArea1";
			series187->Enabled = false;
			series187->Legend = L"Legend1";
			series187->Name = L"IMU Yaw Orig";
			series188->ChartArea = L"ChartArea1";
			series188->Enabled = false;
			series188->Legend = L"Legend1";
			series188->Name = L"Motor Front Orig";
			series189->ChartArea = L"ChartArea1";
			series189->Enabled = false;
			series189->Legend = L"Legend1";
			series189->Name = L"Motor Back Orig";
			series190->ChartArea = L"ChartArea1";
			series190->Enabled = false;
			series190->Legend = L"Legend1";
			series190->Name = L"Motor Left Orig";
			series191->ChartArea = L"ChartArea1";
			series191->Enabled = false;
			series191->Legend = L"Legend1";
			series191->Name = L"Motor Right Orig";
			series192->ChartArea = L"ChartArea1";
			series192->Enabled = false;
			series192->Legend = L"Legend1";
			series192->Name = L"Pressure Orig";
			series193->ChartArea = L"ChartArea1";
			series193->Enabled = false;
			series193->Legend = L"Legend1";
			series193->Name = L"PID Pitch Orig";
			series194->ChartArea = L"ChartArea1";
			series194->Enabled = false;
			series194->Legend = L"Legend1";
			series194->Name = L"PID Roll Orig";
			series195->ChartArea = L"ChartArea1";
			series195->Enabled = false;
			series195->Legend = L"Legend1";
			series195->Name = L"PID Throttle Orig";
			series196->ChartArea = L"ChartArea1";
			series196->Enabled = false;
			series196->Legend = L"Legend1";
			series196->Name = L"PID Yaw Orig";
			series197->ChartArea = L"ChartArea1";
			series197->Enabled = false;
			series197->Legend = L"Legend1";
			series197->Name = L"RC Channel 1 Orig";
			series198->ChartArea = L"ChartArea1";
			series198->Enabled = false;
			series198->Legend = L"Legend1";
			series198->Name = L"RC Channel 2 Orig";
			series199->ChartArea = L"ChartArea1";
			series199->Enabled = false;
			series199->Legend = L"Legend1";
			series199->Name = L"RC Channel 3 Orig";
			series200->ChartArea = L"ChartArea1";
			series200->Enabled = false;
			series200->Legend = L"Legend1";
			series200->Name = L"RC Channel 4 Orig";
			series201->ChartArea = L"ChartArea1";
			series201->Enabled = false;
			series201->Legend = L"Legend1";
			series201->Name = L"RC Channel 5 Orig";
			series202->ChartArea = L"ChartArea1";
			series202->Enabled = false;
			series202->Legend = L"Legend1";
			series202->Name = L"RC Channel 6 Orig";
			series203->ChartArea = L"ChartArea1";
			series203->Enabled = false;
			series203->Legend = L"Legend1";
			series203->Name = L"RC Channel 7 Orig";
			series204->ChartArea = L"ChartArea1";
			series204->Enabled = false;
			series204->Legend = L"Legend1";
			series204->Name = L"RC Channel 8 Orig";
			series205->ChartArea = L"ChartArea1";
			series205->Enabled = false;
			series205->Legend = L"Legend1";
			series205->Name = L"Gyro Temp Orig";
			series206->ChartArea = L"ChartArea1";
			series206->Enabled = false;
			series206->Legend = L"Legend1";
			series206->Name = L"Altitude Orig";
			series207->BorderWidth = 2;
			series207->ChartArea = L"ChartArea1";
			series207->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series207->Legend = L"Legend1";
			series207->Name = L"IMU Pitch Rate";
			series208->ChartArea = L"ChartArea1";
			series208->Enabled = false;
			series208->Legend = L"Legend1";
			series208->Name = L"IMU Pitch Rate Orig";
			series209->BorderWidth = 2;
			series209->ChartArea = L"ChartArea1";
			series209->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series209->Legend = L"Legend1";
			series209->Name = L"IMU Roll Rate";
			series210->ChartArea = L"ChartArea1";
			series210->Enabled = false;
			series210->Legend = L"Legend1";
			series210->Name = L"IMU Roll Rate Orig";
			series211->BorderWidth = 2;
			series211->ChartArea = L"ChartArea1";
			series211->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series211->Legend = L"Legend1";
			series211->Name = L"IMU Yaw Rate";
			series212->ChartArea = L"ChartArea1";
			series212->Enabled = false;
			series212->Legend = L"Legend1";
			series212->Name = L"IMU Yaw Rate Orig";
			series213->BorderWidth = 2;
			series213->ChartArea = L"ChartArea1";
			series213->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series213->Legend = L"Legend1";
			series213->Name = L"Main Loop Time";
			series214->BorderWidth = 2;
			series214->ChartArea = L"ChartArea1";
			series214->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::FastLine;
			series214->Legend = L"Legend1";
			series214->Name = L"IMU Loop Time";
			series215->ChartArea = L"ChartArea1";
			series215->Enabled = false;
			series215->Legend = L"Legend1";
			series215->Name = L"Main Loop Time Orig";
			series216->ChartArea = L"ChartArea1";
			series216->Enabled = false;
			series216->Legend = L"Legend1";
			series216->Name = L"IMU Loop Time Orig";
			this->chart1->Series->Add(series145);
			this->chart1->Series->Add(series146);
			this->chart1->Series->Add(series147);
			this->chart1->Series->Add(series148);
			this->chart1->Series->Add(series149);
			this->chart1->Series->Add(series150);
			this->chart1->Series->Add(series151);
			this->chart1->Series->Add(series152);
			this->chart1->Series->Add(series153);
			this->chart1->Series->Add(series154);
			this->chart1->Series->Add(series155);
			this->chart1->Series->Add(series156);
			this->chart1->Series->Add(series157);
			this->chart1->Series->Add(series158);
			this->chart1->Series->Add(series159);
			this->chart1->Series->Add(series160);
			this->chart1->Series->Add(series161);
			this->chart1->Series->Add(series162);
			this->chart1->Series->Add(series163);
			this->chart1->Series->Add(series164);
			this->chart1->Series->Add(series165);
			this->chart1->Series->Add(series166);
			this->chart1->Series->Add(series167);
			this->chart1->Series->Add(series168);
			this->chart1->Series->Add(series169);
			this->chart1->Series->Add(series170);
			this->chart1->Series->Add(series171);
			this->chart1->Series->Add(series172);
			this->chart1->Series->Add(series173);
			this->chart1->Series->Add(series174);
			this->chart1->Series->Add(series175);
			this->chart1->Series->Add(series176);
			this->chart1->Series->Add(series177);
			this->chart1->Series->Add(series178);
			this->chart1->Series->Add(series179);
			this->chart1->Series->Add(series180);
			this->chart1->Series->Add(series181);
			this->chart1->Series->Add(series182);
			this->chart1->Series->Add(series183);
			this->chart1->Series->Add(series184);
			this->chart1->Series->Add(series185);
			this->chart1->Series->Add(series186);
			this->chart1->Series->Add(series187);
			this->chart1->Series->Add(series188);
			this->chart1->Series->Add(series189);
			this->chart1->Series->Add(series190);
			this->chart1->Series->Add(series191);
			this->chart1->Series->Add(series192);
			this->chart1->Series->Add(series193);
			this->chart1->Series->Add(series194);
			this->chart1->Series->Add(series195);
			this->chart1->Series->Add(series196);
			this->chart1->Series->Add(series197);
			this->chart1->Series->Add(series198);
			this->chart1->Series->Add(series199);
			this->chart1->Series->Add(series200);
			this->chart1->Series->Add(series201);
			this->chart1->Series->Add(series202);
			this->chart1->Series->Add(series203);
			this->chart1->Series->Add(series204);
			this->chart1->Series->Add(series205);
			this->chart1->Series->Add(series206);
			this->chart1->Series->Add(series207);
			this->chart1->Series->Add(series208);
			this->chart1->Series->Add(series209);
			this->chart1->Series->Add(series210);
			this->chart1->Series->Add(series211);
			this->chart1->Series->Add(series212);
			this->chart1->Series->Add(series213);
			this->chart1->Series->Add(series214);
			this->chart1->Series->Add(series215);
			this->chart1->Series->Add(series216);
			this->chart1->Size = System::Drawing::Size(894, 611);
			this->chart1->TabIndex = 0;
			this->chart1->Text = L"chart1";
			// 
			// listBox36
			// 
			this->listBox36->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox36->FormattingEnabled = true;
			this->listBox36->ItemHeight = 12;
			this->listBox36->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox36->Location = System::Drawing::Point(111, 567);
			this->listBox36->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox36->Name = L"listBox36";
			this->listBox36->Size = System::Drawing::Size(64, 16);
			this->listBox36->TabIndex = 61;
			this->listBox36->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox36_SelectedIndexChanged);
			// 
			// listBox35
			// 
			this->listBox35->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox35->FormattingEnabled = true;
			this->listBox35->ItemHeight = 12;
			this->listBox35->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox35->Location = System::Drawing::Point(111, 551);
			this->listBox35->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox35->Name = L"listBox35";
			this->listBox35->Size = System::Drawing::Size(64, 16);
			this->listBox35->TabIndex = 60;
			this->listBox35->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox35_SelectedIndexChanged);
			// 
			// listBox34
			// 
			this->listBox34->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox34->FormattingEnabled = true;
			this->listBox34->ItemHeight = 12;
			this->listBox34->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox34->Location = System::Drawing::Point(111, 535);
			this->listBox34->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox34->Name = L"listBox34";
			this->listBox34->Size = System::Drawing::Size(64, 16);
			this->listBox34->TabIndex = 59;
			this->listBox34->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox34_SelectedIndexChanged);
			// 
			// listBox32
			// 
			this->listBox32->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox32->FormattingEnabled = true;
			this->listBox32->ItemHeight = 12;
			this->listBox32->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox32->Location = System::Drawing::Point(111, 519);
			this->listBox32->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox32->Name = L"listBox32";
			this->listBox32->Size = System::Drawing::Size(64, 16);
			this->listBox32->TabIndex = 58;
			this->listBox32->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox32_SelectedIndexChanged);
			// 
			// listBox33
			// 
			this->listBox33->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox33->FormattingEnabled = true;
			this->listBox33->ItemHeight = 12;
			this->listBox33->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox33->Location = System::Drawing::Point(111, 503);
			this->listBox33->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox33->Name = L"listBox33";
			this->listBox33->Size = System::Drawing::Size(64, 16);
			this->listBox33->TabIndex = 57;
			this->listBox33->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox33_SelectedIndexChanged);
			// 
			// listBox29
			// 
			this->listBox29->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox29->FormattingEnabled = true;
			this->listBox29->ItemHeight = 12;
			this->listBox29->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox29->Location = System::Drawing::Point(111, 487);
			this->listBox29->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox29->Name = L"listBox29";
			this->listBox29->Size = System::Drawing::Size(64, 16);
			this->listBox29->TabIndex = 56;
			this->listBox29->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox29_SelectedIndexChanged);
			// 
			// listBox30
			// 
			this->listBox30->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox30->FormattingEnabled = true;
			this->listBox30->ItemHeight = 12;
			this->listBox30->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox30->Location = System::Drawing::Point(111, 471);
			this->listBox30->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox30->Name = L"listBox30";
			this->listBox30->Size = System::Drawing::Size(64, 16);
			this->listBox30->TabIndex = 55;
			this->listBox30->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox30_SelectedIndexChanged);
			// 
			// listBox31
			// 
			this->listBox31->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox31->FormattingEnabled = true;
			this->listBox31->ItemHeight = 12;
			this->listBox31->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox31->Location = System::Drawing::Point(111, 455);
			this->listBox31->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox31->Name = L"listBox31";
			this->listBox31->Size = System::Drawing::Size(64, 16);
			this->listBox31->TabIndex = 54;
			this->listBox31->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox31_SelectedIndexChanged);
			// 
			// listBox22
			// 
			this->listBox22->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox22->FormattingEnabled = true;
			this->listBox22->ItemHeight = 12;
			this->listBox22->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox22->Location = System::Drawing::Point(111, 439);
			this->listBox22->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox22->Name = L"listBox22";
			this->listBox22->Size = System::Drawing::Size(64, 16);
			this->listBox22->TabIndex = 53;
			this->listBox22->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox22_SelectedIndexChanged);
			// 
			// listBox23
			// 
			this->listBox23->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox23->FormattingEnabled = true;
			this->listBox23->ItemHeight = 12;
			this->listBox23->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox23->Location = System::Drawing::Point(111, 422);
			this->listBox23->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox23->Name = L"listBox23";
			this->listBox23->Size = System::Drawing::Size(64, 16);
			this->listBox23->TabIndex = 52;
			this->listBox23->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox23_SelectedIndexChanged);
			// 
			// listBox24
			// 
			this->listBox24->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox24->FormattingEnabled = true;
			this->listBox24->ItemHeight = 12;
			this->listBox24->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox24->Location = System::Drawing::Point(111, 407);
			this->listBox24->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox24->Name = L"listBox24";
			this->listBox24->Size = System::Drawing::Size(64, 16);
			this->listBox24->TabIndex = 51;
			this->listBox24->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox24_SelectedIndexChanged);
			// 
			// listBox25
			// 
			this->listBox25->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox25->FormattingEnabled = true;
			this->listBox25->ItemHeight = 12;
			this->listBox25->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox25->Location = System::Drawing::Point(111, 391);
			this->listBox25->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox25->Name = L"listBox25";
			this->listBox25->Size = System::Drawing::Size(64, 16);
			this->listBox25->TabIndex = 50;
			this->listBox25->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox25_SelectedIndexChanged);
			// 
			// listBox26
			// 
			this->listBox26->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox26->FormattingEnabled = true;
			this->listBox26->ItemHeight = 12;
			this->listBox26->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox26->Location = System::Drawing::Point(111, 375);
			this->listBox26->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox26->Name = L"listBox26";
			this->listBox26->Size = System::Drawing::Size(64, 16);
			this->listBox26->TabIndex = 49;
			this->listBox26->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox26_SelectedIndexChanged);
			// 
			// listBox27
			// 
			this->listBox27->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox27->FormattingEnabled = true;
			this->listBox27->ItemHeight = 12;
			this->listBox27->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox27->Location = System::Drawing::Point(111, 360);
			this->listBox27->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox27->Name = L"listBox27";
			this->listBox27->Size = System::Drawing::Size(64, 16);
			this->listBox27->TabIndex = 48;
			this->listBox27->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox27_SelectedIndexChanged);
			// 
			// listBox28
			// 
			this->listBox28->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox28->FormattingEnabled = true;
			this->listBox28->ItemHeight = 12;
			this->listBox28->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox28->Location = System::Drawing::Point(111, 343);
			this->listBox28->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox28->Name = L"listBox28";
			this->listBox28->Size = System::Drawing::Size(64, 16);
			this->listBox28->TabIndex = 47;
			this->listBox28->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox28_SelectedIndexChanged);
			// 
			// listBox15
			// 
			this->listBox15->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox15->FormattingEnabled = true;
			this->listBox15->ItemHeight = 12;
			this->listBox15->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox15->Location = System::Drawing::Point(111, 327);
			this->listBox15->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox15->Name = L"listBox15";
			this->listBox15->Size = System::Drawing::Size(64, 16);
			this->listBox15->TabIndex = 46;
			this->listBox15->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox15_SelectedIndexChanged);
			// 
			// listBox16
			// 
			this->listBox16->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox16->FormattingEnabled = true;
			this->listBox16->ItemHeight = 12;
			this->listBox16->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox16->Location = System::Drawing::Point(111, 310);
			this->listBox16->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox16->Name = L"listBox16";
			this->listBox16->Size = System::Drawing::Size(64, 16);
			this->listBox16->TabIndex = 45;
			this->listBox16->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox16_SelectedIndexChanged);
			// 
			// listBox17
			// 
			this->listBox17->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox17->FormattingEnabled = true;
			this->listBox17->ItemHeight = 12;
			this->listBox17->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox17->Location = System::Drawing::Point(111, 295);
			this->listBox17->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox17->Name = L"listBox17";
			this->listBox17->Size = System::Drawing::Size(64, 16);
			this->listBox17->TabIndex = 44;
			this->listBox17->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox17_SelectedIndexChanged);
			// 
			// listBox18
			// 
			this->listBox18->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox18->FormattingEnabled = true;
			this->listBox18->ItemHeight = 12;
			this->listBox18->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox18->Location = System::Drawing::Point(111, 279);
			this->listBox18->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox18->Name = L"listBox18";
			this->listBox18->Size = System::Drawing::Size(64, 16);
			this->listBox18->TabIndex = 43;
			this->listBox18->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox18_SelectedIndexChanged);
			// 
			// listBox19
			// 
			this->listBox19->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox19->FormattingEnabled = true;
			this->listBox19->ItemHeight = 12;
			this->listBox19->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox19->Location = System::Drawing::Point(111, 264);
			this->listBox19->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox19->Name = L"listBox19";
			this->listBox19->Size = System::Drawing::Size(64, 16);
			this->listBox19->TabIndex = 42;
			this->listBox19->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox19_SelectedIndexChanged);
			// 
			// listBox20
			// 
			this->listBox20->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox20->FormattingEnabled = true;
			this->listBox20->ItemHeight = 12;
			this->listBox20->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox20->Location = System::Drawing::Point(111, 247);
			this->listBox20->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox20->Name = L"listBox20";
			this->listBox20->Size = System::Drawing::Size(64, 16);
			this->listBox20->TabIndex = 41;
			this->listBox20->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox20_SelectedIndexChanged);
			// 
			// listBox21
			// 
			this->listBox21->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox21->FormattingEnabled = true;
			this->listBox21->ItemHeight = 12;
			this->listBox21->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox21->Location = System::Drawing::Point(111, 231);
			this->listBox21->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox21->Name = L"listBox21";
			this->listBox21->Size = System::Drawing::Size(64, 16);
			this->listBox21->TabIndex = 40;
			this->listBox21->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox21_SelectedIndexChanged);
			// 
			// listBox8
			// 
			this->listBox8->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox8->FormattingEnabled = true;
			this->listBox8->ItemHeight = 12;
			this->listBox8->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox8->Location = System::Drawing::Point(111, 214);
			this->listBox8->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox8->Name = L"listBox8";
			this->listBox8->Size = System::Drawing::Size(64, 16);
			this->listBox8->TabIndex = 39;
			this->listBox8->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox8_SelectedIndexChanged);
			// 
			// listBox9
			// 
			this->listBox9->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox9->FormattingEnabled = true;
			this->listBox9->ItemHeight = 12;
			this->listBox9->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox9->Location = System::Drawing::Point(111, 199);
			this->listBox9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox9->Name = L"listBox9";
			this->listBox9->Size = System::Drawing::Size(64, 16);
			this->listBox9->TabIndex = 38;
			this->listBox9->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox9_SelectedIndexChanged);
			// 
			// listBox10
			// 
			this->listBox10->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox10->FormattingEnabled = true;
			this->listBox10->ItemHeight = 12;
			this->listBox10->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox10->Location = System::Drawing::Point(111, 183);
			this->listBox10->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox10->Name = L"listBox10";
			this->listBox10->Size = System::Drawing::Size(64, 16);
			this->listBox10->TabIndex = 37;
			this->listBox10->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox10_SelectedIndexChanged);
			// 
			// listBox11
			// 
			this->listBox11->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox11->FormattingEnabled = true;
			this->listBox11->ItemHeight = 12;
			this->listBox11->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox11->Location = System::Drawing::Point(111, 167);
			this->listBox11->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox11->Name = L"listBox11";
			this->listBox11->Size = System::Drawing::Size(64, 16);
			this->listBox11->TabIndex = 36;
			this->listBox11->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox11_SelectedIndexChanged);
			// 
			// listBox12
			// 
			this->listBox12->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox12->FormattingEnabled = true;
			this->listBox12->ItemHeight = 12;
			this->listBox12->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox12->Location = System::Drawing::Point(111, 152);
			this->listBox12->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox12->Name = L"listBox12";
			this->listBox12->Size = System::Drawing::Size(64, 16);
			this->listBox12->TabIndex = 35;
			this->listBox12->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox12_SelectedIndexChanged);
			// 
			// listBox13
			// 
			this->listBox13->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox13->FormattingEnabled = true;
			this->listBox13->ItemHeight = 12;
			this->listBox13->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox13->Location = System::Drawing::Point(111, 135);
			this->listBox13->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox13->Name = L"listBox13";
			this->listBox13->Size = System::Drawing::Size(64, 16);
			this->listBox13->TabIndex = 34;
			this->listBox13->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox13_SelectedIndexChanged);
			// 
			// listBox14
			// 
			this->listBox14->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox14->FormattingEnabled = true;
			this->listBox14->ItemHeight = 12;
			this->listBox14->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox14->Location = System::Drawing::Point(111, 119);
			this->listBox14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox14->Name = L"listBox14";
			this->listBox14->Size = System::Drawing::Size(64, 16);
			this->listBox14->TabIndex = 33;
			this->listBox14->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox14_SelectedIndexChanged);
			// 
			// listBox7
			// 
			this->listBox7->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox7->FormattingEnabled = true;
			this->listBox7->ItemHeight = 12;
			this->listBox7->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox7->Location = System::Drawing::Point(111, 102);
			this->listBox7->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox7->Name = L"listBox7";
			this->listBox7->Size = System::Drawing::Size(64, 16);
			this->listBox7->TabIndex = 32;
			this->listBox7->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox7_SelectedIndexChanged);
			// 
			// listBox6
			// 
			this->listBox6->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox6->FormattingEnabled = true;
			this->listBox6->ItemHeight = 12;
			this->listBox6->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox6->Location = System::Drawing::Point(111, 87);
			this->listBox6->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox6->Name = L"listBox6";
			this->listBox6->Size = System::Drawing::Size(64, 16);
			this->listBox6->TabIndex = 31;
			this->listBox6->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox6_SelectedIndexChanged);
			// 
			// listBox5
			// 
			this->listBox5->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox5->FormattingEnabled = true;
			this->listBox5->ItemHeight = 12;
			this->listBox5->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox5->Location = System::Drawing::Point(111, 71);
			this->listBox5->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox5->Name = L"listBox5";
			this->listBox5->Size = System::Drawing::Size(64, 16);
			this->listBox5->TabIndex = 30;
			this->listBox5->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox5_SelectedIndexChanged);
			// 
			// listBox4
			// 
			this->listBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox4->FormattingEnabled = true;
			this->listBox4->ItemHeight = 12;
			this->listBox4->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox4->Location = System::Drawing::Point(111, 56);
			this->listBox4->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox4->Name = L"listBox4";
			this->listBox4->Size = System::Drawing::Size(64, 16);
			this->listBox4->TabIndex = 29;
			this->listBox4->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox4_SelectedIndexChanged);
			// 
			// listBox3
			// 
			this->listBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox3->FormattingEnabled = true;
			this->listBox3->ItemHeight = 12;
			this->listBox3->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox3->Location = System::Drawing::Point(111, 39);
			this->listBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox3->Name = L"listBox3";
			this->listBox3->Size = System::Drawing::Size(64, 16);
			this->listBox3->TabIndex = 28;
			this->listBox3->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox3_SelectedIndexChanged);
			// 
			// listBox2
			// 
			this->listBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox2->FormattingEnabled = true;
			this->listBox2->ItemHeight = 12;
			this->listBox2->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox2->Location = System::Drawing::Point(111, 23);
			this->listBox2->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox2->Name = L"listBox2";
			this->listBox2->Size = System::Drawing::Size(64, 16);
			this->listBox2->TabIndex = 27;
			this->listBox2->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox2_SelectedIndexChanged);
			// 
			// listBox1
			// 
			this->listBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 6.75F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->listBox1->FormattingEnabled = true;
			this->listBox1->ItemHeight = 12;
			this->listBox1->Items->AddRange(gcnew cli::array< System::Object^  >(9) {L"0.0001", L"0.001", L"0.01", L"0.1", L"1", L"10", 
				L"100", L"1000", L"10000"});
			this->listBox1->Location = System::Drawing::Point(111, 6);
			this->listBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->listBox1->Name = L"listBox1";
			this->listBox1->Size = System::Drawing::Size(64, 16);
			this->listBox1->TabIndex = 26;
			this->listBox1->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::listBox1_SelectedIndexChanged);
			// 
			// checkedListBox1
			// 
			this->checkedListBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom) 
				| System::Windows::Forms::AnchorStyles::Left));
			this->checkedListBox1->CheckOnClick = true;
			this->checkedListBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point, 
				static_cast<System::Byte>(0)));
			this->checkedListBox1->FormattingEnabled = true;
			this->checkedListBox1->Items->AddRange(gcnew cli::array< System::Object^  >(36) {L"Gyro X", L"Gyro Y", L"Gyro Z", L"Acc X", 
				L"Acc Y", L"Acc Z", L"Mag X", L"Mag Y", L"Mag Z", L"Pressure", L"IMU Pitch", L"IMU Roll", L"IMU Yaw", L"Motor Front", L"Motor Back", 
				L"Motor Left", L"Motor Right", L"PID Pitch", L"PID Roll", L"PID Throttle", L"PID Yaw", L"RC Channel 1", L"RC Channel 2", L"RC Channel 3", 
				L"RC Channel 4", L"RC Channel 5", L"RC Channel 6", L"RC Channel 7", L"RC Channel 8", L"Gyro Temp", L"Altitude", L"IMU Pitch Rate", 
				L"IMU Roll Rate", L"IMU Yaw Rate", L"Main Loop Time", L"IMU Loop Time"});
			this->checkedListBox1->Location = System::Drawing::Point(2, 6);
			this->checkedListBox1->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkedListBox1->Name = L"checkedListBox1";
			this->checkedListBox1->Size = System::Drawing::Size(105, 580);
			this->checkedListBox1->TabIndex = 23;
			this->checkedListBox1->SelectedIndexChanged += gcnew System::EventHandler(this, &Form1::checkedListBox1_SelectedIndexChanged);
			// 
			// tabPage9
			// 
			this->tabPage9->Controls->Add(this->pictureBox3);
			this->tabPage9->Controls->Add(this->label33);
			this->tabPage9->Controls->Add(this->label32);
			this->tabPage9->Controls->Add(this->label14);
			this->tabPage9->Location = System::Drawing::Point(4, 22);
			this->tabPage9->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->tabPage9->Name = L"tabPage9";
			this->tabPage9->Size = System::Drawing::Size(1085, 609);
			this->tabPage9->TabIndex = 8;
			this->tabPage9->Text = L"About";
			this->tabPage9->UseVisualStyleBackColor = true;
			// 
			// pictureBox3
			// 
			this->pictureBox3->Image = (cli::safe_cast<System::Drawing::Image^  >(resources->GetObject(L"pictureBox3.Image")));
			this->pictureBox3->InitialImage = (cli::safe_cast<System::Drawing::Image^  >(resources->GetObject(L"pictureBox3.InitialImage")));
			this->pictureBox3->Location = System::Drawing::Point(55, 144);
			this->pictureBox3->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->pictureBox3->Name = L"pictureBox3";
			this->pictureBox3->Size = System::Drawing::Size(674, 372);
			this->pictureBox3->TabIndex = 3;
			this->pictureBox3->TabStop = false;
			// 
			// label33
			// 
			this->label33->AutoSize = true;
			this->label33->Location = System::Drawing::Point(52, 122);
			this->label33->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label33->Name = L"label33";
			this->label33->Size = System::Drawing::Size(57, 13);
			this->label33->TabIndex = 2;
			this->label33->Text = L"June 2010";
			// 
			// label32
			// 
			this->label32->AutoSize = true;
			this->label32->Location = System::Drawing::Point(52, 83);
			this->label32->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label32->Name = L"label32";
			this->label32->Size = System::Drawing::Size(112, 13);
			this->label32->TabIndex = 1;
			this->label32->Text = L"Tim Moore (Timmoore)";
			// 
			// label14
			// 
			this->label14->AutoSize = true;
			this->label14->Location = System::Drawing::Point(52, 47);
			this->label14->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label14->Name = L"label14";
			this->label14->Size = System::Drawing::Size(306, 13);
			this->label14->TabIndex = 0;
			this->label14->Text = L"Quadcopter Propeller confguration and diagnostic console V1.0";
			// 
			// serialPort1
			// 
			this->serialPort1->BaudRate = 115200;
			this->serialPort1->StopBits = System::IO::Ports::StopBits::Two;
			// 
			// saveFileDialog1
			// 
			this->saveFileDialog1->FileName = L"quadcapture.txt";
			// 
			// openFileDialog1
			// 
			this->openFileDialog1->FileName = L"quadcapture.txt";
			// 
			// statusStrip1
			// 
			this->statusStrip1->Items->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(8) {this->toolStripSplitButton1, 
				this->toolStripStatusLabel2, this->toolStripStatusLabel3, this->toolStripStatusLabel4, this->toolStripStatusLabel5, this->toolStripStatusLabel6, 
				this->toolStripStatusLabel7, this->toolStripStatusLabel8});
			this->statusStrip1->Location = System::Drawing::Point(0, 637);
			this->statusStrip1->Name = L"statusStrip1";
			this->statusStrip1->Size = System::Drawing::Size(1093, 22);
			this->statusStrip1->TabIndex = 1;
			this->statusStrip1->Text = L"statusStrip1";
			// 
			// toolStripSplitButton1
			// 
			this->toolStripSplitButton1->AutoSize = false;
			this->toolStripSplitButton1->DisplayStyle = System::Windows::Forms::ToolStripItemDisplayStyle::Text;
			this->toolStripSplitButton1->Image = (cli::safe_cast<System::Drawing::Image^  >(resources->GetObject(L"toolStripSplitButton1.Image")));
			this->toolStripSplitButton1->ImageTransparentColor = System::Drawing::Color::Magenta;
			this->toolStripSplitButton1->Name = L"toolStripSplitButton1";
			this->toolStripSplitButton1->Size = System::Drawing::Size(82, 20);
			this->toolStripSplitButton1->Text = L"Disconnect";
			this->toolStripSplitButton1->ButtonClick += gcnew System::EventHandler(this, &Form1::toolStripSplitButton1_ButtonClick);
			this->toolStripSplitButton1->DropDownOpening += gcnew System::EventHandler(this, &Form1::toolStripSplitButton1_Opening);
			this->toolStripSplitButton1->DropDownItemClicked += gcnew System::Windows::Forms::ToolStripItemClickedEventHandler(this, &Form1::toolStripDropDownButton1_DropDownItemClicked);
			// 
			// toolStripStatusLabel2
			// 
			this->toolStripStatusLabel2->AutoSize = false;
			this->toolStripStatusLabel2->AutoToolTip = true;
			this->toolStripStatusLabel2->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel2->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel2->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel2->Name = L"toolStripStatusLabel2";
			this->toolStripStatusLabel2->Size = System::Drawing::Size(136, 17);
			this->toolStripStatusLabel2->Text = L"Configuration Modified";
			this->toolStripStatusLabel2->ToolTipText = L"Configuration status";
			// 
			// toolStripStatusLabel3
			// 
			this->toolStripStatusLabel3->AutoSize = false;
			this->toolStripStatusLabel3->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel3->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel3->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel3->Name = L"toolStripStatusLabel3";
			this->toolStripStatusLabel3->Size = System::Drawing::Size(128, 17);
			this->toolStripStatusLabel3->Text = L"Waypoint map loaded";
			this->toolStripStatusLabel3->ToolTipText = L"Waypoint status";
			// 
			// toolStripStatusLabel4
			// 
			this->toolStripStatusLabel4->AutoSize = false;
			this->toolStripStatusLabel4->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel4->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel4->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel4->Name = L"toolStripStatusLabel4";
			this->toolStripStatusLabel4->Size = System::Drawing::Size(51, 17);
			this->toolStripStatusLabel4->Text = L"Logging";
			this->toolStripStatusLabel4->ToolTipText = L"Logging status";
			// 
			// toolStripStatusLabel5
			// 
			this->toolStripStatusLabel5->AutoSize = false;
			this->toolStripStatusLabel5->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel5->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel5->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel5->Name = L"toolStripStatusLabel5";
			this->toolStripStatusLabel5->Size = System::Drawing::Size(33, 17);
			this->toolStripStatusLabel5->Text = L"Hold";
			this->toolStripStatusLabel5->ToolTipText = L"Altitude hold";
			// 
			// toolStripStatusLabel6
			// 
			this->toolStripStatusLabel6->AutoSize = false;
			this->toolStripStatusLabel6->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel6->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel6->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel6->Name = L"toolStripStatusLabel6";
			this->toolStripStatusLabel6->Size = System::Drawing::Size(35, 17);
			this->toolStripStatusLabel6->Text = L"10.0V";
			this->toolStripStatusLabel6->ToolTipText = L"Battery Voltage";
			// 
			// toolStripStatusLabel7
			// 
			this->toolStripStatusLabel7->AutoSize = false;
			this->toolStripStatusLabel7->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel7->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel7->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel7->Name = L"toolStripStatusLabel7";
			this->toolStripStatusLabel7->Size = System::Drawing::Size(169, 17);
			this->toolStripStatusLabel7->Text = L"P: 000.000 R: 000.000 Y: 000.000";
			this->toolStripStatusLabel7->ToolTipText = L"IMU angles";
			// 
			// toolStripStatusLabel8
			// 
			this->toolStripStatusLabel8->AutoSize = false;
			this->toolStripStatusLabel8->BorderSides = static_cast<System::Windows::Forms::ToolStripStatusLabelBorderSides>((System::Windows::Forms::ToolStripStatusLabelBorderSides::Left | System::Windows::Forms::ToolStripStatusLabelBorderSides::Right));
			this->toolStripStatusLabel8->BorderStyle = System::Windows::Forms::Border3DStyle::RaisedOuter;
			this->toolStripStatusLabel8->ImageScaling = System::Windows::Forms::ToolStripItemImageScaling::None;
			this->toolStripStatusLabel8->Name = L"toolStripStatusLabel8";
			this->toolStripStatusLabel8->Size = System::Drawing::Size(150, 17);
			this->toolStripStatusLabel8->Text = L"F:-500 B:-500 L:-500 R:-500";
			this->toolStripStatusLabel8->ToolTipText = L"Motor Speeds";
			// 
			// groupBox14
			// 
			this->groupBox14->Controls->Add(this->label87);
			this->groupBox14->Controls->Add(this->label88);
			this->groupBox14->Controls->Add(this->checkBox21);
			this->groupBox14->Controls->Add(this->checkBox22);
			this->groupBox14->Controls->Add(this->checkBox23);
			this->groupBox14->Controls->Add(this->label89);
			this->groupBox14->Controls->Add(this->label90);
			this->groupBox14->Controls->Add(this->label91);
			this->groupBox14->Controls->Add(this->numericUpDown32);
			this->groupBox14->Controls->Add(this->numericUpDown34);
			this->groupBox14->Controls->Add(this->numericUpDown35);
			this->groupBox14->Location = System::Drawing::Point(500, 246);
			this->groupBox14->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox14->Name = L"groupBox14";
			this->groupBox14->Padding = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->groupBox14->Size = System::Drawing::Size(218, 121);
			this->groupBox14->TabIndex = 21;
			this->groupBox14->TabStop = false;
			this->groupBox14->Text = L"AHRS";
			// 
			// label87
			// 
			this->label87->AutoSize = true;
			this->label87->Location = System::Drawing::Point(140, 21);
			this->label87->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label87->Name = L"label87";
			this->label87->Size = System::Drawing::Size(33, 13);
			this->label87->TabIndex = 18;
			this->label87->Text = L"invert";
			// 
			// label88
			// 
			this->label88->AutoSize = true;
			this->label88->Location = System::Drawing::Point(10, 21);
			this->label88->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label88->Name = L"label88";
			this->label88->Size = System::Drawing::Size(25, 13);
			this->label88->TabIndex = 17;
			this->label88->Text = L"axis";
			// 
			// checkBox21
			// 
			this->checkBox21->AutoSize = true;
			this->checkBox21->Location = System::Drawing::Point(149, 92);
			this->checkBox21->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox21->Name = L"checkBox21";
			this->checkBox21->Size = System::Drawing::Size(15, 14);
			this->checkBox21->TabIndex = 7;
			this->checkBox21->UseVisualStyleBackColor = true;
			// 
			// checkBox22
			// 
			this->checkBox22->AutoSize = true;
			this->checkBox22->Location = System::Drawing::Point(149, 66);
			this->checkBox22->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox22->Name = L"checkBox22";
			this->checkBox22->Size = System::Drawing::Size(15, 14);
			this->checkBox22->TabIndex = 7;
			this->checkBox22->UseVisualStyleBackColor = true;
			// 
			// checkBox23
			// 
			this->checkBox23->AutoSize = true;
			this->checkBox23->Location = System::Drawing::Point(149, 42);
			this->checkBox23->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->checkBox23->Name = L"checkBox23";
			this->checkBox23->Size = System::Drawing::Size(15, 14);
			this->checkBox23->TabIndex = 6;
			this->checkBox23->UseVisualStyleBackColor = true;
			this->checkBox23->CheckedChanged += gcnew System::EventHandler(this, &Form1::checkBox23_CheckedChanged);
			// 
			// label89
			// 
			this->label89->AutoSize = true;
			this->label89->Location = System::Drawing::Point(181, 94);
			this->label89->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label89->Name = L"label89";
			this->label89->Size = System::Drawing::Size(14, 13);
			this->label89->TabIndex = 5;
			this->label89->Text = L"Z";
			// 
			// label90
			// 
			this->label90->AutoSize = true;
			this->label90->Location = System::Drawing::Point(181, 66);
			this->label90->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label90->Name = L"label90";
			this->label90->Size = System::Drawing::Size(14, 13);
			this->label90->TabIndex = 4;
			this->label90->Text = L"Y";
			// 
			// label91
			// 
			this->label91->AutoSize = true;
			this->label91->Location = System::Drawing::Point(182, 42);
			this->label91->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
			this->label91->Name = L"label91";
			this->label91->Size = System::Drawing::Size(14, 13);
			this->label91->TabIndex = 3;
			this->label91->Text = L"X";
			// 
			// numericUpDown32
			// 
			this->numericUpDown32->Location = System::Drawing::Point(8, 92);
			this->numericUpDown32->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown32->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown32->Name = L"numericUpDown32";
			this->numericUpDown32->Size = System::Drawing::Size(120, 20);
			this->numericUpDown32->TabIndex = 2;
			// 
			// numericUpDown34
			// 
			this->numericUpDown34->Location = System::Drawing::Point(8, 65);
			this->numericUpDown34->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown34->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown34->Name = L"numericUpDown34";
			this->numericUpDown34->Size = System::Drawing::Size(120, 20);
			this->numericUpDown34->TabIndex = 1;
			// 
			// numericUpDown35
			// 
			this->numericUpDown35->Location = System::Drawing::Point(8, 38);
			this->numericUpDown35->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->numericUpDown35->Maximum = System::Decimal(gcnew cli::array< System::Int32 >(4) {2, 0, 0, 0});
			this->numericUpDown35->Name = L"numericUpDown35";
			this->numericUpDown35->Size = System::Drawing::Size(120, 20);
			this->numericUpDown35->TabIndex = 0;
			this->numericUpDown35->ValueChanged += gcnew System::EventHandler(this, &Form1::numericUpDown35_ValueChanged);
			// 
			// Form1
			// 
			this->AutoScaleDimensions = System::Drawing::SizeF(6, 13);
			this->AutoScaleMode = System::Windows::Forms::AutoScaleMode::Font;
			this->ClientSize = System::Drawing::Size(1093, 659);
			this->Controls->Add(this->statusStrip1);
			this->Controls->Add(this->tabControl1);
			this->Icon = (cli::safe_cast<System::Drawing::Icon^  >(resources->GetObject(L"$this.Icon")));
			this->Margin = System::Windows::Forms::Padding(2, 3, 2, 3);
			this->Name = L"Form1";
			this->Text = L"QuadConsole";
			this->WindowState = System::Windows::Forms::FormWindowState::Minimized;
			this->FormClosing += gcnew System::Windows::Forms::FormClosingEventHandler(this, &Form1::Form1_FormClosing);
			this->Load += gcnew System::EventHandler(this, &Form1::Form1_Load);
			this->Shown += gcnew System::EventHandler(this, &Form1::Form1_Shown);
			this->tabControl1->ResumeLayout(false);
			this->tabPage1->ResumeLayout(false);
			this->tabPage1->PerformLayout();
			this->groupBox12->ResumeLayout(false);
			this->groupBox12->PerformLayout();
			this->groupBox4->ResumeLayout(false);
			this->groupBox5->ResumeLayout(false);
			this->tabPage2->ResumeLayout(false);
			this->tabPage3->ResumeLayout(false);
			this->tabPage3->PerformLayout();
			this->groupBox7->ResumeLayout(false);
			this->groupBox7->PerformLayout();
			this->tabPage4->ResumeLayout(false);
			this->tabPage4->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar18))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar17))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar16))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar15))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar14))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar13))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar12))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar11))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown12))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown11))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown10))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown9))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown8))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown7))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown6))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown5))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown4))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown3))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown2))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown1))->EndInit();
			this->tabPage5->ResumeLayout(false);
			this->tabPage5->PerformLayout();
			this->tabPage6->ResumeLayout(false);
			this->tabPage6->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown14))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown13))->EndInit();
			this->groupBox8->ResumeLayout(false);
			this->groupBox8->PerformLayout();
			this->tabPage7->ResumeLayout(false);
			this->tabPage7->PerformLayout();
			this->groupBox10->ResumeLayout(false);
			this->groupBox10->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown15))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown16))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown17))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown18))->EndInit();
			this->groupBox9->ResumeLayout(false);
			this->groupBox9->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown20))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown19))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown21))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown22))->EndInit();
			this->tabPage8->ResumeLayout(false);
			this->groupBox13->ResumeLayout(false);
			this->groupBox13->PerformLayout();
			this->groupBox11->ResumeLayout(false);
			this->groupBox11->PerformLayout();
			this->groupBox6->ResumeLayout(false);
			this->groupBox6->PerformLayout();
			this->groupBox3->ResumeLayout(false);
			this->groupBox3->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown29))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown30))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown31))->EndInit();
			this->groupBox2->ResumeLayout(false);
			this->groupBox2->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown26))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown27))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown28))->EndInit();
			this->groupBox1->ResumeLayout(false);
			this->groupBox1->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown25))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown24))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown23))->EndInit();
			this->tabPage15->ResumeLayout(false);
			this->tabPage10->ResumeLayout(false);
			this->tabPage11->ResumeLayout(false);
			this->tabPage11->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar10))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar9))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar8))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar7))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar6))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar5))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar4))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar3))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar2))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->trackBar1))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox1))->EndInit();
			this->tabPage13->ResumeLayout(false);
			this->tabPage13->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox2))->EndInit();
			this->tabPage12->ResumeLayout(false);
			this->tabPage12->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox4))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown33))->EndInit();
			this->tabPage14->ResumeLayout(false);
			this->splitContainer1->Panel1->ResumeLayout(false);
			this->splitContainer1->Panel2->ResumeLayout(false);
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->splitContainer1))->EndInit();
			this->splitContainer1->ResumeLayout(false);
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->chart1))->EndInit();
			this->tabPage9->ResumeLayout(false);
			this->tabPage9->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->pictureBox3))->EndInit();
			this->statusStrip1->ResumeLayout(false);
			this->statusStrip1->PerformLayout();
			this->groupBox14->ResumeLayout(false);
			this->groupBox14->PerformLayout();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown32))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown34))->EndInit();
			(cli::safe_cast<System::ComponentModel::ISupportInitialize^  >(this->numericUpDown35))->EndInit();
			this->ResumeLayout(false);
			this->PerformLayout();

		}
#pragma endregion
		void InitControls(void)
		{
			Form1::form = this;
			this->comboBox1->Items->Clear();
			this->comboBox1->Items->AddRange(this->serialPort1->GetPortNames());
			this->comboBox1->SelectedIndex = 0;
			if(comp != nullptr)
			{
				int i = this->comboBox1->FindStringExact(comp);
				this->comboBox1->SelectedIndex = i;
				SetChecked(comp);
			}
			this->serialPort1->DataReceived += gcnew System::IO::Ports::SerialDataReceivedEventHandler(DataReceviedHandler);
			this->richTextBox1->Clear();
		}

		void Connect(int select)
		{
			bool error = false;
			if (this->button1->Text == "Connect") {
				this->serialPort1->PortName = this->comboBox1->SelectedItem->ToString();
				if(this->comp == nullptr)
					this->comp = this->serialPort1->PortName;
				else if(this->comp->Equals(this->serialPort1->PortName) == false)
					comp = this->serialPort1->PortName;
				if(baudrate != -1)
					this->serialPort1->BaudRate = baudrate;

				error = true;
				// Waiting / hour glass  
				this->Cursor->Current = Cursors::WaitCursor; 
				toolStripSplitButton1->Text = "Connecting";
				for(int i = 0;(i < 10) && (error == true); i++)
				{
					error = false;
					try
					{
						this->serialPort1->ReadBufferSize = 8192;
						this->serialPort1->WriteBufferSize = 8192;
						// Open the port
						this->serialPort1->Open();
					}
					catch (...) { error = true; }
					if (i < 10)
						Thread::Sleep(1000);
				}
				// Back to normal
				this->Cursor->Current = Cursors::Default;
				if (error)
				{
					toolStripSplitButton1->Text = "Connect";
					MessageBox::Show(this, "Could not open the COM port.  Most likely it is already in use, has been removed, or is unavailable.", "COM Port Unavalible", MessageBoxButtons::OK, MessageBoxIcon::Stop);
				}
				else
				{
					toolStripSplitButton1->Text = "Disconnect";
					this->button1->Text = "Disconnect";
					this->richTextBox1->Clear();				// empty console and sensor displays
					this->richTextBox2->Clear();
				}
			}
			else {
				//Do the actual close on another thread to avoid deadlocks
				Thread^ CloseDown = gcnew Thread(gcnew ThreadStart(this, &Form1::CloseSerialOnExit));
				CloseDown->Start();
			}
		}
private: System::Void CloseSerialOnExit() {
	if (form->serialPort1->IsOpen) {
		try {
				this->serialPort1->DiscardOutBuffer();
				this->serialPort1->DiscardInBuffer();
				this->serialPort1->Close();
				//Now update the button text on the UI thread
				this->Invoke(gcnew MethodInvoker(this, &Form1::NowButton));
		}
		catch (Exception^ ex) {
			MessageBox::Show(ex->Message);
		}
	}
}

private: System::Void NowButton() {
	this->button1->Text = "Connect";
	toolStripSplitButton1->Text = "Connect";
}

private: static System::Void SystemEvents_PowerModeChanged(System::Object^ sender, PowerModeChangedEventArgs^ e) {
  if( e->Mode == PowerModes::Suspend ){
	  form->CloseSerialOnExit();
  }
}

private: System::Void Form1_Load(System::Object^  sender, System::EventArgs^  e) {
      myTimer->Tick += gcnew EventHandler( TimerEventProcessor );

	  SystemEvents::PowerModeChanged += gcnew PowerModeChangedEventHandler(&QuadConsole1::Form1::SystemEvents_PowerModeChanged);

      // Sets the timer interval to 5 seconds.
      myTimer->Interval = 125; //200;
      myTimer->Start();
	  varmaxcount = 1;
	  varmax = 40;
		 }
private: System::Void button1_Click(System::Object^  sender, System::EventArgs^  e) {
			Form1^ form;
	        form = (Form1^)button1->FindForm();
			form->Connect(0);
		 }
private: static void DataReceviedHandler(
                        Object^ sender,
                        System::IO::Ports::SerialDataReceivedEventArgs^ e)
    {
        System::IO::Ports::SerialPort^ sp = (System::IO::Ports::SerialPort^)sender;
        String^ indata = sp->ReadExisting();
		if(closing || !form->serialPort1->IsOpen)
			return;
		form->SetText(indata);
	}
public: System::Void SetText(String^ value)   
{
	if(closing)
		return;
    if (InvokeRequired)
	{
		doingtext = 1;
        Invoke(gcnew SetTextDelegate(this, &QuadConsole1::Form1::SetText), value);   
		doingtext = 0;
	}
    else
	{
		int i;
		line += value;											// save until we have a line (CR) and process a line at a time
		while ((i = line->IndexOf('\r', 0)) != -1)				// have line
		{
			String^ newline = line->Substring(0, i+1);			// isolate the line
			line = line->Remove(0, i+1);						// remove  the current line we are procesing
			try
			{
				ProcessResponse(newline);
			}
			catch (...) {  }
		}
	}
} 
private: int Str2Q15s(String ^input, int *val)
{
	int ret = 0;
	double num;
	try {
		num = Double::Parse(input);
		int s = (num < 0);
		if(num < 0)
			num = -num;
		int v1 = (int)num;
		int v2 = v1 << 16;
		unsigned int v3;
		v3 = ((unsigned int)((num - (double)v1)*65536.0));
		v2 |= v3&0xffff;
		if(s)
			v2 = -v2;
		*val = v2;
		ret = 1;
	}
	catch(...)
	{
		ret = 0;
	}
	return ret;
}
private: String^ Q15s2Str(int val)
{
	return Q15s2Str(val, 0);
}
private: String^ Q15s2Str(int val, int no)
{
	String ^s;
	int sign = (val < 0);
	if(val < 0)
		val = -val;
	int v1 = val;
	v1 >>= 16;
	long long v2 = val & 0xffff;
	String ^z = ".";
	v2 = (v2*100000)/65536;
	if (v2 != 0)
	{
		if(v2 < 10)
			z = ".0000";
		else if(v2 < 100)
			z = ".000";
		else if(v2 < 1000)
			z = ".00";
		else if(v2 < 10000)
			z = ".0";
		while(1)
		{
			if ((v2 % 10) == 0)
				v2 /= 10;
			else
				break;
		}
	}
	int zl = z->Length-1;
	if((no != 0) && (zl > no))
		z = z->Substring(0, no);
	int n = no - zl;
	if(n < 0) n = 0;
	String^ s1 = v2.ToString();
	if((no != 0) && (s1->Length > n))
		s = v1.ToString() + z + s1->Substring(0, n);
	else
		s = v1.ToString() + z + s1;
	if(sign)
		s = "-" + s;
	return s;
}
private: System::Void AddSeriesData(String^ name, int index, double data)   
{
	System::Windows::Forms::DataVisualization::Charting::Series^ s;
	System::Windows::Forms::DataVisualization::Charting::ChartArea^ c;
	s = this->chart1->Series->FindByName(name);
	s->Points->AddXY(index, data);
	// Adjust Y & X axis scale
	chart1->ResetAutoValues();
	c = chart1->ChartAreas->FindByName("ChartArea1");
	if(c->AxisX->Maximum < pointIndex)
	{
		c->AxisX->Maximum = pointIndex;
 	}
	// Keep a constant number of points by removing them from the left
	while(s->Points->Count > numberOfPointsInChart)
	{
		// Remove data points on the left side
		while(s->Points->Count > numberOfPointsAfterRemoval)
		{
			s->Points->RemoveAt(0);
		}
		
		// Adjust X axis scale
		c->AxisX->Minimum = pointIndex - numberOfPointsAfterRemoval;
		c->AxisX->Maximum = c->AxisX->Minimum + numberOfPointsInChart;
	}
}
public: System::Void ProcessResponse(String^ value)   
{
	int newm;

	if (value->Length >= 2)										// its not a response if < 2 characters
	{
		if (value->StartsWith("M!"))						// motor command
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);
			if(value->Length >= 7)
			{
				String^ s1;
				String^ s2;
				int mid, val;
				s1 = value->Substring(2, 1);				// get the motor id
				s2 = value->Substring(3, 4);				// and the value
				mid = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				val = Int32::Parse(s2, NumberStyles::AllowHexSpecifier);
				if((mid >= 0) && (mid <= 3))
					mcommand[mid] = val;
			}
		}
		else if (value->StartsWith("A!"))						// all variables
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);
			int start = 2;
			int end;
			int variable;
			int val;
			String^ s1;
			String^ s2;
			while(start < value->Length)
			{
				end = value->IndexOf(',', start);
				if(end == -1)
					end = value->IndexOf('\r', start);
				if(end == -1)
					break;
				s1 = value->Substring(start, 2);				// get the variable id
				s2 = value->Substring(start+2, end-start-2);	// and the value
				variable = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				if (s2->Length <= 8)
					val = Int32::Parse(s2, NumberStyles::AllowHexSpecifier);
				else
					val = 0;
				if (end-start-2 == 2)							// sign extend
					if (val & 0x80)
						val |= 0xffffff00;
				if (end-start-2 == 4)							// sign extend
					if (val & 0x8000)
						val |= 0xffff0000;
				if (variable < varmax)
					UpdateVariable(variable, val, s2);			// update the correct UI control
				start = end+1;
			}
		}
		else if (value->StartsWith("H!"))						// artifical horizon values
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
			{
				myStream->WriteLine(value);
			}
			double angles[6];
			int j = 0;
			for(int i = 2; i < (2+48); i += 8)					// get IMU input angles
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				int v1 = val >> 16;
				long long v2 = val & 0xffff;
				v2 = (v2*100000)/65536;
				angles[j] = (double)v1 + (((double)v2)/100000.0);
				if(j < 6)j++;
			}
			int inv = 0;
			if(HPitchA != angles[0])
			{
				HPitchA =  Math::PI * -(180-angles[0]) / 180.0;
				inv = 1;
			}
			if(HRollA != angles[1])
			{
				HRollA =  (Math::PI * -(180-angles[1]) / 180.0);
				inv = 1;
			}
			if(HYaw != angles[2])
			{
				HYaw =  Math::PI * angles[2] / 180.0;
				inv = 1;
			}
			if(HSPitch != angles[3])
			{
				HSPitch =  Math::PI * -(180-angles[3]) / 180.0;
				Pitch = Math::PI * angles[3] / 180.0;
				inv = 1;
			}
			if(HSRoll != angles[4])
			{
				HSRoll =  (Math::PI * -(180-angles[4]) / 180.0);
				Roll =  (Math::PI * angles[4] / 180.0);
				inv = 1;
			}
			if(HSYaw != angles[5])
			{
				HSYaw =  Math::PI * angles[5] / 180.0;
				Yaw =  Math::PI * angles[5] / 180.0;
				inv = 1;
			}
			if(inv)
			{
				this->pictureBox1->Invalidate();
				this->pictureBox2->Invalidate();
			}
		}
		else if (value->StartsWith("S!"))						// sensor values
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
			{
				myStream->WriteLine(value);
			}
			String^ output = "";
			// Sensor output
			double angles[6];
			double sensors[16];
			int j = 0;
			for(int i = 3; i < (3+144); i += 9)					// gyro and acc, mag values
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				sensors[j] = val;
				if(j < 16)j++;
			}
			this->trackBar5->Value = (int)(sensors[0]+0.5);
			this->trackBar6->Value = (int)(sensors[1]+0.5);
			this->trackBar7->Value = (int)(sensors[2]+0.5);
			this->trackBar8->Value = (int)(sensors[3]*2.5);
			this->trackBar9->Value = (int)(sensors[4]*2.5);
			this->trackBar10->Value = (int)(sensors[5]*2.5);
			pointIndex++;
			AddSeriesData("Gyro X Orig", pointIndex, sensors[0]/3.2);
			AddSeriesData("Gyro X", pointIndex, (sensors[0]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex])/3.2);
			AddSeriesData("Gyro Y Orig", pointIndex, sensors[1]/3.2);
			AddSeriesData("Gyro Y", pointIndex, (sensors[1]*scales[listBox2->SelectedIndex==-1?4:listBox2->SelectedIndex])/3.2);
			AddSeriesData("Gyro Z Orig", pointIndex, sensors[2]/3.2);
			AddSeriesData("Gyro Z", pointIndex, (sensors[2]*scales[listBox3->SelectedIndex==-1?4:listBox3->SelectedIndex])/3.2);
			AddSeriesData("Acc X Orig", pointIndex, sensors[3]*4);
			AddSeriesData("Acc X", pointIndex, (sensors[3]*scales[listBox4->SelectedIndex==-1?4:listBox4->SelectedIndex])*4);
			AddSeriesData("Acc Y Orig", pointIndex, sensors[4]*4);
			AddSeriesData("Acc Y", pointIndex, (sensors[4]*scales[listBox5->SelectedIndex==-1?4:listBox5->SelectedIndex])*4);
			AddSeriesData("Acc Z Orig", pointIndex, sensors[5]*4);
			AddSeriesData("Acc Z", pointIndex, (sensors[5]*scales[listBox6->SelectedIndex==-1?4:listBox6->SelectedIndex])*4);
			AddSeriesData("Mag X", pointIndex, (sensors[7]*scales[listBox7->SelectedIndex==-1?4:listBox7->SelectedIndex])/1.62);
			AddSeriesData("Mag X Orig", pointIndex, sensors[7]/1.62);
			AddSeriesData("Mag Y", pointIndex, (sensors[8]*scales[listBox14->SelectedIndex==-1?4:listBox14->SelectedIndex])/1.62);
			AddSeriesData("Mag Y Orig", pointIndex, sensors[8]/1.62);
			AddSeriesData("Mag Z", pointIndex, (sensors[9]*scales[listBox13->SelectedIndex==-1?4:listBox13->SelectedIndex])/1.62);
			AddSeriesData("Mag Z Orig", pointIndex, sensors[9]/1.62);
			AddSeriesData("Pressure", pointIndex, (sensors[12]*scales[listBox12->SelectedIndex==-1?4:listBox12->SelectedIndex]));
			AddSeriesData("Pressure Orig", pointIndex, sensors[12]);
			AddSeriesData("Altitude", pointIndex, (sensors[15]*scales[listBox29->SelectedIndex==-1?4:listBox29->SelectedIndex]));
			AddSeriesData("Altitude Orig", pointIndex, sensors[15]);
			j = 0;
			for(int i = 174; i < (174+27); i += 9)					// get IMU input angles
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				int v1 = val >> 16;
				long long v2 = val & 0xffff;
				v2 = (v2*100000)/65536;
				angles[j] = (double)v1 + (((double)v2)/100000.0);
				if(j < 6)j++;
			}
			int inv = 0;
			if(SPitch != angles[0])
			{
				SPitch =  Math::PI * -(180-angles[0]) / 180.0;
				inv = 1;
			}
			if(SRoll != angles[1])
			{
				SRoll =  (Math::PI * -(180-angles[1]) / 180.0);
				inv = 1;
			}
			if(SYaw != angles[2])
			{
				SYaw =  Math::PI * angles[2] / 180.0;
				inv = 1;
			}
			j = 0;
			for(int i = 256; i < (256+48); i += 8)					// get IMU output values
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				int v1 = val >> 16;
				long long v2 = val & 0xffff;
				v2 = (v2*100000)/65536;
				sensors[j] = (double)v1 + (((double)v2)/100000.0);
				if(j < 6)j++;
				this->richTextBox2->AppendText(Q15s2Str(val) + " ");
				output += Q15s2Str(val) + " ";
			}
			AddSeriesData("IMU Pitch", pointIndex, (sensors[0]*scales[listBox11->SelectedIndex==-1?4:listBox11->SelectedIndex]));
			AddSeriesData("IMU Pitch Orig", pointIndex, sensors[0]);
			AddSeriesData("IMU Roll", pointIndex, (sensors[1]*scales[listBox10->SelectedIndex==-1?4:listBox10->SelectedIndex]));
			AddSeriesData("IMU Roll Orig", pointIndex, sensors[1]);
			AddSeriesData("IMU Yaw", pointIndex, (sensors[2]*scales[listBox9->SelectedIndex==-1?4:listBox9->SelectedIndex]));
			AddSeriesData("IMU Yaw Orig", pointIndex, sensors[2]);
			AddSeriesData("IMU Pitch Rate", pointIndex, (sensors[3]*scales[listBox33->SelectedIndex==-1?4:listBox33->SelectedIndex]));
			AddSeriesData("IMU Pitch Rate Orig", pointIndex, sensors[3]);
			AddSeriesData("IMU Roll Rate", pointIndex, (sensors[4]*scales[listBox32->SelectedIndex==-1?4:listBox32->SelectedIndex]));
			AddSeriesData("IMU Roll Rate Orig", pointIndex, sensors[4]);
			AddSeriesData("IMU Yaw Rate", pointIndex, (sensors[5]*scales[listBox34->SelectedIndex==-1?4:listBox34->SelectedIndex]));
			AddSeriesData("IMU Yaw Rate Orig", pointIndex, sensors[5]);

			inv = 0;
			if(Pitch != sensors[0])
			{
				Pitch = Math::PI * sensors[0] / 180.0;
				PitchA = Pitch - Math::PI;
				inv = 1;
			}
			if(Roll != sensors[1])
			{
				Roll =  (Math::PI * sensors[1] / 180.0);
				RollA =  Roll - Math::PI;
				inv = 1;
			}
			if(Yaw != sensors[2])
			{
				Yaw =  Math::PI * sensors[2] / 180.0;
				inv = 1;
			}
			if(inv)
			{
				this->label48->Text = Q15s2Str((unsigned int)((PitchA*180.0)/Math::PI)<<16, 3);
				this->label49->Text = Q15s2Str((unsigned int)((RollA*180.0)/Math::PI)<<16, 3);
				this->label50->Text = Q15s2Str((unsigned int)((Yaw*180.0)/Math::PI)<<16, 3);
				String ^s = "P: " + ((PitchA*180.0)/Math::PI).ToString("F3") + " R: " + ((RollA*180.0)/Math::PI).ToString("F3") + " Y: " + ((Yaw*180.0)/Math::PI).ToString("F3");
				toolStripStatusLabel7->Text = s;
				this->pictureBox1->Invalidate();
			}
			for(int i = 304; i < (304+24); i += 8)				// pressure values
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				if (s1->Length == 0)
					continue;
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				this->richTextBox2->AppendText(val.ToString() + " ");
				output += val.ToString() + " ";
			}
			j = 0;
			for(int i = 328; i < (328+(128)); i += 8)			// times
			{
				int val;
				String^ s1 = value->Substring(i, 8);
				if (s1->Length == 0)
					continue;
				val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
				times[j] = val;
				if(j < 16)j++;
			}
			AddSeriesData("Main Loop Time", pointIndex, (times[0]*scales[listBox11->SelectedIndex==-1?4:listBox11->SelectedIndex])/(clockfreq/1000));
			AddSeriesData("Main Loop Time Orig", pointIndex, times[0]/(clockfreq/1000));
			AddSeriesData("IMU Loop Time", pointIndex, (times[8]*scales[listBox11->SelectedIndex==-1?4:listBox11->SelectedIndex])/(clockfreq/1000));
			AddSeriesData("IMU Loop Time Orig", pointIndex, times[8]/(clockfreq/1000));
			j = 0;
			if (value->Length > 464+64)
			{
				int inv = 0;
				for(int i = 464; i < (464+64); i += 8)			// motor speeds
				{
					int val;
					String^ s1 = value->Substring(i, 8);
					if (s1->Length == 8)
					{
						val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
						motors[j] = val;
						if (motors[j] < -500)
							motors[j] = -500;
						if (motors[j] > 500)
							motors[j] = 500;
						inv = 1;
						if(j < 8)j++;
						this->richTextBox2->AppendText(val.ToString() + " ");
						output += val.ToString() + " ";
					}
				}
				noupdate = 1;
				this->trackBar1->Value = motors[0];
				this->trackBar2->Value = motors[1];
				this->trackBar3->Value = motors[2];
				this->trackBar4->Value = motors[3];
				noupdate = 0;
				AddSeriesData("Motor Front", pointIndex, (motors[0]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("Motor Front Orig", pointIndex, motors[0]);
				AddSeriesData("Motor Back", pointIndex, (motors[1]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("Motor Back Orig", pointIndex, motors[1]);
				AddSeriesData("Motor Left", pointIndex, (motors[2]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("Motor Left Orig", pointIndex, motors[2]);
				AddSeriesData("Motor Right", pointIndex, (motors[3]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("Motor Right Orig", pointIndex, motors[3]);
				String^ s = "F:" + motors[0].ToString("D") + " B:" + motors[1].ToString("D") + " L:" + motors[2].ToString("D") + " R:" + motors[3].ToString("D");
				toolStripStatusLabel8->Text = s;
				if (inv)
					this->pictureBox1->Invalidate();
			}
			if (value->Length > 528+8)
			{
				String^ s1 = value->Substring(528, 8);			// Battery voltage
				if (s1->Length == 8)
				{
					String ^ s;
					int val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
					if(val == -1)
					{
						s = "N/A";
						toolStripStatusLabel6->Text = "";
					}
					else
					{
						s = Q15s2Str(val) + "V";
						toolStripStatusLabel6->Text = Q15s2Str(val, 3) + "V";;
					}
					this->label46->Text = s;
					this->richTextBox2->AppendText(s + " ");
					output += s + " ";
				}
			}
			if (value->Length > 536+8)
			{
				String^ s1 = value->Substring(536, 8);			// Ground distance
				if (s1->Length == 8)
				{
					int val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
					this->richTextBox2->AppendText(val.ToString() + "in ");
					output += val.ToString() + "in ";
				}
			}
			if (value->Length > 544+8)
			{
				String^ s1 = value->Substring(544, 8);			// Magnetic north
				if (s1->Length == 8)
				{
					int val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
					double v1 = ((double)val);
					this->richTextBox2->AppendText(Q15s2Str((int)v1) + " ");
					output += Q15s2Str((int)v1) + " ";
				}
			}
			if (value->Length > 552+8)
			{
				String^ s1 = value->Substring(552, 8);			// Altitude meters
				if (s1->Length == 8)
				{
					int val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
					this->richTextBox2->AppendText(Q15s2Str(val) + " ");
					output += Q15s2Str(val) + " ";
				}
			}
			if (value->Length > 560+8)
			{
				String^ s1 = value->Substring(560, 8);			// Gyro Temp
				if (s1->Length == 8)
				{
					int val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
					this->richTextBox2->AppendText(val.ToString() + " ");
					output += val.ToString() + " ";
					AddSeriesData("Gyro Temp", pointIndex, (val*scales[listBox30->SelectedIndex==-1?4:listBox30->SelectedIndex])/280.0);
					AddSeriesData("Gyro Temp Orig", pointIndex, val/280.0);
				}
			}
			j = 0;
			if (value->Length > 568+64)
			{
				int inv = 0;
				for(int i = 568; i < (568+64); i += 8)			// PID motor speeds
				{
					int val;
					String^ s1 = value->Substring(i, 8);
					if (s1->Length == 8)
					{
						val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
						pids[j] = val;
						if(j < 8)j++;
						this->richTextBox2->AppendText(val.ToString() + " ");
						output += val.ToString() + " ";
					}
				}
				AddSeriesData("PID Pitch", pointIndex, (pids[0]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("PID Pitch Orig", pointIndex, pids[0]);
				AddSeriesData("PID Roll", pointIndex, (pids[1]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("PID Roll Orig", pointIndex, pids[1]);
				AddSeriesData("PID Throttle", pointIndex, (pids[2]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("PID Throttle Orig", pointIndex, pids[2]);
				AddSeriesData("PID Yaw", pointIndex, (pids[3]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("PID Yaw Orig", pointIndex, pids[3]);
			}
			j = 0;
			if (value->Length > 632+64)
			{
				int inv = 0;
				for(int i = 632; i < (632+64); i += 8)			// RC Receiver
				{
					int val;
					String^ s1 = value->Substring(i, 8);
					if (s1->Length == 8)
					{
						val = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
						rc[j] = val;
						if(j < 8)j++;
						this->richTextBox2->AppendText(val.ToString() + " ");
						output += val.ToString() + " ";
					}
				}
				SetRCIndicator(1, rc);
				SetRCIndicator(2, rc);
				SetRCIndicator(3, rc);
				SetRCIndicator(4, rc);
				SetRCIndicator(5, rc);
				SetRCIndicator(6, rc);
				SetRCIndicator(7, rc);
				SetRCIndicator(8, rc);
				AddSeriesData("RC Channel 1", pointIndex, (rc[0]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 1 Orig", pointIndex, rc[0]);
				AddSeriesData("RC Channel 2", pointIndex, (rc[1]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 2 Orig", pointIndex, rc[1]);
				AddSeriesData("RC Channel 3", pointIndex, (rc[2]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 3 Orig", pointIndex, rc[2]);
				AddSeriesData("RC Channel 4", pointIndex, (rc[3]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 4 Orig", pointIndex, rc[3]);
				AddSeriesData("RC Channel 5", pointIndex, (rc[4]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 5 Orig", pointIndex, rc[4]);
				AddSeriesData("RC Channel 6", pointIndex, (rc[5]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 6 Orig", pointIndex, rc[5]);
				AddSeriesData("RC Channel 7", pointIndex, (rc[6]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 7 Orig", pointIndex, rc[6]);
				AddSeriesData("RC Channel 8", pointIndex, (rc[7]*scales[listBox1->SelectedIndex==-1?4:listBox1->SelectedIndex]));
				AddSeriesData("RC Channel 8 Orig", pointIndex, rc[7]);
			}

			// Redraw chart
			chart1->Invalidate();

			if(myStream)
			{
				myStream->WriteLine(output);
			}
			this->richTextBox2->AppendText("\r");
			this->richTextBox2->SelectionStart = this->richTextBox2->Text->Length;
			this->richTextBox2->ScrollToCaret();
		}
		else if (value->StartsWith("I!"))						// max variable id
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);
			int l = value->Length;
			String^ s1 = value->Substring(2, l-3);
			newm = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);

			if (newm != varmax)									// no of variables changed so fast update the variables
			{
				varindex = 0;
				varmax = newm;
				myTimer->Interval = 125;
				form->serialPort1->Write("A\r");				// get all variables
				form->serialPort1->Write("WP\r");				// get waypoints
			}
			else
				varmaxcount = 50;
		}
		else if (value->StartsWith("SC!"))
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);

			String^ s1 = value->Substring(3, 8);
			if (s1->Length == 8)
			{
				clockfreq = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);

				if((clockfreq % 1000000) == 0)
				{
					label78->Text = (clockfreq/1000000).ToString() + "Mhz";
				}
				else if((clockfreq % 1000) == 0)
				{
					label78->Text = (clockfreq/1000).ToString() + "Khz";
				}
				else
				{
					label78->Text = (clockfreq).ToString() + "Hz";
				}
			}
		}
		else if (value->StartsWith("U!")
		 ||	value->StartsWith("SP!")
		 ||	value->StartsWith("SR!")
		 ||	value->StartsWith("SY!")
		 )														// variable update response
		{														// nothing to do for update responses
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);
		}
		else if (value->StartsWith("WP!"))						// waypoint values
		{
			if (rawmode)
			{
				this->richTextBox1->AppendText(value);					// not a response so display in console
				this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
				this->richTextBox1->ScrollToCaret();
			}
			if(myStream)
				myStream->WriteLine(value);
			int j = 0;
			if (value->Length >= 11)
			{
				int len = value->Length;
				int var = 0;
				for(int i = 3; len >= 8; i += 8, len -= 8)					// waypoints
				{
					String^ s1 = value->Substring(i, 8);
					if (s1->Length == 8)
					{
						switch(var)
						{
						case 0:
							waypoints[j].valid = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
							var++;
							break;
						case 1:
							waypoints[j].latq = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
							var++;
							break;
						case 2:
							waypoints[j].longq = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
							var++;
							break;
						case 3:
							waypoints[j].altq = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
							var++;
							break;
						case 4:
							waypoints[j++].pressureq = Int32::Parse(s1, NumberStyles::AllowHexSpecifier);
							var = 0;
							break;
						}
					}
					else
						break;
				}
				Decimal way = numericUpDown33->Value;
				this->textBox8->Text = Q15s2Str(waypoints[(int)way].latq);
				textBox9->Text = Q15s2Str(waypoints[(int)way].longq);
				textBox10->Text = Q15s2Str(waypoints[(int)way].altq);
				UpdateWaypoints(1);
			}
		}
		else													// not a response so display in console
		{
			if(myStream)
				myStream->WriteLine(value);
			this->richTextBox1->AppendText(value);
			this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
			this->richTextBox1->ScrollToCaret();
		}
	}
	else
	{
		if(myStream)
			myStream->WriteLine(value);
		this->richTextBox1->AppendText(value);					// not a response so display in console
		this->richTextBox1->SelectionStart = this->richTextBox1->Text->Length;
		this->richTextBox1->ScrollToCaret();
	}
}
 static void TimerEventProcessor( Object^ /*myObject*/, EventArgs^ /*myEventArgs*/ )
   {
	   static int count;
	   static int sensorcount;
	   int scount = 4;

		if(tobeclosed == 1)
			form->Close();
	   if(form->startquad == 1)
		   form->pictureBox1->Invalidate();
	   if (form->serialPort1->IsOpen)
	   {
			mut->WaitOne();
			if(form->startah != 0)
				form->serialPort1->Write("H\r");				// artifical horizon read ommand
			if(form->startquad != 0)
				scount = 2;
			if (sensorcount++ > scount)
			{
				sensorcount = 0;
				form->serialPort1->Write("S\r");				// a sensor read ommand
			}
			varindex++;
			if (varindex > varmax)
			{
				myTimer->Interval = 125;						// updated all variables so slow down updates
				varindex = 0;
			}
			count++;
			if ((count > varmaxcount) || (varmax == 0))
			{
				count = 0;
				form->serialPort1->Write("SC\r");				// get clock frequency
				form->serialPort1->Write("A\r");				// get all variables
				form->serialPort1->Write("I\r");				// a variable id max command
				form->serialPort1->Write("WP\r");				// get waypoints
			}
			if(startcalibration == 1)
			{
				if((calibrationcount < 30) && ((mcommand[0] != 0xffff) || (mcommand[1] != 0xffff) || (mcommand[2] != 0xffff) || (mcommand[3] != 0xffff)))
				{
					calibrationcount++;
					switch(calibrationcount&3)
					{
					case 0:
						form->serialPort1->Write("M0FFFF\r");
						break;
					case 1:
						form->serialPort1->Write("M1FFFF\r");
						break;
					case 2:
						form->serialPort1->Write("M2FFFF\r");
						break;
					case 3:
						form->serialPort1->Write("M3FFFF\r");
						break;
					}
				}
				else
				{
					// Back to normal
					form->Cursor->Current = Cursors::Default;
					if((mcommand[0] == 0xffff) && (mcommand[1] == 0xffff) && (mcommand[2] == 0xffff) && (mcommand[3] == 0xffff))
						form->button16->Text = "Stop Calibration";
				}
			}
			else if(startcalibration == 2)
			{
				if((calibrationcount < 30) && ((mcommand[0] != 0) || (mcommand[1] != 0) || (mcommand[2] != 0) || (mcommand[3] != 0)))
				{
					calibrationcount++;
					switch(calibrationcount&3)
					{
					case 0:
						form->serialPort1->Write("M00000\r");
						break;
					case 1:
						form->serialPort1->Write("M10000\r");
						break;
					case 2:
						form->serialPort1->Write("M20000\r");
						break;
					case 3:
						form->serialPort1->Write("M30000\r");
						break;
					}
				}
				else
				{
					// Back to normal
					form->Cursor->Current = Cursors::Default;
					if((mcommand[0] == 0) && (mcommand[1] == 0) && (mcommand[2] == 0) && (mcommand[3] == 0))
						form->button16->Text = "Start Calibration";
				}
			}
			mut->ReleaseMutex();
	   }
 }
public: System::Void UpdateVariable(int variable, int value, String^)
{
	update = variable+1;
	// Variable value
	switch (variable)											// update UI control with variable value
	{
	case 0:
		this->checkBox1->Checked = (value != 0);
		break;
	case 1:
		if(!textBox1->Focused)
			this->textBox1->Text = Q15s2Str(value);
		break;
	case 2:
		if(!textBox2->Focused)
			this->textBox2->Text = Q15s2Str(value);
		break;
	case 3:
		this->checkBox3->Checked = (value != 0);
		break;
	case 4:
		this->checkBox4->Checked = (value != 0);
		break;
	case 5:
		this->numericUpDown1->Value = value;
		break;
	case 6:
		this->numericUpDown2->Value = value;
		break;
	case 7:
		this->numericUpDown3->Value = value;
		break;
	case 8:
		this->numericUpDown4->Value = value;
		break;
	case 9:
		this->numericUpDown5->Value = value+1;
		break;
	case 10:
		this->numericUpDown6->Value = value+1;
		break;
	case 11:
		this->numericUpDown7->Value = value+1;
		break;
	case 12:
		this->numericUpDown8->Value = value+1;
		break;
	case 13:
		this->numericUpDown9->Value = value+1;
		break;
	case 14:
		this->numericUpDown10->Value = value+1;
		break;
	case 15:
		this->numericUpDown11->Value = value+1;
		break;
	case 16:
		this->numericUpDown12->Value = value+1;
		break;
	case 17:
		this->comboBox2->SelectedIndex = value;
		break;
	case 18:
		{
			int v;
			switch (value)
			{
			case 4:
				v = 0;
				break;
			case 6:
				v = 1;
				break;
			case 8:
				v = 2;
				break;
			}
			this->comboBox3->SelectedIndex = v;
		}
		break;
	case 19:
		this->checkBox5->Checked = (value != 0);
		break;
	case 20:
		this->checkBox6->Checked = (value != 0);
		break;
	case 21:
		this->numericUpDown13->Value = value;
		break;
	case 22:
		this->numericUpDown14->Value = value;
		break;
	case 23:
		this->checkBox8->Checked = (value != 0);
		break;
	case 24:
		if(!textBox3->Focused)
			this->textBox3->Text = Q15s2Str(value);
		break;
	case 25:
		if(!textBox4->Focused)
			this->textBox4->Text = Q15s2Str(value);
		break;
	case 26:
		if(!textBox5->Focused)
			this->textBox5->Text = Q15s2Str(value);
		break;
	case 27:
		if(!textBox6->Focused)
			this->textBox6->Text = Q15s2Str(value);
		break;
	case 28:
		if(!textBox7->Focused)
			this->textBox7->Text = Q15s2Str(value);
		break;
	case 29:
		this->numericUpDown19->Value = value;
		break;
	case 30:
		this->numericUpDown22->Value = value;
		break;
	case 31:
		this->numericUpDown15->Value = value;
		break;
	case 32:
		this->numericUpDown18->Value = value;
		break;
	case 33:
		this->numericUpDown21->Value = value;
		break;
	case 34:
		this->numericUpDown20->Value = value;
		break;
	case 35:
		this->numericUpDown17->Value = value;
		break;
	case 36:
		this->numericUpDown16->Value = value;
		break;
	case 37:
		this->numericUpDown23->Value = value&0x7f;
		this->checkBox14->Checked = ((value&0x80) != 0);
		break;
	case 38:
		this->numericUpDown24->Value = value&0x7f;
		this->checkBox15->Checked = ((value&0x80) != 0);
		break;
	case 39:
		this->numericUpDown25->Value = value&0x7f;
		this->checkBox16->Checked = ((value&0x80) != 0);
		break;
	case 40:
		this->numericUpDown28->Value = value&0x7f;
		this->checkBox11->Checked = ((value&0x80) != 0);
		break;
	case 41:
		this->numericUpDown27->Value = value&0x7f;
		this->checkBox12->Checked = ((value&0x80) != 0);
		break;
	case 42:
		this->numericUpDown26->Value = value&0x7f;
		this->checkBox13->Checked = ((value&0x80) != 0);
		break;
	case 43:
		this->numericUpDown31->Value = value&0x7f;
		this->checkBox2->Checked = ((value&0x80) != 0);
		break;
	case 44:
		this->numericUpDown30->Value = value&0x7f;
		this->checkBox9->Checked = ((value&0x80) != 0);
		break;
	case 45:
		this->numericUpDown29->Value = value&0x7f;
		this->checkBox10->Checked = ((value&0x80) != 0);
		break;
	case 46:
		this->comboBox4->SelectedIndex = value+12;
		break;
	case 47:
		this->checkBox7->Checked = (value != 0);
		break;
	case 48:
		if(!textBox17->Focused)
			this->textBox17->Text = Q15s2Str(value);
		break;
	case 49:
		checkBox17->Checked = ((value & 1) != 0);
		checkBox18->Checked = ((value & 2) != 0);
		checkBox19->Checked = ((value & 4) != 0);
		break;
	case 50:
		break;
	case 51:
		this->label53->Text = Q15s2Str(value);
		break;
	case 52:
		this->label54->Text = Q15s2Str(value);
		break;
	case 53:
		this->label55->Text = Q15s2Str(value);
		break;
	case 54:
		if(!textBox11->Focused)
			this->textBox11->Text = Q15s2Str(value);
		break;
	case 55:
		if(!textBox12->Focused)
			this->textBox12->Text = Q15s2Str(value);
		break;
	case 56:
		if(!textBox13->Focused)
			this->textBox13->Text = Q15s2Str(value);
		break;
	case 57:
		if(!textBox14->Focused)
			this->textBox14->Text = Q15s2Str(value);
		break;
	case 58:
		if(!textBox15->Focused)
			this->textBox15->Text = Q15s2Str(value);
		break;
	case 59:
		if(!textBox16->Focused)
			this->textBox16->Text = Q15s2Str(value);
		break;
	case 60:
		checkBox20->Checked = ((value & 1) != 0);
		break;
	case 61:
		this->numericUpDown35->Value = value&0x7f;
		this->checkBox23->Checked = ((value&0x80) != 0);
		break;
	case 62:
		this->numericUpDown34->Value = value&0x7f;
		this->checkBox22->Checked = ((value&0x80) != 0);
		break;
	case 63:
		this->numericUpDown32->Value = value&0x7f;
		this->checkBox21->Checked = ((value&0x80) != 0);
		break;
	}
	update = 0;
}
delegate System::Void SetTextDelegate(String^ value);
private: System::Void comboBox1_DropDown( Object^ sender, System::EventArgs^ e )
	{
		LoadStatusComPorts();
		LoadComPorts();
	}
private: System::Void LoadComPorts()
	{
		// get current line of com ports and update combobox with it
		int i = this->comboBox1->SelectedIndex;
		this->comboBox1->Items->Clear();	// leave current selected if possible
		this->comboBox1->Items->AddRange(this->serialPort1->GetPortNames());
		if (this->comboBox1->Items->Count <= i)
			this->comboBox1->SelectedIndex = 0;
		else
			this->comboBox1->SelectedIndex = i;
   }
private: System::Void button2_Click(System::Object^  sender, System::EventArgs^  e) {
			 // Load
			if (form->serialPort1->IsOpen) {
				mut->WaitOne();
				form->serialPort1->Write("CL\r");				// eeprom load command
				mut->ReleaseMutex();
				SetConfigStatus(false);
				varmaxcount = 5;
			}
		}
private: System::Void button3_Click(System::Object^  sender, System::EventArgs^  e) {
			 // Save
			if (form->serialPort1->IsOpen) {
				mut->WaitOne();
				form->serialPort1->Write("CS\r");				// eeprom save command
				mut->ReleaseMutex();
				SetConfigStatus(false);
			}
		}
private: System::Void button4_Click(System::Object^  sender, System::EventArgs^  e) {
			 // Default
			if (form->serialPort1->IsOpen) {
				mut->WaitOne();
				form->serialPort1->Write("CD\r");				// eeprom reset command
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
		}
private: System::Void button5_Click(System::Object^  sender, System::EventArgs^  e) {
			 // reboot
			if (form->serialPort1->IsOpen) {
				mut->WaitOne();
				form->serialPort1->Write("CB\r");				// prop reboot command
				mut->ReleaseMutex();
				varmaxcount = 5;
			}
		}
private: System::Void checkBox1_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 0
		if ((update != 1) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox1->Checked)
				form->serialPort1->Write("U00FF\r");
			else
				form->serialPort1->Write("U0000\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox3_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 3
		if ((update != 4) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox3->Checked)
				form->serialPort1->Write("U03FF\r");
			else
				form->serialPort1->Write("U0300\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox4_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 4
		if ((update != 5) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox4->Checked)
				form->serialPort1->Write("U04FF\r");
			else
				form->serialPort1->Write("U0400\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown1_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 5
		if ((update != 6) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U05" + Decimal::ToUInt32(this->numericUpDown1->Value).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown2_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 6
		if ((update != 7) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U06" + Decimal::ToUInt32(this->numericUpDown2->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown3_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 7
		if ((update != 8) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U07" + Decimal::ToUInt32(this->numericUpDown3->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown4_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 8
		if ((update != 9) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U08" + Decimal::ToUInt32(this->numericUpDown4->Value).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown5_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 9
		if ((update != 10) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U09" + Decimal::ToUInt32(this->numericUpDown5->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown6_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 10
		if ((update != 11) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0A" + Decimal::ToUInt32(this->numericUpDown6->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown7_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 11
		if ((update != 12) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0B" + Decimal::ToUInt32(this->numericUpDown7->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown8_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 12
		if ((update != 13) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0C" + Decimal::ToUInt32(this->numericUpDown8->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown9_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 13
		if ((update != 14) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0D" + Decimal::ToUInt32(this->numericUpDown9->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown10_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 14
		if ((update != 15) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0E" + Decimal::ToUInt32(this->numericUpDown10->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown11_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 15
		if ((update != 16) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U0F" + Decimal::ToUInt32(this->numericUpDown11->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown12_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 16
		if ((update != 17) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U10" + Decimal::ToUInt32(this->numericUpDown12->Value-1).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void comboBox2_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 17
		if ((update != 18) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U11" + this->comboBox2->SelectedIndex.ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void comboBox3_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 18
		if ((update != 19) && form->serialPort1->IsOpen) {
			int v = 0;
			switch(this->comboBox3->SelectedIndex)
			{
			case 0:
				v = 4;
				break;
			case 1:
				v = 6;
				break;
			case 2:
				v = 8;
				break;
			}
			mut->WaitOne();
			form->serialPort1->Write("U12" + v.ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox5_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 19
		if ((update != 20) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox5->Checked)
				form->serialPort1->Write("U13FF\r");
			else
				form->serialPort1->Write("U1300\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox6_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 20
		if ((update != 21) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox6->Checked)
				form->serialPort1->Write("U14FF\r");
			else
				form->serialPort1->Write("U1400\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown13_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 21
		if ((update != 22) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U15" + Decimal::ToInt32(this->numericUpDown13->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown14_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 22
		if ((update != 23) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U16" + Decimal::ToUInt32(this->numericUpDown14->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown15_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 31
		if ((update != 32) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U1F" + Decimal::ToUInt32(this->numericUpDown15->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown16_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 36
		if ((update != 37) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U24" + Decimal::ToUInt32(this->numericUpDown16->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown17_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 35
		if ((update != 36) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U23" + Decimal::ToUInt32(this->numericUpDown17->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown18_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 32
		if ((update != 33) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U20" + Decimal::ToUInt32(this->numericUpDown18->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown19_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 29
		if ((update != 30) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U1D" + Decimal::ToUInt32(this->numericUpDown19->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown20_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 34
		if ((update != 35) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U22" + Decimal::ToUInt32(this->numericUpDown20->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown21_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 33
		if ((update != 34) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U21" + Decimal::ToUInt32(this->numericUpDown21->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown22_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 30
		if ((update != 31) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U1E" + Decimal::ToUInt32(this->numericUpDown22->Value).ToString("X4") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown23_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 37
		if ((update != 38) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown23->Value;
			val = val + (this->checkBox14->Checked?128:0);
			form->serialPort1->Write("U25" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown24_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 38
		if ((update != 39) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown24->Value;
			val = val + (this->checkBox15->Checked?128:0);
			form->serialPort1->Write("U26" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown25_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 39
		if ((update != 40) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown25->Value;
			val = val + (this->checkBox16->Checked?128:0);
			form->serialPort1->Write("U27" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown28_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 40
		if ((update != 41) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown28->Value;
			val = val + (this->checkBox11->Checked?128:0);
			form->serialPort1->Write("U28" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown27_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 41
		if ((update != 42) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown27->Value;
			val = val + (this->checkBox12->Checked?128:0);
			form->serialPort1->Write("U29" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown26_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 42
		if ((update != 43) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown26->Value;
			val = val + (this->checkBox13->Checked?128:0);
			form->serialPort1->Write("U2A" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown31_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 43
		if ((update != 44) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown31->Value;
			val = val + (this->checkBox2->Checked?128:0);
			form->serialPort1->Write("U2B" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown30_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 44
		if ((update != 45) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown30->Value;
			val = val + (this->checkBox9->Checked?128:0);
			form->serialPort1->Write("U2C" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown29_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 45
		if ((update != 46) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown29->Value;
			val = val + (this->checkBox10->Checked?128:0);
			form->serialPort1->Write("U2D" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void comboBox4_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 46
		if ((update != 47) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U2E" + (this->comboBox4->SelectedIndex-12).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void pictureBox1_Paint(System::Object^  sender, System::Windows::Forms::PaintEventArgs^  e) {
		/*
			Currently only works for 4 motor + configuration
			Needs to read NoofMotors and FourFive config and work for 4 +/x, 6, 8 +/x configurations

			Pitch - front down is +ve
			Roll - right down is +ve
			Yaw - cw is +ve
		*/
		double xf, yf, xb, yb, xl, yl, xr, yr, xt, yt, xm, ym;
		double ymid, xmid;
		double lyaw = 2*Math::PI - Yaw;

		ymid = pictureBox1->Height/2;
		xmid = pictureBox1->Width/2;
		// calculate and draw main quad
		// Calculate the endpoints based on Pitch and Roll
		yf = ymid + Math::Sin(Pitch)*160;
		yb = ymid - Math::Sin(Pitch)*160;
		xf = xmid + Math::Cos(Pitch)*Math::Sin(lyaw)*160;
		xb = xmid - Math::Cos(Pitch)*Math::Sin(lyaw)*160;

		yl = ymid - Math::Sin(Roll)*160;
		yr = ymid + Math::Sin(Roll)*160;
		xl = xmid - Math::Cos(Roll)*Math::Cos(lyaw)*160;
		xr = xmid + Math::Cos(Roll)*Math::Cos(lyaw)*160;

		xt = xmid - Math::Sin(Roll)*Math::Cos(lyaw)*50 - Math::Sin(Pitch)*Math::Sin(lyaw)*50;
		yt = ymid - Math::Cos(Roll)*Math::Cos(Pitch)*50;

		e->Graphics->DrawLine(redpen,(int)xmid,(int)ymid,(int)xf,(int)yf);	// front is red
	    e->Graphics->DrawLine(blackpen,(int)xmid,(int)ymid,(int)xb,(int)yb);
	    e->Graphics->DrawLine(ablackpen,(int)xl,(int)yl,(int)xr,(int)yr);
	    e->Graphics->DrawLine(ablackpen,(int)xmid,(int)ymid,(int)xt,(int)yt);

		// Calculate and draw motors - motors are front. back, left, right
		// motor speed is -500-500, arrow length is max 100
		double l = (motors[0] + 500.0)/10.0;
		if(l < 0.0)
			l = 0.0;
		if(l > 100.0)
			l = 100.0;
		xm = xf - Math::Sin(Roll)*Math::Cos(lyaw)*50 - Math::Sin(Pitch)*Math::Sin(lyaw)*l;
		ym = yf - Math::Cos(Pitch)*Math::Cos(Roll)*l;
		if(l > 0)
		{
		    e->Graphics->DrawLine(amotorpen,(int)xf,(int)yf,(int)xm,(int)ym);
			DrawProp(0, (int)xm, (int)ym, e);
		}
		l = (motors[1] + 500.0)/10.0;
		if(l < 0.0)
			l = 0.0;
		if(l > 100.0)
			l = 100.0;
		xm = xb - Math::Sin(Roll)*Math::Cos(lyaw)*50 - Math::Sin(Pitch)*Math::Sin(lyaw)*l;
		ym = yb - Math::Cos(Pitch)*Math::Cos(Roll)*l;
		if(l > 0)
		{
			e->Graphics->DrawLine(amotorpen,(int)xb,(int)yb,(int)xm,(int)ym);
			DrawProp(1, (int)xm, (int)ym, e);
		}
		l = (motors[2] + 500.0)/10.0;
		if(l < 0.0)
			l = 0.0;
		if(l > 100.0)
			l = 100.0;
		xm = xl - Math::Sin(Roll)*Math::Cos(lyaw)*50 - Math::Sin(Pitch)*Math::Sin(lyaw)*l;
		ym = yl - Math::Cos(Roll)*Math::Cos(Pitch)*l;
		if(l > 0)
		{
		    e->Graphics->DrawLine(amotorpen,(int)xl,(int)yl,(int)xm,(int)ym);
			DrawProp(2, (int)xm, (int)ym, e);
		}
		l = (motors[3] + 500.0)/10.0;
		if(l < 0.0)
			l = 0.0;
		if(l > 100.0)
			l = 100.0;
		xm = xr - Math::Sin(Roll)*Math::Cos(lyaw)*50 - Math::Sin(Pitch)*Math::Sin(lyaw)*l;
		ym = yr - Math::Cos(Roll)*Math::Cos(Pitch)*l;
		if(l > 0)
		{
		    e->Graphics->DrawLine(amotorpen,(int)xr,(int)yr,(int)xm,(int)ym);
			DrawProp(3, (int)xm, (int)ym, e);
		}
		if ((Yaw < Math::PI/2) || (Yaw > Math::PI*3/4))
		    e->Graphics->DrawLine(ablackpen,(int)xmid,(int)ymid,(int)xr,(int)yr);
	}
private: System::Void DrawProp(int p, int x, int y, System::Windows::Forms::PaintEventArgs^  e) {
		double xf, yf;
		static double ycount, y1count;
		double lyaw;
		if((p == 0) || (p == 1))
		{
			if(this->checkBox6->Checked != 0)		//spin the props the correct direction
				lyaw = Yaw + ycount;
			else
				lyaw = Yaw + y1count;
		}
		else
		{
			if(this->checkBox5->Checked != 0)
				lyaw = Yaw + y1count;
			else
				lyaw = Yaw + ycount;
		}
		xf = x - Math::Cos(Roll)*Math::Cos(lyaw)*20 - Math::Cos(Pitch)*Math::Sin(lyaw)*20;
		yf = y - Math::Sin(Roll)*Math::Sin(lyaw)*20 + Math::Sin(Pitch)*Math::Cos(lyaw)*20;
		
	    e->Graphics->DrawLine(pblackpen,x,y,(int)xf,(int)yf);

		lyaw += Math::PI/2;
		xf = x - Math::Cos(Roll)*Math::Cos(lyaw)*20 - Math::Cos(Pitch)*Math::Sin(lyaw)*20;
		yf = y - Math::Sin(Roll)*Math::Sin(lyaw)*20 + Math::Sin(Pitch)*Math::Cos(lyaw)*20;
		
	    e->Graphics->DrawLine(pblackpen,x,y,(int)xf,(int)yf);

		lyaw += Math::PI/2;
		xf = x - Math::Cos(Roll)*Math::Cos(lyaw)*20 - Math::Cos(Pitch)*Math::Sin(lyaw)*20;
		yf = y - Math::Sin(Roll)*Math::Sin(lyaw)*20 + Math::Sin(Pitch)*Math::Cos(lyaw)*20;
		
	    e->Graphics->DrawLine(pblackpen,x,y,(int)xf,(int)yf);

		lyaw += Math::PI/2;
		xf = x - Math::Cos(Roll)*Math::Cos(lyaw)*20 - Math::Cos(Pitch)*Math::Sin(lyaw)*20;
		yf = y - Math::Sin(Roll)*Math::Sin(lyaw)*20 + Math::Sin(Pitch)*Math::Cos(lyaw)*20;

	    e->Graphics->DrawLine(pblackpen,x,y,(int)xf,(int)yf);

		if(p == 3)
		{
			ycount += Math::PI/8;
			if(ycount > (Math::PI*2+Math::PI/16))
				ycount -= Math::PI*2;
			y1count -= Math::PI/8;
			if(y1count < (-Math::PI/16))
				y1count = Math::PI*2;
		}
	}
private: System::Void checkBox7_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 47
		if ((update != 48) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if (this->checkBox7->Checked)
				form->serialPort1->Write("U2FFF\r");
			else
				form->serialPort1->Write("U2F00\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void button6_Click(System::Object^  sender, System::EventArgs^  e) {

		if (this->button6->Text == "Capture") {
			saveFileDialog1->Filter = "Capture File|*.txt";
			saveFileDialog1->Title = "Save a Capture File";
			saveFileDialog1->RestoreDirectory = true ;

			if(saveFileDialog1->ShowDialog() == System::Windows::Forms::DialogResult::OK)
			{
				if((myStream = gcnew StreamWriter(saveFileDialog1->OpenFile())))
				{
					int i;
					DateTime d1 = DateTime::Now;
					button6->Text = "Close";
					toolStripStatusLabel4->Text = "Logging";
					if((i = saveFileDialog1->FileName->LastIndexOf('\\')) == -1)
						label86->Text = saveFileDialog1->FileName;
					else
						label86->Text = saveFileDialog1->FileName->Substring(i+1);
					myStream->WriteLine("Quadcopter capture file " + d1.ToLocalTime());
				}
			}
		}
		else
		{
			if(myStream)
				myStream->Close();
			myStream = nullptr;
			button6->Text = "Capture";
			label86->Text = "";
			toolStripStatusLabel4->Text = "";
		}
	}
private: System::Void checkBox2_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 43
		if ((update != 44) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown31->Value;
			val = val + (this->checkBox2->Checked?128:0);
			form->serialPort1->Write("U2B" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox9_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 44
		if ((update != 45) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown30->Value;
			val = val + (this->checkBox9->Checked?128:0);
			form->serialPort1->Write("U2C" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox10_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 45
		if ((update != 46) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown29->Value;
			val = val + (this->checkBox10->Checked?128:0);
			form->serialPort1->Write("U2D" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox11_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 40
		if ((update != 41) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown28->Value;
			val = val + (this->checkBox11->Checked?128:0);
			form->serialPort1->Write("U28" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox12_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 41
		if ((update != 42) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown29->Value;
			val = val + (this->checkBox12->Checked?128:0);
			form->serialPort1->Write("U29" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox13_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 42
		if ((update != 43) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown30->Value;
			val = val + (this->checkBox13->Checked?128:0);
			form->serialPort1->Write("U2A" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox14_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 37
		if ((update != 38) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown23->Value;
			val = val + (this->checkBox14->Checked?128:0);
			form->serialPort1->Write("U25" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox15_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 38
		if ((update != 39) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown24->Value;
			val = val + (this->checkBox15->Checked?128:0);
			form->serialPort1->Write("U26" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox16_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 39
		if ((update != 40) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown25->Value;
			val = val + (this->checkBox16->Checked?128:0);
			form->serialPort1->Write("U27" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void textBox1_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 1
		int v1;
		if(Str2Q15s(textBox1->Text, &v1))
		{
			if ((update != 2) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U01" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox1->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox1_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox1->Text, &val))
		{
			e->Cancel = true;
            textBox1->Select(0, textBox1->Text->Length);
		}
	}
private: System::Void button7_Click(System::Object^  sender, System::EventArgs^  e) {
		// Pitch Offset
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("SP\r");				// prop Pitch Offset command
			form->serialPort1->Write("A\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
			varmaxcount = 5;
		}
	}
private: System::Void button8_Click(System::Object^  sender, System::EventArgs^  e) {
		// Pitch Offset
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("SR\r");				// prop Roll Offset command
			form->serialPort1->Write("A\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
			varmaxcount = 5;
		}
	}
private: System::Void button9_Click(System::Object^  sender, System::EventArgs^  e) {
		// Yaw Offset
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("SY\r");				// prop Yaw Offset command
			form->serialPort1->Write("A\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
			varmaxcount = 5;
		}
	}
private: System::Void textBox2_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 2
		int v1;
		if(Str2Q15s(textBox2->Text, &v1))
		{
			if ((update != 3) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U02" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox2->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox2_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox2->Text, &val))
		{
			e->Cancel = true;
            textBox2->Select(0, textBox2->Text->Length);
		}
	}
private: System::Void textBox3_Validated(System::Object^  sender, System::EventArgs^  e) {
		int v1;
		// Update variable 24
		if(Str2Q15s(textBox3->Text, &v1))
		{
			if ((update != 25) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U18" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox3->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox3_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox3->Text, &val))
		{
			e->Cancel = true;
            textBox3->Select(0, textBox3->Text->Length);
		}
	}
private: System::Void textBox4_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 25
		int v1;
		if(Str2Q15s(textBox4->Text, &v1))
		{
			if ((update != 26) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U19" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox4->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox4_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox4->Text, &val))
		{
			e->Cancel = true;
            textBox4->Select(0, textBox4->Text->Length);
		}
	}
private: System::Void textBox5_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 26
		int v1;
		if(Str2Q15s(textBox5->Text, &v1))
		{
			if ((update != 27) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U1A" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox5->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox5_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox5->Text, &val))
		{
			e->Cancel = true;
            textBox5->Select(0, textBox5->Text->Length);
		}
	}
private: System::Void textBox6_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 27
		int v1;
		if(Str2Q15s(textBox6->Text, &v1))
		{
			if ((update != 28) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U1B" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox6->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox6_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox6->Text, &val))
		{
			e->Cancel = true;
            textBox6->Select(0, textBox6->Text->Length);
		}
	}
private: System::Void textBox7_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 28
		int v1;
		if(Str2Q15s(textBox7->Text, &v1))
		{
			if ((update != 29) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U1C" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox7->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox7_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox7->Text, &val))
		{
			e->Cancel = true;
            textBox7->Select(0, textBox7->Text->Length);
		}
	}
private: System::Void button10_Click(System::Object^  sender, System::EventArgs^  e) {
		// waypoint load
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("WL\r");				// waypoint load command
			form->serialPort1->Write("WP\r");				// waypoint print command
			mut->ReleaseMutex();
		}
	}
private: System::Void button11_Click(System::Object^  sender, System::EventArgs^  e) {
		// waypoint save
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("WS\r");				// waypoint save command
			mut->ReleaseMutex();
		}
	}
private: System::Void button12_Click(System::Object^  sender, System::EventArgs^  e) {
		// waypoint delete
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("WD\r");				// waypoint delete command
			form->serialPort1->Write("WP\r");				// waypoint print command
			mut->ReleaseMutex();
		}
		//pictureBox4->Load("http://maps.google.com/maps/api/staticmap?center=47.59867,-122.11708&zoom=15&size=640x480&maptype=roadmap&markers=color:blue|label:S|40.702157,-74.015794&markers=color:green|label:G|47.59867,-122.112318&markers=color:red|color:red|label:C|40.718217,-73.998284&sensor=false");
	}
private: System::Void button13_Click(System::Object^  sender, System::EventArgs^  e) {
		// waypoint update
		if (form->serialPort1->IsOpen) {
			mut->WaitOne();
			int lat, longi, alt;
			if(Str2Q15s(textBox8->Text, &lat) && Str2Q15s(textBox9->Text, &longi) && Str2Q15s(textBox10->Text, &alt))
			{
				Decimal v1, v2, v3, v4;
				v1 = numericUpDown33->Value;
				v2 = lat;
				v3 = longi;
				v4 = alt;
				String ^s = "W" + Decimal::ToUInt32(v1).ToString("X2") + Decimal::ToUInt32(v2).ToString("X8") \
					 + Decimal::ToUInt32(v3).ToString("X8") + Decimal::ToUInt32(v4).ToString("X8") + "00000000\r";
				form->serialPort1->Write(s);
				form->serialPort1->Write("WP\r");				// waypoint print command
			}
			mut->ReleaseMutex();
		}
	}
private: System::Void tabPage12_SizeChanged(System::Object^  sender, System::EventArgs^  e) {
		UpdateWaypoints(0);
	}
private: System::Void UpdateWaypoints(int all) {
		int w;
		int h;
		this->pictureBox4->Top = 0;
		this->pictureBox4->Width = this->tabPage12->Size.Width - 90;
		this->pictureBox4->Left = 90;
		this->pictureBox4->Height = this->tabPage12->Size.Height;
		h = this->pictureBox4->Size.Height;
		w =	this->pictureBox4->Size.Width;
		int	gotways = 0;
		for(int i = 0; i < 20; i++)
		{
			if(waypoints[i].valid)
			{
				gotways++;
			}
		}
		if(gotways == 0)
		{
			static int done;
			if((all == 0) && (done == 1))
				return;
			try {
				pictureBox4->Load("http://maps.google.com/maps/api/staticmap?center=0,0&zoom=1&size=" + \
(640) + "x" + (480) + "&maptype=hybrid&sensor=false");
				done = 1;
				toolStripStatusLabel3->Text = "Waypoint map loaded";
			}
			catch (Exception^ ex) {
				done = 0;
				toolStripStatusLabel3->Text = ex->Message;
			}
		}
		else
		{
			static int done;
			if((all == 0) && (done == 1))
				return;
			int first = true;
			String ^starter;
			if(gotways != 1)
				starter = gcnew String("http://maps.google.com/maps/api/staticmap?size=");
			else
				starter = gcnew String("http://maps.google.com/maps/api/staticmap?");
			String ^markers = gcnew String("&maptype=hybrid&markers=color:green|label:W|");
			for(int i = 0; i < 20; i++)
			{
				if(waypoints[i].valid)
				{
					if(gotways == 1)
					{
						starter += "center=";
						starter += Q15s2Str(waypoints[i].latq);
						starter += ",";
						starter += Q15s2Str(waypoints[i].longq);
						starter += "&size=";
					}
					if(first == false)
						markers += "|";
					else
						first = false;
					markers += Q15s2Str(waypoints[i].latq);
					markers += ",";
					markers += Q15s2Str(waypoints[i].longq);
				}
			}
			markers += "&sensor=false";
			try {
				pictureBox4->Load(starter + (640) + "x" + (480) + markers);
				done = 1;
				toolStripStatusLabel3->Text = "Waypoint map loaded";
			}
			catch (Exception^ ex) {
				done = 0;
				toolStripStatusLabel3->Text = ex->Message;
			}
		}
		//pictureBox4->SizeMode = PictureBoxSizeMode::Zoom;
	}
private: System::Void numericUpDown33_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		Decimal way = numericUpDown33->Value;
		this->textBox8->Text = Q15s2Str(waypoints[(int)way].latq);
		textBox9->Text = Q15s2Str(waypoints[(int)way].longq);
		textBox10->Text = Q15s2Str(waypoints[(int)way].altq);
	}
private: System::Void textBox11_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 54
		int v1;
		if(Str2Q15s(textBox11->Text, &v1))
		{
			if ((update != 55) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U36" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox11->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox11_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox11->Text, &val))
		{
			e->Cancel = true;
            textBox11->Select(0, textBox11->Text->Length);
		}
	}
private: System::Void pictureBox2_Paint(System::Object^  sender, System::Windows::Forms::PaintEventArgs^  e) {
		DrawHeadsup(rectl, 1, e);
		DrawHeadsup(rectr, 0, e);

		this->label60->Text = Convert::ToString((int)(HSYaw*180.0/Math::PI));
		this->label62->Text = Convert::ToString((int)(HSPitch*180.0/Math::PI));
		this->label64->Text = Convert::ToString((int)(HSRoll*180.0/Math::PI));
		this->label61->Text = Convert::ToString((int)(HYaw*180.0/Math::PI));
		this->label63->Text = Convert::ToString((int)(HPitchA*180.0/Math::PI));
		this->label65->Text = Convert::ToString((int)(HRollA*180.0/Math::PI));
	}
private: System::Void DrawHeadsup(Rectangle rect, int sens, System::Windows::Forms::PaintEventArgs^  e) {
		e->Graphics->DrawArc(tblackpen, rect, 0.0, 360.0);
		DrawBackGround(rect, sens, e);
		e->Graphics->DrawLine(tblackpen, rect.Left, (rect.Top+rect.Bottom)/2, rect.Left+rect.Width, (rect.Top+rect.Bottom)/2);

		DrawPartRadius(rect, 0, 7, e);
		DrawPartRadius(rect, 10, 7, e);
		DrawPartRadius(rect, -10, 7, e);
		DrawPartRadius(rect, 20, 7, e);
		DrawPartRadius(rect, -20, 7, e);
		DrawPartRadius(rect, 30, 15, e);
		DrawPartRadius(rect, -30, 15, e);
		DrawPartRadius(rect, 60, 15, e);
		DrawPartRadius(rect, -60, 15, e);
		DrawPartRadius(rect, 180, 7, e);
		DrawPartRadius(rect, 170, 7, e);
		DrawPartRadius(rect, -170, 7, e);
		DrawPartRadius(rect, 160, 7, e);
		DrawPartRadius(rect, -160, 7, e);
		DrawPartRadius(rect, 150, 7, e);
		DrawPartRadius(rect, -150, 7, e);

		DrawForeGround(rect, sens, e);
	}
private: System::Void DrawPartRadius(Rectangle rect, int angle, int len, System::Windows::Forms::PaintEventArgs^  e) {
		int centerx = (rect.Left+rect.Right)/2;
		int centery = (rect.Top+rect.Bottom)/2;
		double radiusa = centerx - rect.Left;
		double radiusb = centery - rect.Top;
		double s = Math::Sin(Math::PI * angle / 180.0);
		double c = Math::Cos(Math::PI * angle / 180.0);
		double radius = (radiusa*radiusb)/Math::Sqrt((radiusa*c)*(radiusa*c) + (radiusb*s)*(radiusb*s));
		int end1x = centerx - (int)(radius*s);
		int end1y = centery - (int)(radius*c);
		int end2x = end1x + (int)(len*s);
		int end2y = end1y + (int)(len*c); 
		e->Graphics->DrawLine(tblackpen, end1x, end1y, end2x, end2y);
	}
private: System::Void DrawBackGround(Rectangle rect, int sens, System::Windows::Forms::PaintEventArgs^  e) {
		GraphicsPath^ pathb = gcnew GraphicsPath;
		GraphicsPath^ patht = gcnew GraphicsPath;
		if (sens == 1)
		{
			patht->AddArc(rect, (float)(-((HSRoll+HSPitch)*180.0/Math::PI)-180), (float)(180+2*(HSPitch*180.0/Math::PI)));
			pathb->AddArc(rect, (float)(-((HSRoll-HSPitch)*180.0/Math::PI)), (float)(180-2*(HSPitch*180.0/Math::PI)));
		}
		else
		{
			patht->AddArc(rect, (float)(-((HRollA+HPitchA)*180.0/Math::PI)-180), (float)(180+2*(HPitchA*180.0/Math::PI)));
			pathb->AddArc(rect, (float)(-((HRollA-HPitchA)*180.0/Math::PI)), (float)(180-2*(HPitchA*180.0/Math::PI)));
		}
		e->Graphics->FillPath(blue, patht);
		e->Graphics->FillPath(brown, pathb);
	}
private: System::Void DrawForeGround(Rectangle rect, int sens, System::Windows::Forms::PaintEventArgs^  e) {
		float centerx = (float)((rect.Left+rect.Right)/2);
		float centery = (float)((rect.Top+rect.Bottom)/2);
		int inc = (rect.Top-rect.Bottom)/16;
		int i;
		double end1x, end2x;
		double roll = (sens==1)?HSRoll:HRollA;

		e->Graphics->TranslateTransform((float)centerx, (float)centery);
		e->Graphics->RotateTransform((float)(-roll*180.0/Math::PI));
		for(i = -45; i < 60; i += 10)
			e->Graphics->DrawLine(tblackpen, -10, (i*inc)/8, 10, (i*inc)/8);
		for(i = -50; i < 55; i += 10)
		{
			if (i == 0)
				continue;
			end1x = -(15 + Math::Abs(i/2));
			end2x = (15 + Math::Abs(i/2));
			e->Graphics->DrawLine(tblackpen, (int)end1x, (int)(i*inc)/8, (int)end2x, (int)(i*inc)/8);
			e->Graphics->DrawString(Convert::ToString((float)i), hupfont, white, (float)(end1x-((i<0)?25:18)), (float)((i*inc)/8-5));
			e->Graphics->DrawString(Convert::ToString((float)i), hupfont, white, (float)(end2x+5), (float)((i*inc)/8-5));
		}
		Point point1 = CreatePoint(rect, 0, 0);
		Point point2 = CreatePoint(rect, 5, 30);
		Point point3 = CreatePoint(rect, -5, 30);
		array<Point>^ arrow = {point1,point2,point3};
		e->Graphics->FillPolygon(white, arrow);

		point1 = CreatePoint(rect, 180, 0);
		point2 = CreatePoint(rect, 175, 30);
		point3 = CreatePoint(rect, -175, 30);
		array<Point>^ arrowb = {point1,point2,point3,point1};
		e->Graphics->DrawLines(tblackpen, arrowb);

		e->Graphics->ResetTransform();
	}
private: Point CreatePoint(Rectangle rect, int angle, int len) {
		float centerx = (float)((rect.Left+rect.Right)/2);
		float centery = (float)((rect.Top+rect.Bottom)/2);
		// Create points that define polygon.
		double radiusa = centerx - rect.Left;
		double radiusb = centery - rect.Top;
		double s = Math::Sin(Math::PI * angle / 180.0);
		double c = Math::Cos(Math::PI * angle / 180.0);
		double radius = (radiusa*radiusb)/Math::Sqrt((radiusa*c)*(radiusa*c) + (radiusb*s)*(radiusb*s));
		int end1x = -(int)(radius*s);
		int end1y = -(int)(radius*c);
		int end2x = end1x + (int)(len*s);
		int end2y = end1y + (int)(len*c);
		return Point(end2x, end2y);
	}
private: System::Void tabControl1_Deselected(System::Object^  sender, System::Windows::Forms::TabControlEventArgs^  e) {
		if(this->tabControl1->SelectedIndex == 10)
			startquad = 0;
		if(this->tabControl1->SelectedIndex == 11)
			startah = 0;
	}
private: System::Void tabControl1_Selected(System::Object^  sender, System::Windows::Forms::TabControlEventArgs^  e) {
		if(this->tabControl1->SelectedIndex == 8)
			if(form->serialPort1->IsOpen)
				button16->Enabled = true;
			else
				button16->Enabled = false;
		if(this->tabControl1->SelectedIndex == 10)
			startquad = 1;
		if(this->tabControl1->SelectedIndex == 11)
			startah = 1;
	}
private: System::Void pictureBox2_SizeChanged(System::Object^  sender, System::EventArgs^  e) {
		SetHeadsUpSize();
	}
private: System::Void SetHeadsUpSize() {
		int x = this->pictureBox2->Width;
		int y =	this->pictureBox2->Height;
		rectl.Height = y - 160;
		rectl.Width = (x - 260)/2;
		rectl.X = 80;
		rectl.Y = 80;
		rectr.Height = y - 160;
		rectr.Width = (x - 260)/2;
		rectr.X = 80 + 100 + rectl.Width;
		rectr.Y = 80;
		this->label60->Left = 80 + rectl.Width/2;
		this->label60->Top = 40;
		this->label62->Left = x/2-40;
		this->label62->Top = y/2-8;
		this->label64->Left = 80+rectl.Width/2;
		this->label64->Top = y-40;
		this->label61->Left = x/2 + 100/2 + rectr.Width/2;
		this->label61->Top = 40;
		this->label63->Left = x/2+10;
		this->label63->Top = y/2-8;
		this->label65->Left = x/2 + 100/2 + rectr.Width/2;
		this->label65->Top = y-40;
		this->label66->Left = x/2-25;
		this->label66->Top = y/2-20;
		this->label67->Left =  80+rectl.Width/2 - 25;
		this->label67->Top = y-40;
		this->label68->Left =  x/2 + 100/2 + rectr.Width/2 - 25;
		this->label68->Top = y-40;
		this->label69->Left = x/2 + 100/2 + rectr.Width/2 - 25;
		this->label69->Top = 40;
		this->label70->Left = 80+rectl.Width/2 - 25;
		this->label70->Top = 40;
		this->label76->Left = x/2 + 100/2 + rectr.Width/2 - 47;
		this->label77->Left = 80+rectl.Width/2 - 47;

		pictureBox2->Invalidate();
	}
private: System::Void tabPage11_SizeChanged(System::Object^  sender, System::EventArgs^  e) {
		QuadTabSizeChanged();
	}
private: System::Void QuadTabSizeChanged() {
		int y = this->tabPage11->Height;
		int x = this->tabPage11->Width;
		int x1 = this->trackBar1->Width;
		this->pictureBox1->Height = y;
		this->pictureBox1->Width = x - 5*x1;
		this->trackBar1->Height = y/2;
		this->trackBar2->Height = y/2;
		this->trackBar3->Height = y/2;
		this->trackBar4->Height = y/2;
		this->trackBar5->Height = y/2;
		this->trackBar6->Height = y/2;
		this->trackBar7->Height = y/2;
		this->trackBar8->Height = y/2;
		this->trackBar9->Height = y/2;
		this->trackBar10->Height = y/2;
		this->trackBar3->Top = y/2;
		this->trackBar4->Top = y/2;
		this->trackBar8->Top = y/2;
		this->trackBar9->Top = y/2;
		this->trackBar10->Top = y/2;
		this->trackBar5->Left = x - 3*x1;
		this->trackBar6->Left =  x - 2*x1;
		this->trackBar7->Left =  x - x1;
		this->trackBar8->Left = x - 3*x1;
		this->trackBar9->Left =  x - 2*x1;
		this->trackBar10->Left =  x - x1;
		label79->Left = x - 3*x1 - 30;
		label79->Top = y/4 - 5;
		label80->Left = x - 3*x1 - 30;
		label80->Top = 3*y/4 - 5;
		label81->Left = 2*x1 + 10;
		label81->Top = 3*y/4 - 5;
	}
private: System::Void SetupSeries() {
		System::Windows::Forms::DataVisualization::Charting::Series^ s;
		System::Windows::Forms::DataVisualization::Charting::ChartColorPalette palette = this->chart1->Palette;
		int i = 0;
		s = this->chart1->Series->FindByName("Gyro X");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(0);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Gyro Y");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(1);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Gyro Z");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(2);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Acc X");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(3);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Acc Y");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(4);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Acc Z");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(5);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Mag X");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(6);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Mag Y");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(7);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Mag Z");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(8);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Pressure");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(9);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Pitch");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(10);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Roll");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(11);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Yaw");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(12);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Motor Front");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(13);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Motor Back");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(14);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Motor Left");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(15);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Motor Right");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(16);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("PID Pitch");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(17);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("PID Roll");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(18);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("PID Throttle");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(19);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("PID Yaw");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(20);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 1");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(21);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 2");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(22);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 3");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(23);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 4");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(24);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 5");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(25);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 6");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(26);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 7");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(27);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("RC Channel 8");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(28);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Gyro Temp");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(29);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Altitude");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(30);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Pitch Rate");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(31);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Roll Rate");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(32);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Yaw Rate");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(33);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("Main Loop Time");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(34);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		s = this->chart1->Series->FindByName("IMU Loop Time");
		s->Enabled = !!this->checkedListBox1->GetItemChecked(35);
		if(s->Enabled)
		{
			s->Color = colors[i++];
			i %= 10;
		}
		chart1->ResetAutoValues();
	}
private: System::Void splitContainer1_ClientSizeChanged(System::Object^  sender, System::EventArgs^  e) {
		HistoryTabSizeChanged();
		 }
private: System::Void HistoryTabSizeChanged() {
		int y = this->tabPage14->Height;
		int x = this->tabPage14->Width;
		int x1 = this->checkedListBox1->Width;
		int w = this->splitContainer1->Panel2->Width;
		int w1 = this->splitContainer1->Width;
		int i = w1 - w - splitContainer1->SplitterWidth;
		if(i > 20)
		{
			if(splitContainer1->SplitterDistance > i)
				i += 5;
			else
				i -= 5;
			//splitContainer1->SplitterDistance = i;
		}
		if( y > 0)
		{
			this->chart1->Height = y;
			this->chart1->Width = x - w; //x1;
			//checkedListBox1->Left = x - x1;
		}
	}
private: System::Void checkBox34_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		rawmode = !!this->checkBox34->Checked;
	}
private: System::Void textBox12_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 55
		int v1;
		if(Str2Q15s(textBox12->Text, &v1))
		{
			if ((update != 56) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U37" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox12->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox12_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox12->Text, &val))
		{
			e->Cancel = true;
            textBox12->Select(0, textBox12->Text->Length);
		}
	}
private: System::Void textBox13_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 56
		int v1;
		if(Str2Q15s(textBox13->Text, &v1))
		{
			if ((update != 57) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U38" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox13->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox13_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox13->Text, &val))
		{
			e->Cancel = true;
            textBox13->Select(0, textBox13->Text->Length);
		}
	}
private: System::Void textBox14_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 57
		int v1;
		if(Str2Q15s(textBox14->Text, &v1))
		{
			if ((update != 58) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U39" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox14->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox14_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox14->Text, &val))
		{
			e->Cancel = true;
            textBox14->Select(0, textBox14->Text->Length);
		}
	}
private: System::Void textBox15_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 58
		int v1;
		if(Str2Q15s(textBox15->Text, &v1))
		{
			if ((update != 59) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U3A" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox15->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox15_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox15->Text, &val))
		{
			e->Cancel = true;
            textBox15->Select(0, textBox15->Text->Length);
		}
	}
private: System::Void textBox16_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 59
		int v1;
		if(Str2Q15s(textBox16->Text, &v1))
		{
			if ((update != 60) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U3B" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox16->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox16_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox16->Text, &val))
		{
			e->Cancel = true;
            textBox16->Select(0, textBox16->Text->Length);
		}
	}
private: System::Void button14_Click(System::Object^  sender, System::EventArgs^  e) {
		if (this->button14->Text == "Open") {
			openFileDialog1->Filter = "Capture File|*.txt";
			openFileDialog1->Title = "Open a Capture File";
			openFileDialog1->RestoreDirectory = true ;

			if(openFileDialog1->ShowDialog() == System::Windows::Forms::DialogResult::OK)
			{
				if((myReadStream = gcnew StreamReader(openFileDialog1->OpenFile())))
				{
					int i;
					if((i = openFileDialog1->FileName->LastIndexOf('\\')) == -1)
						label86->Text = openFileDialog1->FileName;
					else
						label86->Text = openFileDialog1->FileName->Substring(i+1);
					DateTime d1 = DateTime::Now;
					// Waiting / hour glass  
					this->Cursor->Current = Cursors::WaitCursor; 
					while(1)
					{
						String ^s = myReadStream->ReadLine();
						if(s == nullptr)
							break;
						else if(s->Length == 0)
							;
						else
						{
							s = s + "\r";
							try
							{
								ProcessResponse(s);
							}
							catch (...) {  }
						}
					}
					// Back to normal
					this->Cursor->Current = Cursors::Default;
					if(myReadStream)
						myReadStream->Close();
					myReadStream = nullptr;
				}
			}
		}
	}
private: System::Void button15_Click(System::Object^  sender, System::EventArgs^  e) {
		System::Windows::Forms::DataVisualization::Charting::Series^ s;
		label86->Text = "";
		s = this->chart1->Series->FindByName("Gyro X");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro X Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Y");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Y Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Z");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Z Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc X");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc X Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc Y");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc Y Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc Z");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Acc Z Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag X");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag X Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag Y");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag Y Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag Z");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Mag Z Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Pitch");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Pitch Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Roll");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Roll Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Yaw");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Yaw Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Front");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Front Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Back");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Back Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Left");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Left Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Right");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Motor Right Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Pressure");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Pressure Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Pitch");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Pitch Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Roll");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Roll Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Throttle");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Throttle Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Yaw");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("PID Yaw Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 1");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 1 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 2");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 2 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 3");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 3 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 4");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 4 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 5");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 5 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 6");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 6 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 7");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 7 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 8");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("RC Channel 8 Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Temp");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Gyro Temp Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Altitude");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Altitude Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Pitch Rate");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Pitch Rate Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Roll Rate");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Roll Rate Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Yaw Rate");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Yaw Rate Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Main Loop Time");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("Main Loop Time Orig");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Loop Time");
		s->Points->Clear();
		s = this->chart1->Series->FindByName("IMU Loop Time Orig");
		s->Points->Clear();
		pointIndex = 0;
		System::Windows::Forms::DataVisualization::Charting::ChartArea^ c;
		// Adjust Y & X axis scale
		chart1->ResetAutoValues();
		c = chart1->ChartAreas->FindByName("ChartArea1");
		// Adjust X axis scale
		c->AxisX->Minimum = pointIndex;
		c->AxisX->Maximum = pointIndex+1;
	}
private: System::Void trackBar1_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		if ((noupdate == 0) && form->serialPort1->IsOpen) {
			Decimal val;
			mut->WaitOne();
			val = trackBar1->Value;
			form->serialPort1->Write("M0" + Decimal::ToUInt32(val).ToString("X4") + "\r");
			mut->ReleaseMutex();
		}
	}
private: System::Void trackBar2_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		if ((noupdate == 0) && form->serialPort1->IsOpen) {
			Decimal val;
			mut->WaitOne();
			val = trackBar2->Value;
			form->serialPort1->Write("M1" + Decimal::ToUInt32(val).ToString("X4") + "\r");
			mut->ReleaseMutex();
		}
	}
private: System::Void trackBar3_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		if ((noupdate == 0) && form->serialPort1->IsOpen) {
			Decimal val;
			mut->WaitOne();
			val = trackBar3->Value;
			form->serialPort1->Write("M2" + Decimal::ToUInt32(val).ToString("X4") + "\r");
			mut->ReleaseMutex();
		}
	}
private: System::Void trackBar4_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		if ((noupdate == 0) && form->serialPort1->IsOpen) {
			Decimal val;
			mut->WaitOne();
			val = trackBar4->Value;
			form->serialPort1->Write("M3" + Decimal::ToUInt32(val).ToString("X4") + "\r");
			mut->ReleaseMutex();
		}
	}
private: System::Void checkedListBox1_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		SetupSeries();
	}
private: System::Void ReadConfig() {
		int val = 0, x, y, w, h, val1;
		Int64 val64 = 0;
		x = this->DesktopLocation.X;
		y = this->DesktopLocation.Y;
		w = this->Size.Width;
		h = this->Size.Height;
		val = 0;
		val1 = -1;
		RegistryKey^ k =  Registry::CurrentUser->OpenSubKey("Software\\timmmoore\\QuadCopter", true);
		if (k != nullptr)
		{
		    int::TryParse(k->GetValue("RawMode", val)->ToString(), val);
		    int::TryParse(k->GetValue("Window_Left", x)->ToString(), x);
		    int::TryParse(k->GetValue("Window_Top", y)->ToString(), y);
		    int::TryParse(k->GetValue("Window_Width", w)->ToString(), w);
		    int::TryParse(k->GetValue("Window_Height", h)->ToString(), h);
			comp = k->GetValue("ComPort", h)->ToString();
		    int::TryParse(k->GetValue("Baudrate", val1)->ToString(), val1);
			Int64::TryParse(k->GetValue( "Chart_Display", val64)->ToString(), val64);
		}
		this->checkBox34->Checked = (val != 0);
		this->DesktopLocation = System::Drawing::Point(x, y);
		this->Size = System::Drawing::Size(w, h);
		if(comp != nullptr)
		{
			int i = this->comboBox1->FindStringExact(comp);
			SetChecked(comp);
			if(i == -1) i = 0;
			this->comboBox1->SelectedIndex = i;
		}
		baudrate = val1;
		SetChartDisplay(val64);
	}
private: System::Void WriteConfig() {
		RegistryKey^ k = Registry::CurrentUser->OpenSubKey("Software\\timmmoore\\QuadCopter", true);
		if (k == nullptr)
			k = Registry::CurrentUser->CreateSubKey("Software\\timmmoore\\QuadCopter");
		if (k != nullptr)
		{
			k->SetValue( "RawMode", !!this->checkBox34->Checked, RegistryValueKind::DWord );
			k->SetValue( "Window_Left", this->DesktopLocation.X, RegistryValueKind::DWord );
			k->SetValue( "Window_Width", this->Size.Width, RegistryValueKind::DWord );
			k->SetValue( "Window_Top", this->DesktopLocation.Y, RegistryValueKind::DWord );
			k->SetValue( "Window_Height", this->Size.Height, RegistryValueKind::DWord );
			if(comp == nullptr)
				k->SetValue( "ComPort", this->comboBox1->SelectedItem->ToString(), RegistryValueKind::String );
			else
				k->SetValue( "ComPort", comp, RegistryValueKind::String );
			k->SetValue( "Chart_Display", GetChartDisplay(), RegistryValueKind::QWord );
		}
	}
private: System::Void Form1_Shown(System::Object^  sender, System::EventArgs^  e) {
		ReadConfig();
		WindowState = FormWindowState::Normal;
	}
private: System::Void comboBox1_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		comp = (String^)(this->comboBox1->SelectedItem);
		SetChecked(comp);
	}
private: System::Void textBox17_Validated(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 48
		int v1;
		if(Str2Q15s(textBox17->Text, &v1))
		{
			if ((update != 49) && form->serialPort1->IsOpen) {
				Decimal val;
				mut->WaitOne();
				val = v1;
				form->serialPort1->Write("U30" + Decimal::ToInt32(val).ToString("X8") + "\r");
				mut->ReleaseMutex();
				SetConfigStatus(true);
			}
			textBox17->Text = Q15s2Str(v1);
		}
	}
private: System::Void textBox17_Validating(System::Object^  sender, System::ComponentModel::CancelEventArgs^  e) {
		int val;
		if(!Str2Q15s(textBox17->Text, &val))
		{
			e->Cancel = true;
            textBox17->Select(0, textBox17->Text->Length);
		}
	}
private: System::Void button16_Click(System::Object^  sender, System::EventArgs^  e) {

		if(button16->Text == "Start Calibration")
		{
			if (form->serialPort1->IsOpen) {
				mcommand[0] = mcommand[1] = mcommand[2] = mcommand[3] = 0;
				form->serialPort1->Write("M0FFFF\r");
				// Waiting / hour glass  
				this->Cursor->Current = Cursors::WaitCursor; 
				calibrationcount = 0;
				startcalibration = 1;
			}
		}
		else
		{
			if (form->serialPort1->IsOpen) {
				mcommand[0] = mcommand[1] = mcommand[2] = mcommand[3] = 0xffff;
				form->serialPort1->Write("M00000\r");
				// Waiting / hour glass  
				this->Cursor->Current = Cursors::WaitCursor; 
				calibrationcount = 0;
				startcalibration = 2;
			}
		}
	}
private: System::Void tabPage15_SizeChanged(System::Object^  sender, System::EventArgs^  e) {
		CalibrationTabSizeChanged();
	}
private: System::Void CalibrationTabSizeChanged() {
		int y = this->tabPage15->Height;
		int x = this->tabPage15->Width;
		richTextBox3->Width = x - 20;
		richTextBox4->Width = x - 20;
		button16->Left = x/2 - 53;
	}
private: System::Void SetRCIndicator(int rc, int *value) {
		Decimal rcvalue = -1;
		int val = 0;
		switch(rc)
		{
		case 1:
			rcvalue = numericUpDown5->Value;
			break;
		case 2:
			rcvalue = numericUpDown6->Value;
			break;
		case 3:
			rcvalue = numericUpDown7->Value;
			break;
		case 4:
			rcvalue = numericUpDown8->Value;
			break;
		case 5:
			rcvalue = numericUpDown9->Value;
			break;
		case 6:
			rcvalue = numericUpDown10->Value;
			break;
		case 7:
			rcvalue = numericUpDown11->Value;
			break;
		case 8:
			rcvalue = numericUpDown12->Value;
			break;
		}
		val = value[((int)rcvalue)-1];
		if(val < 1000) val = 1000;
		if(val > 2000) val = 2000;
		switch(rc)
		{
		case 1:
			trackBar11->Value = val;
			break;
		case 2:
			trackBar12->Value = val;
			break;
		case 3:
			trackBar13->Value = val;
			break;
		case 4:
			trackBar14->Value = val;
			break;
		case 5:
			trackBar15->Value = val;
			break;
		case 6:
			trackBar16->Value = val;
			break;
		case 7:
			trackBar17->Value = val;
			if((val-1500) >= numericUpDown2->Value)
			{
				toolStripStatusLabel5->Text = "Hold";
				trackBar17->BackColor = Color::Green;
			}
			else
			{
				toolStripStatusLabel5->Text = "";
				trackBar17->BackColor = Color::Red;
			}
			break;
		case 8:
			trackBar18->Value = val;
			if((val-1500) >= numericUpDown3->Value)
				trackBar18->BackColor = Color::Green;
			else
				trackBar18->BackColor = Color::Red;
			break;
		}
	}
private: System::Void checkBox8_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 23
		if ((update != 24) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if(this->checkBox8->Checked != 0)
				form->serialPort1->Write("U17FF\r");
			else
				form->serialPort1->Write("U1700\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void tabPage3_Click(System::Object^  sender, System::EventArgs^  e) {
		tabPage3->Focus();
	}
private: System::Void tabPage6_Click(System::Object^  sender, System::EventArgs^  e) {
		tabPage6->Focus();
	}
private: System::Void tabPage8_Click(System::Object^  sender, System::EventArgs^  e) {
		tabPage8->Focus();
	}
private: System::Void checkBox17_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		GyroTempInvert();
	}
private: System::Void checkBox18_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		GyroTempInvert();
	}
private: System::Void checkBox19_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		GyroTempInvert();
	}
private: System::Void GyroTempInvert() {
		Decimal val;
		val = checkBox17->Checked?1:0 | checkBox18->Checked?2:0 | checkBox19->Checked?4:0;
		// Update variable 49
		if ((update != 50) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			form->serialPort1->Write("U31" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Int64 GetChartDisplay() {
		Int64 bits = 0;
		Int64 shift = 1;
		try
			{
			for(int i = 0; i <= 63; i++) {
				if(this->checkedListBox1->GetItemChecked(i))
					bits |= shift;
				shift <<= 1;
			}
		}
		catch (...) { }
		return bits;
	}
private: System::Void SetChartDisplay(Int64 val) {
		Int64 shift = 1;
		try
		{
			for(int i = 0; i <= 63; i++) {
				if(val & shift)
				{
					this->checkedListBox1->SetItemChecked(i, true);
				}
				shift <<= 1;
			}
		}
		catch (...) { }
		SetupSeries();
	}
private: System::Void textBox1_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage3->Focus();
		}
	}
private: System::Void textBox2_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage3->Focus();
		}
	}
private: System::Void textBox3_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox4_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox5_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox6_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox7_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox11_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage6->Focus();
		}
	}
private: System::Void textBox12_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void textBox13_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void textBox14_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void textBox15_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void textBox16_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void textBox17_KeyUp(System::Object^  sender, System::Windows::Forms::KeyEventArgs^  e) {
		if(e->KeyCode == Keys::Return)
		{
			tabPage8->Focus();
		}
	}
private: System::Void SetConfigStatus(Boolean status) {
		if(status == true)
			toolStripStatusLabel2->Text = "Configuration modified";
		else
			toolStripStatusLabel2->Text = "";
	}
private: System::Void checkBox20_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 60
		if ((update != 61) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			if(this->checkBox20->Checked != 0)
				form->serialPort1->Write("U3CFF\r");
			else
				form->serialPort1->Write("U3C00\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void toolStripDropDownButton1_DropDownItemClicked(System::Object^  sender, System::Windows::Forms::ToolStripItemClickedEventArgs^  e) {
		if (!form->serialPort1->IsOpen) {
			this->serialPort1->PortName = e->ClickedItem->Text;
			SetChecked(e->ClickedItem->Text);
			int i = this->comboBox1->FindStringExact(e->ClickedItem->Text);
			this->comboBox1->SelectedIndex = i;
		}
	}
private: System::Void SetChecked(String ^comport) {
		int index = -1;
		for(int j = 0;j < toolStripSplitButton1->DropDownItems->Count ; j++)
		{
			if(((ToolStripMenuItem^)(toolStripSplitButton1->DropDownItems[j]))->Checked)
				((ToolStripMenuItem^)(toolStripSplitButton1->DropDownItems[j]))->Checked = false;
		}
		for(int j = 0;j < toolStripSplitButton1->DropDownItems->Count ; j++)
		{
			if(((ToolStripMenuItem^)(toolStripSplitButton1->DropDownItems[j]))->Text == comport)
				((ToolStripMenuItem^)(toolStripSplitButton1->DropDownItems[j]))->Checked = true;
		}
	}
private: System::Void toolStripSplitButton1_ButtonClick(System::Object^  sender, System::EventArgs^  e) {
		Connect(1);
	}
private: System::Void toolStripSplitButton1_Opening(System::Object^  sender, System::EventArgs^  e) {
		LoadStatusComPorts();
		LoadComPorts();
	}
private: System::Void LoadStatusComPorts() {
		array<String^>^ ports = this->serialPort1->GetPortNames(); 
		int index = -1;
		String ^p = nullptr;
		for(int j = 0;j < toolStripSplitButton1->DropDownItems->Count ; j++)
		{
			if(((ToolStripMenuItem^)(toolStripSplitButton1->DropDownItems[j]))->Checked)
			{
				p = toolStripSplitButton1->DropDownItems[j]->Text;
			}
		}
		toolStripSplitButton1->DropDownItems->Clear();
		// Display each port name to the console.
		for each(String^ port in ports)
		{
			toolStripSplitButton1->DropDownItems->Add(port);
		}
		if(p != nullptr)
			SetChecked(p);
		else
			SetChecked(comp);
	}
private: System::Void listBox1_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Gyro X Orig", "Gyro X", listBox1);
	}
private: System::Void listBox2_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Gyro Y Orig", "Gyro Y", listBox2);
	}
private: System::Void listBox3_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Gyro Z Orig", "Gyro Z", listBox3);
	}
private: System::Void listBox4_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Acc X Orig", "Acc X", listBox4);
	}
private: System::Void listBox5_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Acc Y Orig", "Acc Y", listBox5);
	}
private: System::Void listBox6_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Acc Z Orig", "Acc Z", listBox6);
	}
private: System::Void listBox7_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Mag X Orig", "Mag X", listBox7);
	}
private: System::Void listBox8_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Motor Front Orig", "Motor Front", listBox8);
	}
private: System::Void listBox9_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Yaw Orig", "IMU Yaw", listBox9);
	}
private: System::Void listBox10_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Roll Orig", "IMU Roll", listBox10);
	}
private: System::Void listBox11_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Pitch Orig", "IMU Pitch", listBox11);
	}
private: System::Void listBox12_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Pressure Orig", "Pressure", listBox12);
	}
private: System::Void listBox13_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Mag Z Orig", "Mag Z", listBox13);
	}
private: System::Void listBox14_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Mag Y Orig", "Mag Y", listBox14);
	}
private: System::Void listBox15_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("PID Yaw Orig", "PID Yaw", listBox15);
	}
private: System::Void listBox16_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("PID Throttle Orig", "PID Throttle", listBox16);
	}
private: System::Void listBox17_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("PID Roll Orig", "PID Roll", listBox17);
	}
private: System::Void listBox18_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("PID Pitch Orig", "PID Pitch", listBox18);
	}
private: System::Void listBox19_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Motor Right Orig", "Motor Right", listBox19);
	}
private: System::Void listBox20_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Motor Left Orig", "Motor Left", listBox20);
	}
private: System::Void listBox21_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Motor Back Orig", "Motor Back", listBox21);
	}
private: System::Void listBox22_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 7 Orig", "RC Channel 7", listBox22);
	}
private: System::Void listBox23_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 6 Orig", "RC Channel 6", listBox23);
	}
private: System::Void listBox24_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 5 Orig", "RC Channel 5", listBox24);
	}
private: System::Void listBox25_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 4 Orig", "RC Channel 4", listBox25);
	}
private: System::Void listBox26_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 3 Orig", "RC Channel 3", listBox26);
	}
private: System::Void listBox27_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 2 Orig", "RC Channel 2", listBox27);
	}
private: System::Void listBox28_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 1 Orig", "RC Channel 1", listBox28);
	}
private: System::Void listBox29_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Altitude Orig", "Altitude", listBox29);
	}
private: System::Void listBox30_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Gyro Temp Orig", "Gyro Temp", listBox30);
	}
private: System::Void listBox31_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("RC Channel 8 Orig", "RC Channel 8", listBox31);
	}
private: System::Void listBox32_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Roll Rate Orig", "IMU Roll Rate", listBox32);
	}
private: System::Void listBox33_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Pitch Rate Orig", "IMU Pitch Rate", listBox33);
	}
private: System::Void listBox34_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Yaw Rate Orig", "IMU Yaw Rate", listBox34);
	}
private: System::Void listBox35_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("Main Loop Time Orig", "Main Loop Time", listBox35);
	}
private: System::Void listBox36_SelectedIndexChanged(System::Object^  sender, System::EventArgs^  e) {
		ChangeScale("IMU Loop Time Orig", "IMU Loop Time", listBox36);
	}
private: System::Void ChangeScale(String ^orig, String ^dest, System::Windows::Forms::ListBox^ listbox) {
		System::Windows::Forms::DataVisualization::Charting::Series^ s;
		System::Windows::Forms::DataVisualization::Charting::Series^ ss;
		s = this->chart1->Series->FindByName(dest);
		ss = this->chart1->Series->FindByName(orig);
		s->Points->Clear();
		for(int j = 0;j < ss->Points->Count ; j++)
		{
			s->Points->AddXY(ss->Points[j]->XValue, ss->Points[j]->YValues[0]*scales[listbox->SelectedIndex==-1?4:listbox->SelectedIndex]);
		}
	}
private: System::Void Form1_FormClosing(System::Object^  sender, System::Windows::Forms::FormClosingEventArgs^  e) {
		closing = 1;
		tobeclosed = 1;
		if(doingtext)
			e->Cancel = true;
	}
private: System::Void numericUpDown32_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 63
		if ((update != 64) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown32->Value;
			val = val + (this->checkBox21->Checked?128:0);
			form->serialPort1->Write("U3F" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown34_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 62
		if ((update != 63) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown34->Value;
			val = val + (this->checkBox22->Checked?128:0);
			form->serialPort1->Write("U3E" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void numericUpDown35_ValueChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 61
		if ((update != 62) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown35->Value;
			val = val + (this->checkBox23->Checked?128:0);
			form->serialPort1->Write("U3D" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox21_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 63
		if ((update != 64) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown32->Value;
			val = val + (this->checkBox21->Checked?128:0);
			form->serialPort1->Write("U3F" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox22_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 62
		if ((update != 63) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown34->Value;
			val = val + (this->checkBox22->Checked?128:0);
			form->serialPort1->Write("U3E" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
private: System::Void checkBox23_CheckedChanged(System::Object^  sender, System::EventArgs^  e) {
		// Update variable 61
		if ((update != 62) && form->serialPort1->IsOpen) {
			mut->WaitOne();
			Decimal val = this->numericUpDown35->Value;
			val = val + (this->checkBox23->Checked?128:0);
			form->serialPort1->Write("U3D" + Decimal::ToUInt32(val).ToString("X2") + "\r");
			mut->ReleaseMutex();
			SetConfigStatus(true);
		}
	}
};
}
